@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002-2008, The Perl Foundation.
- * $Id: /mirror/trunk/compilers/imcc/debug.c 32919 2008-11-19T17:21:15.952103Z particle  $
+ * $Id: /mirror/trunk/compilers/imcc/debug.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
  */
 
 /*
@@ -24,6 +24,7 @@ handle info/error/warning messages from imcc
 */
 
 #include "imc.h"
+#include "parrot/io.h"
 
 /* HEADERIZER HFILE: compilers/imcc/debug.h */
 
@@ -43,6 +44,7 @@ PARROT_DOES_NOT_RETURN
 void
 IMCC_fatal(PARROT_INTERP, SHIM(int code), ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_fatal)
     va_list ap;
 
     va_start(ap, fmt);
@@ -66,6 +68,7 @@ PARROT_DOES_NOT_RETURN
 void
 IMCC_fataly(PARROT_INTERP, SHIM(int code), ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_fataly)
     va_list ap;
 
     va_start(ap, fmt);
@@ -90,10 +93,11 @@ PARROT_DOES_NOT_RETURN
 void
 IMCC_fatal_standalone(PARROT_INTERP, int code, ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_fatal_standalone)
     va_list ap;
 
     va_start(ap, fmt);
-    imcc_vfprintf(interp, stderr, fmt, ap);
+    imcc_vfprintf(interp, Parrot_io_STDERR(interp), fmt, ap);
     va_end(ap);
     Parrot_exit(interp, code);
 }
@@ -114,12 +118,13 @@ PARROT_DOES_NOT_RETURN
 void
 IMCC_fataly_standalone(PARROT_INTERP, int code, ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_fataly_standalone)
 
     va_list ap;
 
     va_start(ap, fmt);
     fprintf(stderr, "error:imcc:");
-    imcc_vfprintf(interp, stderr, fmt, ap);
+    imcc_vfprintf(interp, Parrot_io_STDERR(interp), fmt, ap);
     va_end(ap);
     IMCC_print_inc(interp);
     Parrot_exit(interp, code);
@@ -140,12 +145,13 @@ PARROT_EXPORT
 void
 IMCC_warning(PARROT_INTERP, ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_warning)
     va_list ap;
     if (IMCC_INFO(interp)->imcc_warn)
         return;
 
     va_start(ap, fmt);
-    imcc_vfprintf(interp, stderr, fmt, ap);
+    imcc_vfprintf(interp, Parrot_io_STDERR(interp), fmt, ap);
     va_end(ap);
 }
 
@@ -164,13 +170,14 @@ PARROT_EXPORT
 void
 IMCC_info(PARROT_INTERP, int level, ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_info)
     va_list ap;
 
     if (level > IMCC_INFO(interp)->verbose)
         return;
 
     va_start(ap, fmt);
-    imcc_vfprintf(interp, stderr, fmt, ap);
+    imcc_vfprintf(interp, Parrot_io_STDERR(interp), fmt, ap);
     va_end(ap);
 }
 
@@ -188,12 +195,13 @@ PARROT_EXPORT
 void
 IMCC_debug(PARROT_INTERP, int level, ARGIN(const char *fmt), ...)
 {
+    ASSERT_ARGS(IMCC_debug)
     va_list ap;
 
     if (!(level & IMCC_INFO(interp)->debug))
         return;
     va_start(ap, fmt);
-    imcc_vfprintf(interp, stderr, fmt, ap);
+    imcc_vfprintf(interp, Parrot_io_STDERR(interp), fmt, ap);
     va_end(ap);
 }
 
@@ -210,19 +218,22 @@ Dumps the current instruction status of IMCC
 void
 dump_instructions(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_instructions)
     const Instruction *ins;
-    int pc;
+    int                pc;
 
-    fprintf(stderr,
+    Parrot_io_fprintf(interp, Parrot_io_STDERR(interp),
             "\nDumping the instructions status:"
             "\n-------------------------------\n");
-    fprintf(stderr,
+    Parrot_io_fprintf(interp, Parrot_io_STDERR(interp),
             "nins line blck deep flags\t    type opnr size   pc  X ins\n");
+
     for (pc = 0, ins = unit->instructions; ins; ins = ins->next) {
         const Basic_block * const bb = unit->bb_list[ins->bbindex];
 
         if (bb) {
-             fprintf(stderr, "%4i %4d %4d %4d\t%x\t%8x %4d %4d %4d  %c ",
+            Parrot_io_fprintf(interp, Parrot_io_STDERR(interp),
+                    "%4i %4d %4d %4d\t%x\t%8x %4d %4d %4d  %c ",
                      ins->index, ins->line, bb->index, bb->loop_depth,
                      ins->flags, (ins->type & ~ITEXT), ins->opnum,
                      ins->opsize, pc, ins->type & ITEXT ? 'X' : ' ');
@@ -231,10 +242,12 @@ dump_instructions(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
              fprintf(stderr, "\t");
         }
 
-        imcc_fprintf(interp, stderr, "%I\n", ins);
+        Parrot_io_fprintf(interp, Parrot_io_STDERR(interp), "%s\n", ins->opname);
+        ins_print(interp, Parrot_io_STDERR(interp), ins);
         pc += ins->opsize;
     }
-    fprintf(stderr, "\n");
+
+    Parrot_io_fprintf(interp, Parrot_io_STDERR(interp), "\n");
 }
 
 /*
@@ -250,6 +263,7 @@ Dumps the current IMCC config data.
 void
 dump_cfg(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_cfg)
     unsigned int i;
     Edge *e;
 
@@ -289,6 +303,7 @@ Dumps the current loops in the IMC_Unit C<unit>.
 void
 dump_loops(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_loops)
     int i;
     Loop_info ** loop_info = unit->loop_info;
 
@@ -335,6 +350,7 @@ Dumps the list of labels in IMC_Unit C<unit>.
 void
 dump_labels(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_labels)
     const SymHash * const hsh = &unit->hash;
     unsigned int          i;
 
@@ -368,6 +384,7 @@ Dumps a list of the symbolic registers in IMC_Unit C<unit>
 void
 dump_symreg(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_symreg)
     unsigned int i;
     SymReg ** const reglist = unit->reglist;
 
@@ -416,6 +433,7 @@ allocated.
 void
 dump_liveness_status(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_liveness_status)
     unsigned int i;
     SymReg ** const reglist = unit->reglist;
 
@@ -444,6 +462,7 @@ Dumps the state of SymReg C<r> in IMC_Unit C<unit>.
 void
 dump_liveness_status_var(ARGIN(const IMC_Unit *unit), ARGIN(const SymReg* r))
 {
+    ASSERT_ARGS(dump_liveness_status_var)
     fprintf(stderr, "\nSymbol %s:", r->name);
     if (r->life_info) {
         unsigned int i;
@@ -492,6 +511,7 @@ Dumps the interference graph for the current IMC_Unit C<unit>
 void
 dump_interference_graph(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_interference_graph)
     int x;
     SymReg** const reglist = unit->reglist;
     const int n_symbols = unit->n_symbols;
@@ -531,6 +551,7 @@ Dumps the current list of dominators for the current IMC_Unit C<unit>.
 void
 dump_dominators(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_dominators)
     unsigned int i;
 
     fprintf(stderr, "\nDumping the Dominators Tree:"
@@ -565,6 +586,7 @@ Dumps the list of dominance frontiers for the current IMC_Unit C<unit>.
 void
 dump_dominance_frontiers(ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(dump_dominance_frontiers)
     unsigned int i;
 
     fprintf(stderr, "\nDumping the Dominance Frontiers:"
