@@ -1,5 +1,5 @@
 /*
- * $Id: /mirror/trunk/compilers/imcc/main.c 33786 2008-12-10T10:29:09.542239Z kjs  $
+ * $Id: /mirror/trunk/compilers/imcc/main.c 35806 2009-01-19T22:31:16.548456Z infinoid  $
  *
  * Intermediate Code Compiler for Parrot.
  *
@@ -45,10 +45,9 @@ extern int yydebug;
 
 static void compile_to_bytecode(PARROT_INTERP,
     ARGIN(const char * const sourcefile),
-    ARGIN(const char * const output_file))
+    ARGIN_NULLOK(const char * const output_file))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3);
+        __attribute__nonnull__(2);
 
 static void determine_input_file_type(PARROT_INTERP,
     ARGIN(const char * const sourcefile))
@@ -77,11 +76,10 @@ static void imcc_get_optimization_description(
 
 static void imcc_run_pbc(PARROT_INTERP,
     int obj_file,
-    ARGIN(const char *output_file),
+    ARGIN_NULLOK(const char *output_file),
     int argc,
     ARGIN(char **argv))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(3)
         __attribute__nonnull__(5);
 
 static void imcc_write_pbc(PARROT_INTERP, ARGIN(const char *output_file))
@@ -100,6 +98,35 @@ static void usage(ARGMOD(FILE *fp))
         __attribute__nonnull__(1)
         FUNC_MODIFIES(*fp);
 
+#define ASSERT_ARGS_compile_to_bytecode __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sourcefile)
+#define ASSERT_ARGS_determine_input_file_type __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sourcefile)
+#define ASSERT_ARGS_determine_output_file_type __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(obj_file) \
+    || PARROT_ASSERT_ARG(output_file)
+#define ASSERT_ARGS_do_pre_process __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_help __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_help_debug __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_imcc_get_optimization_description \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(opt_desc)
+#define ASSERT_ARGS_imcc_run_pbc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(argv)
+#define ASSERT_ARGS_imcc_write_pbc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(output_file)
+#define ASSERT_ARGS_is_all_hex_digits __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(s)
+#define ASSERT_ARGS_Parrot_version __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_usage __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(fp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -117,6 +144,7 @@ Outputs usage error message.
 static void
 usage(ARGMOD(FILE *fp))
 {
+    ASSERT_ARGS(usage)
     fprintf(fp,
             "parrot -[abcCEfgGhjprStvVwy.] [-d [FLAGS]] [-D [FLAGS]]"
             "[-O [level]] [-o FILE] <file>\n");
@@ -135,6 +163,7 @@ Print out list of debugging flag values.
 static void
 help_debug(void)
 {
+    ASSERT_ARGS(help_debug)
     /* split printf for C89 compliance on string length */
     printf(
     "--imcc-debug -d [Flags] ...\n"
@@ -179,6 +208,7 @@ Print out "help" list of options.
 static void
 help(void)
 {
+    ASSERT_ARGS(help)
     /* split printf for C89 compliance on string length */
     printf(
     "parrot [Options] <file>\n"
@@ -236,6 +266,7 @@ Print out parrot version number.
 static void
 Parrot_version(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_version)
     printf("This is parrot version " PARROT_VERSION);
     printf(" built for " PARROT_ARCHNAME ".\n");
     printf("Copyright (C) 2001-2008, The Perl Foundation.\n\
@@ -312,6 +343,7 @@ PARROT_PURE_FUNCTION
 static int
 is_all_hex_digits(ARGIN(const char *s))
 {
+    ASSERT_ARGS(is_all_hex_digits)
     for (; *s; s++)
         if (!isxdigit(*s))
             return 0;
@@ -573,6 +605,7 @@ Pre-processor step.  Turn parser's output codes into Parrot instructions.
 static void
 do_pre_process(PARROT_INTERP)
 {
+    ASSERT_ARGS(do_pre_process)
     int       c;
     YYSTYPE   val;
 
@@ -694,6 +727,7 @@ Create list (opt_desc[]) describing optimisation flags.
 static void
 imcc_get_optimization_description(const PARROT_INTERP, int opt_level, ARGMOD(char *opt_desc))
 {
+    ASSERT_ARGS(imcc_get_optimization_description)
     int i = 0;
 
     if (opt_level & (OPT_PRE | OPT_CFG))
@@ -764,9 +798,10 @@ Write out or run Parrot bytecode.
 */
 
 static void
-imcc_run_pbc(PARROT_INTERP, int obj_file, ARGIN(const char *output_file),
+imcc_run_pbc(PARROT_INTERP, int obj_file, ARGIN_NULLOK(const char *output_file),
         int argc, ARGIN(char **argv))
 {
+    ASSERT_ARGS(imcc_run_pbc)
     if (IMCC_INFO(interp)->imcc_warn)
         PARROT_WARNINGS_on(interp, PARROT_WARNINGS_ALL_FLAG);
     else
@@ -802,6 +837,7 @@ Output packed bytecode file.
 static void
 imcc_write_pbc(PARROT_INTERP, ARGIN(const char *output_file))
 {
+    ASSERT_ARGS(imcc_write_pbc)
     size_t    size;
     opcode_t *packed;
     FILE     *fp;
@@ -840,6 +876,7 @@ Read in the source and determine whether it's Parrot bytecode or PASM
 static void
 determine_input_file_type(PARROT_INTERP, ARGIN(const char * const sourcefile))
 {
+    ASSERT_ARGS(determine_input_file_type)
     yyscan_t yyscanner = IMCC_INFO(interp)->yyscanner;
 
     /* Read in the source and check the file extension for the input type;
@@ -884,6 +921,7 @@ static void
 determine_output_file_type(PARROT_INTERP,
     ARGMOD(int *obj_file), ARGIN(const char *output_file))
 {
+    ASSERT_ARGS(determine_output_file_type)
     const char * const ext = strrchr(output_file, '.');
 
     if (ext) {
@@ -917,8 +955,9 @@ Compile source code into bytecode (or die trying).
 static void
 compile_to_bytecode(PARROT_INTERP,
                     ARGIN(const char * const sourcefile),
-                    ARGIN(const char * const output_file))
+                    ARGIN_NULLOK(const char * const output_file))
 {
+    ASSERT_ARGS(compile_to_bytecode)
     PackFile *pf;
     yyscan_t  yyscanner = IMCC_INFO(interp)->yyscanner;
     const int per_pbc   = (STATE_WRITE_PBC(interp) | STATE_RUN_PBC(interp)) !=0;
@@ -1002,11 +1041,6 @@ imcc_run(PARROT_INTERP, ARGIN(const char *sourcefile), int argc,
     yyscan_t           yyscanner   = IMCC_INFO(interp)->yyscanner;
     const char * const output_file = interp->output_file;
 
-    /* set the top of the stack so GC can trace it for GC-able pointers
-     * see trace_system_areas() in src/cpu_dep.c */
-    if (!interp->lo_var_ptr)
-        interp->lo_var_ptr = (void *)&obj_file;
-
     /* Figure out what kind of source file we have -- if we have one */
     if (!sourcefile || !*sourcefile)
         IMCC_fatal_standalone(interp, 1, "main: No source file specified.\n");
