@@ -1,5 +1,5 @@
 /*
- * $Id: /mirror/trunk/compilers/imcc/optimizer.c 33908 2008-12-14T10:35:51.062036Z cotto  $
+ * $Id: /mirror/trunk/compilers/imcc/optimizer.c 35201 2009-01-07T19:39:37.537872Z coke  $
  * Copyright (C) 2002-2008, The Perl Foundation.
  */
 
@@ -51,7 +51,6 @@ optimizer
 runs with CFG and life info
 
 used_once ... deletes assignments, when LHS is unused
-loop_optimization ... pulls invariants out of loops
 RT #46279 e.g. constant_propagation
 
 post_optimizer: currently pcc_optimize in pcc.c
@@ -76,23 +75,9 @@ e.g. eliminate new Px .PerlUndef because Px where different before
 
 /* HEADERIZER HFILE: compilers/imcc/optimizer.h */
 
-
-/* buggy - turned off */
-#define  DO_LOOP_OPTIMIZATION 0
-
 /* HEADERIZER BEGIN: static */
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 
-PARROT_WARN_UNUSED_RESULT
-static int _is_ins_save(
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Instruction *check_ins),
-    ARGIN(const SymReg *r),
-    int what)
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3);
-
 static int branch_branch(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
@@ -149,17 +134,6 @@ static int if_branch(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*unit);
 
-PARROT_WARN_UNUSED_RESULT
-static int is_ins_save(PARROT_INTERP,
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Instruction *ins),
-    ARGIN(const SymReg *r),
-    int what)
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3)
-        __attribute__nonnull__(4);
-
 static int strength_reduce(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
@@ -176,55 +150,46 @@ static int used_once(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*unit);
 
+#define ASSERT_ARGS_branch_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_branch_cond_loop __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_branch_cond_loop_swap __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit) \
+    || PARROT_ASSERT_ARG(branch) \
+    || PARROT_ASSERT_ARG(start) \
+    || PARROT_ASSERT_ARG(cond)
+#define ASSERT_ARGS_branch_reorg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_constant_propagation __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_dead_code_remove __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_eval_ins __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(op) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_if_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_strength_reduce __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_unused_label __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_used_once __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
-#if DO_LOOP_OPTIMIZATION
-int loop_optimization(Interp *, IMC_Unit *);
-
-PARROT_WARN_UNUSED_RESULT
-int _is_ins_save(
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Instruction *check_ins),
-    ARGIN(const SymReg *r),
-    int what)
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3);
-
-PARROT_WARN_UNUSED_RESULT
-int is_ins_save(PARROT_INTERP,
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Instruction *ins),
-    ARGIN(const SymReg *r),
-    int what)
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3)
-        __attribute__nonnull__(4);
-
-PARROT_WARN_UNUSED_RESULT
-int max_loop_depth(ARGIN(const IMC_Unit *unit))
-        __attribute__nonnull__(1);
-
-int is_invariant(PARROT_INTERP,
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Instruction *ins))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        __attribute__nonnull__(3);
-
-PARROT_WARN_UNUSED_RESULT
-PARROT_CAN_RETURN_NULL
-Basic_block * find_outer(
-    ARGIN(const IMC_Unit *unit),
-    ARGIN(const Basic_block *blk))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
-
-
-#endif
-
 /*
 
 =item C<int pre_optimize>
@@ -238,6 +203,7 @@ Handles optimizations occuring before the construction of the CFG.
 int
 pre_optimize(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(pre_optimize)
     int changed = 0;
 
     if (IMCC_INFO(interp)->optimizer_level & OPT_PRE) {
@@ -266,6 +232,7 @@ PARROT_WARN_UNUSED_RESULT
 int
 cfg_optimize(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(cfg_optimize)
     if (IMCC_INFO(interp)->dont_optimize)
         return 0;
     if (IMCC_INFO(interp)->optimizer_level & OPT_PRE) {
@@ -298,16 +265,13 @@ RT #48260: Not yet documented!!!
 int
 optimize(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(optimize)
     int any = 0;
     if (IMCC_INFO(interp)->optimizer_level & OPT_CFG) {
         IMCC_info(interp, 2, "optimize\n");
         any = constant_propagation(interp, unit);
         if (used_once(interp, unit))
             return 1;
-#if DO_LOOP_OPTIMIZATION
-        if (loop_optimization(interp, unit))
-            return 1;
-#endif
     }
     return any;
 }
@@ -327,6 +291,7 @@ PARROT_CAN_RETURN_NULL
 const char *
 get_neg_op(ARGIN(const char *op), ARGOUT(int *n))
 {
+    ASSERT_ARGS(get_neg_op)
     static const struct br_pairs {
         const char * const op;
         const char * const nop;
@@ -372,6 +337,7 @@ to the simpler negated form:
 static int
 if_branch(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(if_branch)
     Instruction *ins, *last;
     int reg, changed = 0;
 
@@ -436,6 +402,7 @@ guaranteed that one operand is non constant if opsize == 4
 static int
 strength_reduce(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(strength_reduce)
     Instruction *ins, *tmp;
     SymReg *r;
     int changes = 0;
@@ -680,12 +647,12 @@ even though sometimes it may be safe.
 static int
 constant_propagation(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
-    Instruction *ins, *ins2, *tmp, *prev;
-    int i;
+    ASSERT_ARGS(constant_propagation)
+    Instruction *ins;
     SymReg *c, *o;
     int any = 0;
 
-    o = c = NULL; /* silence compiler uninit warning */
+    o = c = NULL; /* silence compiler uninit warning, but XXX better to handle flow well */
 
     IMCC_info(interp, 2, "\tconstant_propagation\n");
     for (ins = unit->instructions; ins; ins = ins->next) {
@@ -705,9 +672,12 @@ constant_propagation(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
                before it gets to us */
 
         if (found) {
+            Instruction *ins2;
+
             IMCC_debug(interp, DEBUG_OPT2,
                     "propagating constant %I => \n", ins);
             for (ins2 = ins->next; ins2; ins2 = ins2->next) {
+                int i;
                 if (ins2->bbindex != ins->bbindex)
                     /* restrict to within a basic block */
                     goto next_constant;
@@ -718,7 +688,9 @@ constant_propagation(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
                         if (instruction_writes(ins2, ins2->symregs[i]))
                             goto next_constant;
                         else if (instruction_reads(ins2, ins2->symregs[i])) {
+                            Instruction *tmp;
                             SymReg *old;
+
                             IMCC_debug(interp, DEBUG_OPT2,
                                     "\tpropagating into %I register %i",
                                     ins2, i);
@@ -729,7 +701,7 @@ constant_propagation(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
                                 unit, ins2->opname, ins2->symregs, ins2->opsize,
                                 &found);
                             if (found) {
-                                prev = ins2->prev;
+                                const Instruction * const prev = ins2->prev;
                                 if (prev) {
                                     subst_ins(unit, ins2, tmp, 1);
                                     any = 1;
@@ -783,6 +755,7 @@ Instruction *
 IMCC_subst_constants_umix(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *name),
         ARGMOD(SymReg **r), int n)
 {
+    ASSERT_ARGS(IMCC_subst_constants_umix)
     Instruction *tmp;
     const char * const ops[] = {
         "abs", "add", "div", "mul", "sub", "fdiv"
@@ -823,6 +796,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 eval_ins(PARROT_INTERP, ARGIN(const char *op), size_t ops, ARGIN(SymReg **r))
 {
+    ASSERT_ARGS(eval_ins)
     opcode_t eval[4], *pc;
     int opnum;
     int i;
@@ -904,6 +878,7 @@ Instruction *
 IMCC_subst_constants(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *name),
         ARGMOD(SymReg **r), int n, ARGOUT(int *ok))
 {
+    ASSERT_ARGS(IMCC_subst_constants)
     Instruction *tmp;
     const char * const ops[] = {
         "add", "sub", "mul", "div", "fdiv", "pow",
@@ -929,24 +904,20 @@ IMCC_subst_constants(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *na
     };
 
     size_t i;
-    char fmt[64], op[20];
+    const char *fmt;
+    char op[20];
     const char *debug_fmt = NULL;   /* gcc -O uninit warn */
     int found, branched;
 
     /* construct a FLOATVAL_FMT with needed precision */
-    switch (NUMVAL_SIZE) {
-        case 8:
-            strcpy(fmt, "%0.16g");
-            break;
-        case 12:
-            strcpy(fmt, "%0.18Lg");
-            break;
-        default:
-            IMCC_warning(interp, "subs_constants",
-                    "used default FLOATVAL_FMT\n");
-            strcpy(fmt, FLOATVAL_FMT);
-            break;
-    }
+#if NUMVAL_SIZE == 8
+    fmt = "%0.16g";
+#elif NUMVAL_SIZE == 12
+    fmt = "%0.18Lg";
+#else
+    fmt = FLOATVAL_FMT;
+    IMCC_warning(interp, "subs_constants", "used default FLOATVAL_FMT\n");
+#endif
 
     tmp = NULL;
     found = 0;
@@ -1059,8 +1030,9 @@ IMCC_subst_constants(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *na
                 break;
             case 'S':
             {
-                char *name = string_to_cstring(interp, REG_STR(interp, 0));
-                r[1]       = mk_const(interp, name, r[0]->set);
+                char * const name = string_to_cstring(interp, REG_STR(interp, 0));
+
+                r[1] = mk_const(interp, name, r[0]->set);
 
                 snprintf(b, sizeof (b), "%p", REG_STR(interp, 0));
                 string_cstring_free(name);
@@ -1101,6 +1073,7 @@ FALSE.
 static int
 branch_branch(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(branch_branch)
     Instruction *ins;
     int changed = 0;
 
@@ -1161,6 +1134,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 branch_reorg(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(branch_reorg)
     unsigned int i;
     int changed = 0;
 
@@ -1244,6 +1218,7 @@ static int
 branch_cond_loop_swap(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGMOD(Instruction *branch),
         ARGMOD(Instruction *start), ARGMOD(Instruction *cond))
 {
+    ASSERT_ARGS(branch_cond_loop_swap)
     int changed = 0;
     int args;
     const char * const neg_op = get_neg_op(cond->opname, &args);
@@ -1333,6 +1308,7 @@ FALSE.
 static int
 branch_cond_loop(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(branch_cond_loop)
     Instruction *ins, *cond, *start, *prev;
     int changed = 0, found;
 
@@ -1405,6 +1381,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 unused_label(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(unused_label)
     unsigned int i;
     int used;
     int changed = 0;
@@ -1423,14 +1400,14 @@ unused_label(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
                 used = 1;
 #else
             else {
-                Instruction *ins2;
-                SymReg      *addr;
-                int          j;
-
+                int j;
                 for (j=0; unit->bb_list[j]; j++) {
                     /* a branch can be the first ins in a block
                      * (if prev ins was a label)
                      * or the last ins in a block */
+                    Instruction *ins2;
+                    SymReg      *addr;
+
                     ins2 = unit->bb_list[j]->start;
                     if ((ins2->type & ITBRANCH) &&
                             (addr = get_branch_reg(ins2)) != 0) {
@@ -1477,6 +1454,7 @@ RT #48260: Not yet documented!!!
 static int
 dead_code_remove(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(dead_code_remove)
     unsigned int i;
     int changed = 0;
     Instruction *ins, *last;
@@ -1511,9 +1489,13 @@ dead_code_remove(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 
     /* Unreachable instructions */
 
-    for (last = unit->instructions, last && (ins = last->next);
+
+    for (last = unit->instructions, ins = last->next;
          last && ins;
          ins = ins->next) {
+         if (!last && !ins)
+            break;
+
         if ((last->type & IF_goto) && !(ins->type & ITLABEL) &&
             STREQ(last->opname, "branch")) {
             IMCC_debug(interp, DEBUG_OPT1,
@@ -1522,6 +1504,7 @@ dead_code_remove(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
             unit->ostat.deleted_ins++;
             changed++;
         }
+
         /*
          *   branch L1     => --
          * L1: ...            L1:
@@ -1555,6 +1538,7 @@ RT #48260: Not yet documented!!!
 static int
 used_once(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 {
+    ASSERT_ARGS(used_once)
     Instruction *ins;
     int opt = 0;
 
@@ -1580,363 +1564,6 @@ used_once(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
     return opt;
 }
 
-#if DO_LOOP_OPTIMIZATION
-
-static int reason;
-enum check_t { CHK_INV_NEW, CHK_INV_SET, CHK_CLONE };
-
-/*
-
-=item C<static int _is_ins_save>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-PARROT_WARN_UNUSED_RESULT
-static int
-_is_ins_save(ARGIN(const IMC_Unit *unit), ARGIN(const Instruction *check_ins),
-        ARGIN(const SymReg *r), int what)
-{
-    Instruction *ins;
-    int bb;
-    int use_count, lhs_use_count;
-    int i, in_use;
-    int new_bl=-1, set_bl=-1;
-
-    /* now check all instructions where r is used */
-
-    /* we give up fast ;-) */
-    switch (what) {
-        case CHK_INV_NEW:
-        case CHK_INV_SET:
-            if (r->set == 'P' && r->lhs_use_count != 2)
-                return reason=1, 0;
-            if (r->set != 'P' && r->lhs_use_count != 1)
-                return reason=2, 0;
-            break;
-        case CHK_CLONE:
-            if (r->set == 'P' && r->lhs_use_count != 2)
-                return reason=1, 0;
-            break;
-        default:
-            break;
-    }
-
-    use_count = r->use_count;
-    lhs_use_count = r->lhs_use_count;
-    for (bb = 0; bb < unit->n_basic_blocks; bb++) {
-        const Life_range * const lr = r->life_info[bb];
-
-        for (ins = lr->first_ins; ins; ins = ins->next) {
-            int nregs;
-            /* finished with this range */
-            if (!lr->last_ins->next || ins == lr->last_ins->next)
-                break;
-            for (i = in_use = 0; ins->symregs[i]; i++)
-                if (ins->symregs[i] == r) {
-                    in_use++;
-                }
-            nregs = i;
-            if (!in_use)
-                continue;
-
-            /* var is in use in this ins */
-            use_count--;
-            if (instruction_writes(ins, r)) {
-                lhs_use_count--;
-                if (STREQ(ins->opname, "new"))
-                    new_bl=bb;
-                if (STREQ(ins->opname, ""))
-                    set_bl=bb;
-            }
-            /* this is the instruction, to check, it's safe */
-            if (check_ins == ins)
-                continue;
-
-            /* now look for dangerous ops */
-            if (STREQ(ins->opname, "find_global"))
-                return reason=4, 0;
-            if (STREQ(ins->opname, "store_global"))
-                return reason=4, 0;
-            if (STREQ(ins->opname, "push"))
-                return reason=4, 0;
-            if (STREQ(ins->opname, "pop"))
-                return reason=4, 0;
-            if (STREQ(ins->opname, "clone"))
-                return reason=4, 0;
-            /* indexed set/get ??? RT #46289, as index is ok */
-            if (0 && STREQ(ins->opname, "set") && nregs != 2)
-                return reason=5, 0;
-            /*
-             * set P, P  - dangerous?
-             */
-            if (ins->type & ITALIAS)
-                return reason=6, 0;
-            /* we saw all occurencies of reg, so fine */
-            if (lhs_use_count == 0 && use_count == 0) {
-                if (what == CHK_INV_SET && new_bl != set_bl)
-                    return 0;
-                return 1;
-            }
-        }
-        /* we have finished this life range */
-    } /* for bb */
-    return what == CHK_CLONE ? 1 : (reason=10, 0);
-}
-
-/*
-
-=item C<static int is_ins_save>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-PARROT_WARN_UNUSED_RESULT
-static int
-is_ins_save(PARROT_INTERP, ARGIN(const IMC_Unit *unit), ARGIN(const Instruction *ins),
-        ARGIN(const SymReg *r), int what)
-{
-    int save;
-
-    reason = 0;
-    save = _is_ins_save(unit, ins, r, what);
-    if (!save && reason)
-        IMCC_debug(interp, DEBUG_OPT2,
-                   "ins not save var %s reason %d %I\n",
-                r->name, reason, ins);
-    return save;
-}
-
-/*
-
-=item C<int max_loop_depth>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-PARROT_WARN_UNUSED_RESULT
-int
-max_loop_depth(ARGIN(const IMC_Unit *unit))
-{
-    int i;
-    int d = 0;
-
-    for (i = 0; i < unit->n_basic_blocks; i++)
-        if (unit->bb_list[i]->loop_depth > d)
-            d = unit->bb_list[i]->loop_depth;
-    return d;
-}
-
-/*
-
-=item C<int is_invariant>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-int
-is_invariant(PARROT_INTERP, ARGIN(const IMC_Unit *unit), ARGIN(const Instruction *ins))
-{
-    int ok = 0;
-    int what = 0;
-
-    if (STREQ(ins->opname, "new")) {
-        ok = 1;
-        what = CHK_INV_NEW;
-    }
-    /* only, if once assigned and not changed */
-    else if (STREQ(ins->opname, "set") &&
-            !(ins->symregs[0]->usage & U_KEYED) &&
-            ins->symregs[1]->type & VTCONST) {
-        ok = 1;
-        what = CHK_INV_SET;
-    }
-    if (ok)
-        return is_ins_save(interp, unit, ins, ins->symregs[0], what);
-    return 0;
-}
-
-#  define MOVE_INS_1_BL
-#  ifdef MOVE_INS_1_BL
-/*
-
-=item C<Basic_block * find_outer>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-PARROT_WARN_UNUSED_RESULT
-PARROT_CAN_RETURN_NULL
-Basic_block *
-find_outer(ARGIN(const IMC_Unit *unit), ARGIN(const Basic_block *blk))
-{
-    int i;
-    Loop_info ** const loop_info = unit->loop_info;
-    const int          bb        = blk->index;
-    int                i         = unit->n_loops - 1;
-
-    /* loops are sorted depth last */
-    for (; i >= 0; i--) {
-        Loop_info * const info = loop_info[i];
-        if (set_contains(info->loop, bb)) {
-            const int preheader = info->preheader;
-            if (preheader >= 0)
-                return unit->bb_list[preheader];
-        }
-    }
-    return NULL;
-}
-#  endif
-
-/*
-
-=item C<int move_ins_out>
-
-move the instruction ins before loop in bb
-
-=cut
-
-*/
-
-int
-move_ins_out(PARROT_INTERP, ARGMOD(IMC_Unit *unit),
-        ARGMOD(Instruction **ins), ARGIN(const Basic_block *bb))
-{
-    Basic_block *pred;
-    Instruction * next, *out;
-
-    /* check loop_info, where this loop started
-     * actually, this moves instruction to block 0 */
-#  ifdef MOVE_INS_1_BL
-    pred = find_outer(unit, bb);
-#  else
-    UNUSED(bb);
-    pred = unit->bb_list[0];
-#  endif
-    if (!pred) {
-        IMCC_debug(interp, DEBUG_OPT2, "outer loop not found (CFG?)\n");
-        return 0;
-    }
-    out = pred->end;
-    next = (*ins)->next;
-    (*ins)->bbindex = pred->index;
-    IMCC_debug(interp, DEBUG_OPT2, "inserting it in blk %d after %I\n",
-            pred->index, out);
-    *ins = move_ins(unit, *ins, out);
-    if (0 && (DEBUG_OPT2 & IMCC_INFO(interp)->debug)) {
-        char buf[256];
-        SymReg * regs[IMCC_MAX_REGS];
-        Instruction * tmp;
-
-        regs[0] = 0;
-        snprintf(buf, sizeof (buf), "# Invar moved: %s", out->next->op);
-        tmp = INS(interp, unit, "", buf, regs, 0, 0, 0);
-        insert_ins(unit, (*ins)->prev, tmp);
-    }
-    ostat.invariants_moved++;
-    /* RT #46291 CFG is changed here, which also means
-     * that the life_info is wrong now
-     * so, currently we calc CFG and life again */
-    return 1;
-}
-
-/*
-
-=item C<int loop_one>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-int
-loop_one(PARROT_INTERP, ARGMOD(IMC_Unit *unit), int bnr)
-{
-    Basic_block * const bb = unit->bb_list[bnr];
-    Instruction *ins;
-    int changed = 0;
-
-    if (bnr == 0) {
-        IMCC_warning(interp, "loop_one", "wrong loop depth in block 0\n");
-        return 0;
-    }
-    IMCC_debug(interp, DEBUG_OPT2, "loop_one blk %d\n", bnr);
-    for (ins = bb->start ; ins ; ins = ins->next) {
-        reason = 0;
-        if (is_invariant(interp, unit, ins)) {
-            IMCC_debug(interp, DEBUG_OPT2, "found invariant %I\n", ins);
-            if (move_ins_out(interp, unit, &ins, bb)) {
-                changed++;
-                ins = ins->prev;
-            }
-        }
-        if (ins == bb->end)
-            break;
-    }
-    return changed;
-
-}
-
-/*
-
-=item C<int loop_optimization>
-
-RT #48260: Not yet documented!!!
-
-=cut
-
-*/
-
-int
-loop_optimization(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
-{
-    int l;
-    int changed = 0;
-    static int prev_depth;
-
-    const int loop_depth = prev_depth ? prev_depth : max_loop_depth(unit);
-
-    /* work from inside out */
-    IMCC_debug(interp, DEBUG_OPT2, "loop_optimization\n");
-    for (l = loop_depth; l > 0; l--) {
-        int bb;
-
-        IMCC_debug(interp, DEBUG_OPT2, "loop_depth %d\n", l);
-        for (bb = 0; bb < unit->n_basic_blocks; bb++)
-            if (unit->bb_list[bb]->loop_depth == l) {
-                changed |= loop_one(interp, unit, bb);
-            }
-        /* currently e.g. mandel.p6 breaks, if not only the most
-         * inner loop is changed, but outer loops too */
-        if (changed) {
-            prev_depth = l-1;
-            IMCC_debug(interp, DEBUG_OPT2, "after loop_opt\n");
-            if (IMCC_INFO(interp)->debug>1)
-                dump_instructions(interp, unit);
-            return changed;
-        }
-    }
-    prev_depth = 0;
-    return 0;
-}
-#endif
-
 /*
 
 =back
