@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002-2008, The Perl Foundation.
- * $Id: /mirror/trunk/compilers/imcc/pbc.c 33837 2008-12-11T20:01:13.222810Z tewk  $
+ * $Id: /mirror/trunk/compilers/imcc/pbc.c 35819 2009-01-20T05:19:27.074079Z chromatic  $
  */
 
 #include "imc.h"
@@ -126,6 +126,18 @@ static PMC* find_outer(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
+PARROT_WARN_UNUSED_RESULT
+PARROT_CAN_RETURN_NULL
+static subs_t * find_sub_by_subid(PARROT_INTERP,
+    ARGIN(const char *lookup),
+    ARGIN(const subs_t *sym),
+    ARGOUT(int *pc))
+        __attribute__nonnull__(1)
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3)
+        __attribute__nonnull__(4)
+        FUNC_MODIFIES(*pc);
+
 static void fixup_globals(PARROT_INTERP)
         __attribute__nonnull__(1);
 
@@ -194,6 +206,87 @@ static void verify_signature(PARROT_INTERP,
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_add_1_const __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_add_const_key __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(key) \
+    || PARROT_ASSERT_ARG(s_key)
+#define ASSERT_ARGS_add_const_num __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_add_const_pmc_sub __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_add_const_str __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_add_const_table __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_add_const_table_key __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(key)
+#define ASSERT_ARGS_add_const_table_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc)
+#define ASSERT_ARGS_build_key __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(key_reg)
+#define ASSERT_ARGS_constant_folding __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_create_lexinfo __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit) \
+    || PARROT_ASSERT_ARG(sub)
+#define ASSERT_ARGS_find_global_label __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(name) \
+    || PARROT_ASSERT_ARG(sym) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_find_outer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_find_sub_by_subid __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(lookup) \
+    || PARROT_ASSERT_ARG(sym) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_fixup_globals __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_get_codesize __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit) \
+    || PARROT_ASSERT_ARG(src_lines)
+#define ASSERT_ARGS_get_old_size __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(ins_line)
+#define ASSERT_ARGS_imcc_globals_destroy __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_make_new_sub __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(unit)
+#define ASSERT_ARGS_make_pmc_const __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_mk_multi_sig __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_old_blocks __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_slice_deb __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_store_fixup __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(r)
+#define ASSERT_ARGS_store_key_const __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(str)
+#define ASSERT_ARGS_store_sub_size __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_verify_signature __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(ins) \
+    || PARROT_ASSERT_ARG(pc)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -218,6 +311,7 @@ Frees memory allocated for IMCC globals for one particular compilation unit.
 static void
 imcc_globals_destroy(PARROT_INTERP, SHIM(int ex), SHIM(void *param))
 {
+    ASSERT_ARGS(imcc_globals_destroy)
     code_segment_t *cs = IMCC_INFO(interp)->globals->cs;
 
     while (cs) {
@@ -253,6 +347,7 @@ Adds an empty item to constant table, returning its position.
 static int
 add_const_table(PARROT_INTERP)
 {
+    ASSERT_ARGS(add_const_table)
     const size_t oldcount = interp->code->const_table->const_count;
     const size_t newcount = oldcount + 1;
 
@@ -288,6 +383,7 @@ Adds a PMC to the const table, returning its position.
 static int
 add_const_table_pmc(PARROT_INTERP, ARGIN(PMC *pmc))
 {
+    ASSERT_ARGS(add_const_table_pmc)
     int newitem = add_const_table(interp);
 
     interp->code->const_table->constants[newitem]->type  = PFC_PMC;
@@ -310,6 +406,7 @@ Adds a key to the const table, returning its position.
 static int
 add_const_table_key(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(add_const_table_key)
     int newitem = add_const_table(interp);
 
     interp->code->const_table->constants[newitem]->type  = PFC_KEY;
@@ -332,6 +429,7 @@ Opens a compilation unit to emit PBC.
 int
 e_pbc_open(PARROT_INTERP, SHIM(void *param))
 {
+    ASSERT_ARGS(e_pbc_open)
     code_segment_t *cs = mem_allocate_zeroed_typed(code_segment_t);
 
     if (!IMCC_INFO(interp)->globals)
@@ -398,6 +496,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 old_blocks(PARROT_INTERP)
 {
+    ASSERT_ARGS(old_blocks)
     const  subs_t *s;
     size_t         size = 0;
 
@@ -424,6 +523,7 @@ PARROT_CANNOT_RETURN_NULL
 opcode_t *
 make_jit_info(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(make_jit_info)
     const size_t old  = old_blocks(interp);
     const size_t size = unit->n_basic_blocks + old;
 
@@ -471,6 +571,7 @@ Allocates a new globals->cs->subs structure.
 static void
 make_new_sub(PARROT_INTERP, ARGIN(IMC_Unit *unit))
 {
+    ASSERT_ARGS(make_new_sub)
     subs_t * const s = mem_allocate_zeroed_typed(subs_t);
 
     s->prev          = IMCC_INFO(interp)->globals->cs->subs;
@@ -503,6 +604,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 get_old_size(PARROT_INTERP, ARGOUT(int *ins_line))
 {
+    ASSERT_ARGS(get_old_size)
     size_t size = 0;
 
     *ins_line   = 0;
@@ -532,6 +634,7 @@ Sets the given size and line parameters for the current compilation unit.
 static void
 store_sub_size(PARROT_INTERP, size_t size, size_t ins_line)
 {
+    ASSERT_ARGS(store_sub_size)
     IMCC_INFO(interp)->globals->cs->subs->size     = size;
     IMCC_INFO(interp)->globals->cs->subs->ins_line = ins_line;
 }
@@ -550,6 +653,7 @@ Stores fixup information for the given register, program counter, and offset.
 static void
 store_fixup(PARROT_INTERP, ARGIN(const SymReg *r), int pc, int offset)
 {
+    ASSERT_ARGS(store_fixup)
     SymReg * const fixup = _mk_address(interp,
             &IMCC_INFO(interp)->globals->cs->subs->fixup, r->name, U_add_all);
 
@@ -581,6 +685,7 @@ Stores a constant key for the current compilation unit.
 static void
 store_key_const(PARROT_INTERP, ARGIN(const char *str), int idx)
 {
+    ASSERT_ARGS(store_key_const)
     SymReg * const c =
         _mk_const(&IMCC_INFO(interp)->globals->cs->key_consts, str, 0);
     c->color = idx;
@@ -600,6 +705,7 @@ PARROT_WARN_UNUSED_RESULT
 static size_t
 get_codesize(PARROT_INTERP, ARGIN(const IMC_Unit *unit), ARGOUT(size_t *src_lines))
 {
+    ASSERT_ARGS(get_codesize)
     Instruction *ins = unit->instructions;
     size_t       code_size;
 
@@ -617,7 +723,12 @@ get_codesize(PARROT_INTERP, ARGIN(const IMC_Unit *unit), ARGOUT(size_t *src_line
         if (ins->type & ITLABEL)
             ins->symregs[0]->color = code_size;
 
-        if (ins->opname && *ins->opname) {
+        if (ins->opname && STREQ(ins->opname, ".annotate")) {
+            /* Annotations contribute nothing to code size, since they do not
+             * end up in bytecode segment. */
+            (*src_lines)++;
+        }
+        else if (ins->opname && *ins->opname) {
             (*src_lines)++;
             if (ins->opnum < 0)
                 IMCC_fatal(interp, 1, "get_codesize: "
@@ -661,6 +772,7 @@ static subs_t *
 find_global_label(PARROT_INTERP, ARGIN(const char *name),
     ARGIN(const subs_t *sym), ARGOUT(int *pc))
 {
+    ASSERT_ARGS(find_global_label)
     subs_t *s;
 
     *pc = 0;
@@ -686,7 +798,9 @@ static subs_t *
 find_sub_by_subid(PARROT_INTERP, ARGIN(const char *lookup),
     ARGIN(const subs_t *sym), ARGOUT(int *pc))
 {
+    ASSERT_ARGS(find_sub_by_subid)
     subs_t *s;
+    UNUSED(sym);
 
     *pc = 0;
 
@@ -697,13 +811,6 @@ find_sub_by_subid(PARROT_INTERP, ARGIN(const char *lookup),
         if (r && (r->subid && (strcmp(r->subid, lookup) == 0)))
             return s;
 
-        /* if names and namespaces are matching - ok */
-        if (r && r->name && (strcmp(r->name, lookup) == 0)
-                && ((sym->unit->_namespace && s->unit->_namespace
-                        && (strcmp(sym->unit->_namespace->name, s->unit->_namespace->name) == 0))
-                    || (!sym->unit->_namespace && !s->unit->_namespace)))
-            return s;
-
         *pc += s->size;
     }
     return NULL;
@@ -722,6 +829,7 @@ Fixes global information -- particularly locations of global symbols.
 static void
 fixup_globals(PARROT_INTERP)
 {
+    ASSERT_ARGS(fixup_globals)
     subs_t *s;
     int     jumppc = 0;
 
@@ -832,6 +940,7 @@ PARROT_CANNOT_RETURN_NULL
 STRING *
 IMCC_string_from_reg(PARROT_INTERP, ARGIN(const SymReg *r))
 {
+    ASSERT_ARGS(IMCC_string_from_reg)
     const char *buf = r->name;
 
     if (r->type & VT_ENCODED) {
@@ -874,6 +983,7 @@ PARROT_CANNOT_RETURN_NULL
 STRING *
 IMCC_string_from__STRINGC(PARROT_INTERP, ARGIN(const char *buf))
 {
+    ASSERT_ARGS(IMCC_string_from__STRINGC)
     const int ascii = (*buf == '\'' || *buf == '"');
     if (!ascii) {
         /*
@@ -924,6 +1034,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 add_const_str(PARROT_INTERP, ARGIN(const SymReg *r))
 {
+    ASSERT_ARGS(add_const_str)
     const int      k = add_const_table(interp);
     STRING * const s = IMCC_string_from_reg(interp, r);
 
@@ -948,6 +1059,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 add_const_num(PARROT_INTERP, ARGIN_NULLOK(const char *buf))
 {
+    ASSERT_ARGS(add_const_num)
     const int      k = add_const_table(interp);
     STRING * const s = string_from_cstring(interp, buf, 0);
 
@@ -973,27 +1085,20 @@ PARROT_MALLOC
 static PMC*
 mk_multi_sig(PARROT_INTERP, ARGIN(const SymReg *r))
 {
-    PMC       * const multi_sig = pmc_new(interp, enum_class_FixedPMCArray);
-    pcc_sub_t * const pcc_sub   = r->pcc_sub;
-    const INTVAL      n         = pcc_sub->nmulti;
-    INTVAL            i;
-
+    ASSERT_ARGS(mk_multi_sig)
     PackFile_ConstTable *ct;
+    PMC                 *multi_sig;
+    pcc_sub_t * const    pcc_sub = r->pcc_sub;
+    const INTVAL         n       = pcc_sub->nmulti;
+    INTVAL               i;
 
+    /* a :multi sub with no arguments */
+    if (!pcc_sub->multi[0])
+        return pmc_new(interp, enum_class_FixedIntegerArray);
+
+    multi_sig = pmc_new(interp, enum_class_FixedPMCArray);
     VTABLE_set_integer_native(interp, multi_sig, n);
-
-    /* :multi() n = 1, reg = NULL */
-    if (!pcc_sub->multi[0]) {
-        STRING * const sig     = string_from_literal(interp, "__VOID");
-        PMC    * const sig_pmc = pmc_new(interp, enum_class_String);
-
-        VTABLE_set_string_native(interp, sig_pmc, sig);
-        VTABLE_set_pmc_keyed_int(interp, multi_sig, 0, sig_pmc);
-
-        return multi_sig;
-    }
-
-    ct = interp->code->const_table;
+    ct        = interp->code->const_table;
 
     for (i = 0; i < n; ++i) {
         /* multi[i] can be a Key too -
@@ -1002,9 +1107,17 @@ mk_multi_sig(PARROT_INTERP, ARGIN(const SymReg *r))
         r = pcc_sub->multi[i];
 
         if (r->set == 'S') {
-            sig_pmc = pmc_new(interp, enum_class_String);
-            VTABLE_set_string_native(interp, sig_pmc,
-                    ct->constants[r->color]->u.string);
+            STRING *type_name = ct->constants[r->color]->u.string;
+            INTVAL  type_num  = pmc_type(interp, type_name);
+
+            if (type_num == enum_type_undef) {
+                sig_pmc = pmc_new(interp, enum_class_String);
+                VTABLE_set_string_native(interp, sig_pmc, type_name);
+            }
+            else {
+                sig_pmc = pmc_new(interp, enum_class_Integer);
+                VTABLE_set_integer_native(interp, sig_pmc, type_num);
+            }
         }
         else {
             PARROT_ASSERT(r->set == 'K');
@@ -1037,6 +1150,7 @@ static PMC*
 create_lexinfo(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(PMC *sub),
                int need_lex)
 {
+    ASSERT_ARGS(create_lexinfo)
     PMC                *lex_info    = NULL;
     SymHash            *hsh         = &unit->hash;
     PackFile_Constant **constants   = interp->code->const_table->constants;
@@ -1106,6 +1220,7 @@ PARROT_CAN_RETURN_NULL
 static PMC*
 find_outer(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(find_outer)
     subs_t *s;
     PMC    *current;
     STRING *cur_name;
@@ -1169,6 +1284,7 @@ end positions.
 static int
 add_const_pmc_sub(PARROT_INTERP, ARGMOD(SymReg *r), size_t offs, size_t end)
 {
+    ASSERT_ARGS(add_const_pmc_sub)
     PMC                 *ns_pmc;
     PMC                 *sub_pmc;
     Parrot_sub          *sub;
@@ -1390,6 +1506,7 @@ Adds a constant key to constant_table.
 static int
 add_const_key(PARROT_INTERP, ARGIN(const opcode_t *key), int size, ARGIN(const char *s_key))
 {
+    ASSERT_ARGS(add_const_key)
     const SymReg * const r =
         _get_sym(&IMCC_INFO(interp)->globals->cs->key_consts, s_key);
     const opcode_t      *rc;
@@ -1441,6 +1558,7 @@ PARROT_CANNOT_RETURN_NULL
 static const char *
 slice_deb(int bits)
 {
+    ASSERT_ARGS(slice_deb)
     if ((bits & VT_SLICE_BITS) == (VT_START_SLICE|VT_END_SLICE))
         return "start+end";
 
@@ -1477,6 +1595,7 @@ the key, which gets cached in the globals.keys.
 static opcode_t
 build_key(PARROT_INTERP, ARGIN(SymReg *key_reg))
 {
+    ASSERT_ARGS(build_key)
 #define KEYLEN 21
     SymReg   *reg;
 
@@ -1604,6 +1723,7 @@ Creates and returns an INTEGER given an integer-like SymReg.
 INTVAL
 IMCC_int_from_reg(PARROT_INTERP, ARGIN(const SymReg *r))
 {
+    ASSERT_ARGS(IMCC_int_from_reg)
     INTVAL i;
 
     errno = 0;
@@ -1648,6 +1768,7 @@ Creates a constant PMC, given a SymReg.
 static void
 make_pmc_const(PARROT_INTERP, ARGMOD(SymReg *r))
 {
+    ASSERT_ARGS(make_pmc_const)
     PMC    *_class = interp->vtables[r->pmc_type]->pmc_class;
     STRING *s;
     PMC    *p;
@@ -1661,7 +1782,7 @@ make_pmc_const(PARROT_INTERP, ARGMOD(SymReg *r))
     else
         s = string_unescape_cstring(interp, r->name, 0, NULL);
 
-    p       = VTABLE_new_from_string(interp, _class, s, PObj_constant_FLAG);
+    p = VTABLE_instantiate_str(interp, _class, s, PObj_constant_FLAG);
 
     /* append PMC constant */
     r->color = add_const_table_pmc(interp, p);
@@ -1681,6 +1802,7 @@ Adds a constant SymReg to the constant table, depending on its type.
 static void
 add_1_const(PARROT_INTERP, ARGMOD(SymReg *r))
 {
+    ASSERT_ARGS(add_1_const)
     if (r->color >= 0)
         return;
 
@@ -1737,6 +1859,7 @@ Stores a constant's idx for later reuse.
 static void
 constant_folding(PARROT_INTERP, ARGIN(const IMC_Unit *unit))
 {
+    ASSERT_ARGS(constant_folding)
     const SymHash *hsh = &IMCC_INFO(interp)->ghash;
     unsigned int   i;
 
@@ -1795,6 +1918,7 @@ has any instructions.
 int
 e_pbc_new_sub(PARROT_INTERP, SHIM(void *param), ARGIN(IMC_Unit *unit))
 {
+    ASSERT_ARGS(e_pbc_new_sub)
     if (!unit->instructions)
         return 0;
 
@@ -1817,6 +1941,7 @@ Finishes the PBC emitting of a given compilation unit.
 int
 e_pbc_end_sub(PARROT_INTERP, SHIM(void *param), ARGIN(IMC_Unit *unit))
 {
+    ASSERT_ARGS(e_pbc_end_sub)
     Instruction *ins;
     int          pragma;
 
@@ -1872,6 +1997,7 @@ argument types and constants, if missing.
 static void
 verify_signature(PARROT_INTERP, ARGIN(const Instruction *ins), ARGIN(opcode_t *pc))
 {
+    ASSERT_ARGS(verify_signature)
     PMC    *changed_sig    = NULL;
     PMC    * const sig_arr = interp->code->const_table->constants[pc[-1]]->u.key;
     int     needed         = 0;
@@ -1949,6 +2075,7 @@ int
 e_pbc_emit(PARROT_INTERP, SHIM(void *param), ARGIN(const IMC_Unit *unit),
         ARGIN(const Instruction *ins))
 {
+    ASSERT_ARGS(e_pbc_emit)
     op_info_t *op_info;
     int        ok = 0;
     int        op, i;
@@ -2001,8 +2128,7 @@ e_pbc_emit(PARROT_INTERP, SHIM(void *param), ARGIN(const IMC_Unit *unit),
                 (size_t)IMCC_INFO(interp)->ins_line + ins_size + 1);
 
             Parrot_debug_add_mapping(interp, IMCC_INFO(interp)->debug_seg,
-                IMCC_INFO(interp)->ins_line,
-                PF_DEBUGMAPPINGTYPE_FILENAME, sourcefile, 0);
+                IMCC_INFO(interp)->ins_line, sourcefile);
         }
         else
             IMCC_INFO(interp)->debug_seg = NULL;
@@ -2036,7 +2162,46 @@ e_pbc_emit(PARROT_INTERP, SHIM(void *param), ARGIN(const IMC_Unit *unit),
             IMCC_INFO(interp)->npc);
     }
 
-    if (ins->opname && *ins->opname) {
+    if (ins->opname && strcmp(ins->opname, ".annotate") == 0) {
+        /* It's an annotation. */
+        int annotation_type;
+
+        /* Add annotations seg if we're missing one. */
+        if (!interp->code->annotations) {
+            /* Create segment. */
+            char * const name = (char *) mem_sys_allocate(strlen(interp->code->base.name) + 5);
+            strcpy(name, interp->code->base.name);
+            strcat(name, "_ANN");
+            interp->code->annotations = (PackFile_Annotations *)
+                    PackFile_Segment_new_seg(interp, interp->code->base.dir,
+                        PF_ANNOTATIONS_SEG, name, 1);
+            interp->code->annotations->code = interp->code;
+
+            /* Create initial group. */
+            PackFile_Annotations_add_group(interp, interp->code->annotations,
+                    IMCC_INFO(interp)->pc - interp->code->base.data);
+        }
+
+        /* Add annotation. */
+        switch (ins->symregs[1]->set) {
+            case 'I':
+                annotation_type = PF_ANNOTATION_KEY_TYPE_INT;
+                break;
+            case 'N':
+                annotation_type = PF_ANNOTATION_KEY_TYPE_NUM;
+                break;
+            case 'S':
+                annotation_type = PF_ANNOTATION_KEY_TYPE_STR;
+                break;
+            default:
+                IMCC_fatal(interp, 1, "e_pbc_emit:"
+                        "invalid type for annotation value\n");
+        }
+        PackFile_Annotations_add_entry(interp, interp->code->annotations,
+                    IMCC_INFO(interp)->pc - interp->code->base.data,
+                    ins->symregs[0]->color, annotation_type, ins->symregs[1]->color);
+    }
+    else if (ins->opname && *ins->opname) {
         SymReg  *addr, *r;
         opcode_t last_label = 1;
 
@@ -2180,6 +2345,7 @@ Closes this PMC unit.
 int
 e_pbc_close(PARROT_INTERP, SHIM(void *param))
 {
+    ASSERT_ARGS(e_pbc_close)
     fixup_globals(interp);
 
     return 0;
