@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2005, The Perl Foundation.
-# $Id: /mirror/trunk/config/auto/alignptrs.pm 30398 2008-08-20T02:21:59.881769Z jkeenan  $
+# $Id: /mirror/trunk/config/auto/alignptrs.pm 33351 2008-11-28T22:41:42.455437Z coke  $
 
 =head1 NAME
 
@@ -31,11 +31,6 @@ sub _init {
 sub runstep {
     my ( $self, $conf ) = ( shift, shift );
 
-    if ( $conf->options->get('miniparrot') ) {
-        $self->set_result('skipped');
-        return 1;
-    }
-
     my $result_str = '';
     my $align;
     if ( defined( $conf->data->get('ptr_alignment') ) ) {
