@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2007, The Perl Foundation.
-# $Id: /mirror/trunk/config/auto/arch.pm 30398 2008-08-20T02:21:59.881769Z jkeenan  $
+# $Id: /mirror/trunk/config/auto/arch.pm 33351 2008-11-28T22:41:42.455437Z coke  $
 
 =head1 NAME
 
@@ -32,11 +32,6 @@ sub _init {
 sub runstep {
     my ( $self, $conf ) = @_;
 
-    if ( $conf->options->get('miniparrot') ) {
-        $self->set_result('skipped');
-        return 1;
-    }
-
     my $verbose = $conf->options->get('verbose');
     $verbose and print "\n";
 
