@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2003, The Perl Foundation.
-# $Id: /mirror/trunk/config/auto/headers.pm 30398 2008-08-20T02:21:59.881769Z jkeenan  $
+# $Id: /mirror/trunk/config/auto/headers.pm 33351 2008-11-28T22:41:42.455437Z coke  $
 
 =head1 NAME
 
@@ -30,11 +30,6 @@ sub _init {
 sub runstep {
     my ( $self, $conf ) = @_;
 
-    if ( $conf->options->get('miniparrot') ) {
-        $self->set_result('skipped');
-        return 1;
-    }
-
     _set_from_Config($conf);
 
     my @extra_headers = _list_extra_headers($conf);
