@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2008, The Perl Foundation.
-# $Id: /mirror/trunk/config/auto/jit.pm 33351 2008-11-28T22:41:42.455437Z coke  $
+# $Id: /mirror/trunk/config/auto/jit.pm 34160 2008-12-20T03:52:52.625884Z Whiteknight  $
 
 =head1 NAME
 
@@ -103,7 +103,7 @@ sub runstep {
         jitcapable  => 1,
         cc_hasjit   => " -DHAS_JIT -D\U$jitcpuarch",
         TEMP_jit_o =>
-'$(SRC_DIR)/jit$(O) $(SRC_DIR)/jit_cpu$(O) $(SRC_DIR)/jit_debug$(O) $(SRC_DIR)/jit_debug_xcoff$(O)'
+'$(SRC_DIR)/jit$(O) $(SRC_DIR)/jit_cpu$(O) $(SRC_DIR)/jit_debug$(O) $(SRC_DIR)/jit_debug_xcoff$(O) $(SRC_DIR)/jit_defs$(O)'
     );
 
     my $execcapable = $self->_first_probe_for_exec(
