@@ -1,5 +1,5 @@
 # Copyright (C) 2007-2008, The Perl Foundation.
-# $Id: /mirror/trunk/config/auto/warnings.pm 32874 2008-11-19T00:41:26.683427Z chromatic  $
+# $Id: /mirror/trunk/config/auto/warnings.pm 35548 2009-01-14T05:55:09.923853Z petdance  $
 
 =head1 NAME
 
@@ -39,6 +39,7 @@ sub _init {
     my @potential_warnings = qw(
         -falign-functions=16
         -fvisibility=hidden
+        -funit-at-a-time
         -maccumulate-outgoing-args
         -W
         -Wall
@@ -102,37 +103,40 @@ sub _init {
 
     my @cage_warnings = qw(
         -std=c89
-        -Wconversion
         -Werror-implicit-function-declaration
         -Wformat=2
         -Wlarger-than-4096
         -Wlong-long
         -Wmissing-format-attribute
-        -Wmissing-noreturn
-        -Wno-deprecated-declarations
-        -Wno-div-by-zero
+        -Wdeprecated-declarations
+        -Wdiv-by-zero
         -Wno-format-extra-args
         -Wno-import
         -Wno-multichar
         -Wno-pointer-sign
         -Wold-style-definition
-        -Wpadded
-        -Wredundant-decls
-        -Wswitch-enum
-        -Wsystem-headers
         -Wunreachable-code
         -Wunused-function
         -Wunused-label
-        -Wunused-parameter
         -Wunused-value
         -Wunused-variable
     );
 
+    my @may_not_even_be_interesting = qw(
+        -Wpadded
+        -Wredundant-decls
+        -Wswitch-enum
+        -Wsystem-headers
+    );
+
     my @nice_to_have_but_too_noisy_for_now = qw(
         -pedantic
+        -Wconversion
         -Wint-to-pointer-cast
+        -Wmissing-noreturn
         -Wshadow
         -Wunused-macros
+        -Wunused-parameter
     );
 
     $data{potential_warnings}        = \@potential_warnings;
