@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2008, The Perl Foundation.
-# $Id: /mirror/trunk/config/gen/makefiles.pm 32363 2008-11-04T16:07:47.360677Z particle  $
+# $Id: /mirror/trunk/config/gen/makefiles.pm 34058 2008-12-17T15:05:09.138525Z Whiteknight  $
 
 =head1 NAME
 
@@ -46,8 +46,6 @@ sub _init {
             { SOURCE => 'config/gen/makefiles/pge.in' },
         'compilers/tge/Makefile'     =>
             { SOURCE => 'config/gen/makefiles/tge.in' },
-        'compilers/bcg/Makefile'     =>
-            { SOURCE => 'config/gen/makefiles/bcg.in' },
         'compilers/json/Makefile'    =>
             { SOURCE => 'config/gen/makefiles/json.in' },
         'compilers/pirc/Makefile'    =>
