@@ -1,5 +1,5 @@
 /*
- * $Id: dl.c 23553 2007-12-06 20:29:20Z paultcochrane $
+ * $Id: /mirror/trunk/config/gen/platform/darwin/dl.c 32779 2008-11-17T04:08:05.193702Z chromatic  $
  * Copyright (C) 2004-2006, The Perl Foundation.
  */
 
@@ -263,19 +263,16 @@ int
 Parrot_dlclose(void *handle)
 {
     if (handle && !(((struct mach_header *)handle)->magic == MH_MAGIC
-                     || ((struct mach_header *)handle)->magic == MH_CIGAM))
-    {
+               ||   ((struct mach_header *)handle)->magic == MH_CIGAM)) {
         unsigned long options = NSUNLINKMODULE_OPTION_NONE;
 #ifdef __ppc__
         options = NSUNLINKMODULE_OPTION_RESET_LAZY_REFERENCES;
 #endif
 
-        return (int)NSUnLinkModule(handle, options);
+        return NSUnLinkModule(handle, options) ? 1 : 0;
     }
     else
-    {
         return 0;
-    }
 }
 
 /*
