@@ -1,5 +1,5 @@
 /*
- * $Id: env.c 26113 2008-02-27 21:13:31Z chromatic $
+ * $Id: /mirror/trunk/config/gen/platform/win32/env.c 34233 2008-12-21T14:52:19.081827Z Whiteknight  $
  * Copyright (C) 2004-2008, The Perl Foundation.
  */
 
@@ -54,17 +54,12 @@ Parrot_setenv(const char *name, const char *value)
         const int value_len = strlen(value);
 
         {
-            char * const envstring = malloc(
+            char * const envstring = mem_internal_allocate(
                     name_len     /* name  */
                     + 1          /* '='   */
                     + value_len  /* value */
                     + 1);        /* string terminator */
 
-            if (envstring == NULL) {
-                /* RT#48276: Shouldn't we tell anyone that we failed? */
-                return;
-            }
-
             /* Save a bit of time, by using the fact we already have the
             lengths, avoiding strcat */
             strcpy(envstring, name);
@@ -73,11 +68,13 @@ Parrot_setenv(const char *name, const char *value)
 
             if (_putenv(envstring) == 0) {
                 /* success */
+                mem_sys_free(envstring);
             }
             else {
-                /* RT#48276: Shouldn't we tell anyone that we failed? */
+                mem_sys_free(envstring);
+                exit_fatal(1, "Unable to set environment variable %s=%s",
+                    name, value);
             }
-            free(envstring);
         }
     }
 }
