@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2007, The Perl Foundation.
-# $Id: /mirror/trunk/config/init/hints/mswin32.pm 32410 2008-11-06T14:43:08.522274Z tewk  $
+# $Id: /mirror/trunk/config/init/hints/mswin32.pm 35007 2009-01-05T10:41:01.553141Z rurban  $
 
 package init::hints::mswin32;
 
@@ -100,9 +100,7 @@ sub runstep {
 
         # If we are building shared, need to include dynamic libparrot.lib, otherwise
         # the static libparrot.lib.
-        if ( $conf->data->get('parrot_is_shared') ) {
-            $conf->data->set( libparrot_ldflags   => $conf->data->get('build_dir') . '/libparrot.lib' );
-        }
+        $conf->data->set( libparrot_ldflags   => 'libparrot.lib' );
 
         # 'link' needs to be link.exe, not cl.exe.
         # This makes 'link' and 'ld' the same.
@@ -197,7 +195,6 @@ sub runstep {
             $conf->data->set(
                 a       => '.a',
                 ar      => 'ar',
-                cc      => 'gcc',
                 ccflags => '-DWIN32 ',
                 ld      => 'g++',
                 ldflags => '',
@@ -206,7 +203,6 @@ sub runstep {
                 link      => 'gcc',
                 linkflags => '',
                 o         => '.o',
-                blib_dir  => 'blib\\lib',
             );
         }
         elsif ( $make =~ /dmake/i ) {
@@ -219,6 +215,13 @@ sub runstep {
                 optimize  => '',
             );
         }
+        elsif ( $make =~ /mingw32-make/i ) {
+            ; # Vanilla Perl
+            $conf->data->set(
+                make      => 'mingw32-make',
+                make_c    => 'mingw32-make -C',
+            );
+        }
         else {
             warn "unknown configuration";
         }
@@ -228,17 +231,17 @@ sub runstep {
         }
 
         $conf->data->set(
+            cc                  => 'gcc',
             parrot_is_shared    => 1,
             has_dynamic_linking => 1,
             ld_load_flags       => '-shared ',
             ld_share_flags      => '-shared ',
-            libparrot_ldflags   => $conf->data->get('build_dir') . '/libparrot.dll',
+            libparrot_ldflags   => "\"$build_dir\\libparrot.dll\"",
             ncilib_link_extra   => 'src/libnci_test.def',
             sym_export          => '__declspec(dllexport)',
             sym_import          => '__declspec(dllimport)',
-            make                => 'mingw32-make',
-            make_c              => 'mingw32-make -C',
             slash               => '\\',
+            blib_dir            => 'blib\\lib',
         );
     }
 }
