@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2007, The Perl Foundation.
-# $Id: /mirror/trunk/config/inter/libparrot.pm 30398 2008-08-20T02:21:59.881769Z jkeenan  $
+# $Id: /mirror/trunk/config/inter/libparrot.pm 35882 2009-01-21T03:17:50.686519Z infinoid  $
 
 =head1 NAME
 
@@ -19,6 +19,7 @@ use warnings;
 
 use base qw(Parrot::Configure::Step);
 
+use File::Spec ();
 use Parrot::Configure::Utils ':inter';
 
 
@@ -74,6 +75,8 @@ sub runstep {
         : '$(LIBPARROT_STATIC)',
     );
 
+    # Set -rpath (or equivalent) for executables to find the
+    # shared libparrot in the build directory.
     $conf->data->set(
         rpath_blib => ( $parrot_is_shared && $conf->data->get('rpath') )
         ? $conf->data->get('rpath')
@@ -83,6 +86,15 @@ sub runstep {
         : ''
     );
 
+    # Set -rpath (or equivalent) for the installed executables to find the
+    # installed shared libparrot.
+    $conf->data->set(
+        rpath_lib => ( $parrot_is_shared && $conf->data->get('rpath') )
+        ? $conf->data->get('rpath')
+            . $conf->data->get('libdir')
+        : ''
+    );
+
     unless ( defined( $conf->data->get('libparrot_ldflags') ) ) {
         $conf->data->set(libparrot_ldflags =>
         '-L'
