@@ -1,7 +1,7 @@
 /* embed.h
  *  Copyright (C) 2001-2003, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/include/parrot/embed.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ *     $Id: /mirror/trunk/include/parrot/embed.h 34761 2009-01-01T02:15:46.952534Z infinoid  $
  *  Overview:
  *     This is the Parrot embedding system--the only part of Parrot that
  *     the outside world should see.
@@ -64,7 +64,7 @@ PARROT_EXPORT
 PARROT_DOES_NOT_RETURN
 void Parrot_exit(Parrot_Interp, int status);
 
-PARROT_EXPORT void Parrot_run_native(Parrot_Interp interp, native_func_t func);
+PARROT_EXPORT void Parrot_run_native(PARROT_INTERP, native_func_t func);
 
 /* Parrot_set_config_hash exists in *_config.o (e.g install_config.o),
    so if you make this call then you will need to link with it in
