@@ -1,5 +1,5 @@
 /* enums.h
- * $Id: /mirror/trunk/include/parrot/enums.h 27167 2008-04-24T23:21:37.143866Z pmichaud  $
+ * $Id: /mirror/trunk/include/parrot/enums.h 35403 2009-01-11T02:03:04.018399Z Whiteknight  $
  *  Copyright (C) 2001-2008, The Perl Foundation.
  *  Overview:
  *     enums shared by much of the stack-handling code
@@ -58,7 +58,9 @@ typedef enum {
     /* unused - 0x040 */
     PARROT_ARG_OPTIONAL         = 0x080, /* 128 */
     PARROT_ARG_OPT_FLAG         = 0x100, /* 256 prev optional was set */
-    PARROT_ARG_NAME             = 0x200 /* 512 this String is an arg name */
+    PARROT_ARG_NAME             = 0x200, /* 512 this String is an arg name */
+    PARROT_ARG_LOOKAHEAD        = 0x400, /* 1024 this is a lookahead argument */
+    PARROT_ARG_INVOCANT         = 0x800  /* 2048 this PMC is an invocant */
     /* more to come soon */
 
 } Call_bits_enum_t;
@@ -77,6 +79,7 @@ typedef enum {
 #define PARROT_ARG_OPTIONAL_ISSET(o)      ((o) & PARROT_ARG_OPTIONAL)
 #define PARROT_ARG_OPT_FLAG_ISSET(o)      ((o) & PARROT_ARG_OPT_FLAG)
 #define PARROT_ARG_NAME_ISSET(o)          ((o) & PARROT_ARG_NAME)
+#define PARROT_ARG_INVOCANT_ISSET(o)      ((o) & PARROT_ARG_INVOCANT)
 
 
 #endif /* PARROT_ENUMS_H_GUARD */
