@@ -6,7 +6,7 @@
  * exec.h
  *
  * SVN Info
- *    $Id: /mirror/trunk/include/parrot/exec.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ *    $Id: /mirror/trunk/include/parrot/exec.h 34894 2009-01-03T07:19:03.170336Z infinoid  $
  * Overview:
  *    Exec header file.
  * History:
@@ -149,6 +149,29 @@ int Parrot_exec_add_symbol(
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*obj);
 
+#define ASSERT_ARGS_Parrot_exec_add_text_rellocation \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(obj) \
+    || PARROT_ASSERT_ARG(nptr) \
+    || PARROT_ASSERT_ARG(symbol)
+#define ASSERT_ARGS_Parrot_exec_add_text_rellocation_func \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(obj) \
+    || PARROT_ASSERT_ARG(nptr) \
+    || PARROT_ASSERT_ARG(func_name)
+#define ASSERT_ARGS_Parrot_exec_add_text_rellocation_reg \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(obj) \
+    || PARROT_ASSERT_ARG(nptr) \
+    || PARROT_ASSERT_ARG(var)
+#define ASSERT_ARGS_Parrot_exec __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc) \
+    || PARROT_ASSERT_ARG(code_start) \
+    || PARROT_ASSERT_ARG(code_end)
+#define ASSERT_ARGS_Parrot_exec_add_symbol __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(obj) \
+    || PARROT_ASSERT_ARG(symbol)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/exec.c */
 
