@@ -1,7 +1,7 @@
 /* exit.h
  *  Copyright (C) 2001-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/include/parrot/exit.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ *     $Id: /mirror/trunk/include/parrot/exit.h 34889 2009-01-03T06:36:42.042670Z infinoid  $
  *  Overview:
  *
  *  Data Structure and Algorithms:
@@ -39,6 +39,11 @@ void Parrot_on_exit(PARROT_INTERP,
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
+#define ASSERT_ARGS_Parrot_exit __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_Parrot_on_exit __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(function)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/exit.c */
 
