@@ -1,7 +1,7 @@
 /* global_setup.h
  *  Copyright (C) 2001-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/include/parrot/global_setup.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ *     $Id: /mirror/trunk/include/parrot/global_setup.h 34890 2009-01-03T06:58:47.331194Z infinoid  $
  *  Overview:
  *      Contains declarations of global data and the functions
  *      that initialize that data.
@@ -35,6 +35,15 @@ void init_world_once(PARROT_INTERP)
 void parrot_global_setup_2(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_Parrot_set_config_hash_internal \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(parrot_config)
+#define ASSERT_ARGS_init_world __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_init_world_once __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_parrot_global_setup_2 __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/global_setup.c */
 
