@@ -1,7 +1,7 @@
 /* objects.h
  *  Copyright (C) 2007-2008, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/include/parrot/oo.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ *     $Id: /mirror/trunk/include/parrot/oo.h 35757 2009-01-18T22:19:42.746047Z julianalbo  $
  *  Overview:
  *     Parrot class and object header stuff
  *  Data Structure and Algorithms:
@@ -39,7 +39,6 @@ typedef enum {
         ((PMC **)(x))[(y)] = (z); \
     } while (0)
 #define set_attrib_flags(x) do { \
-        PObj_data_is_PMC_array_SET(x); \
         PObj_active_destroy_SET(x); \
     } while (0)
 #define set_attrib_array_size(o, y) do { \
@@ -57,13 +56,6 @@ typedef enum {
 /* HEADERIZER BEGIN: src/oo.c */
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 
-PARROT_EXPORT
-PARROT_CAN_RETURN_NULL
-PARROT_WARN_UNUSED_RESULT
-PMC * Parrot_class_lookup(PARROT_INTERP, ARGIN(STRING *class_name))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
-
 PARROT_EXPORT
 void Parrot_ComposeRole(PARROT_INTERP,
     ARGIN(PMC *role),
@@ -114,10 +106,8 @@ INTVAL Parrot_get_vtable_index(PARROT_INTERP, ARGIN(const STRING *name))
 
 PARROT_EXPORT
 void Parrot_invalidate_method_cache(PARROT_INTERP,
-    ARGIN_NULLOK(STRING *_class),
-    ARGIN(STRING *meth))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(3);
+    ARGIN_NULLOK(STRING *_class))
+        __attribute__nonnull__(1);
 
 PARROT_EXPORT
 PARROT_PURE_FUNCTION
@@ -157,12 +147,6 @@ void init_object_cache(PARROT_INTERP)
 void mark_object_cache(PARROT_INTERP)
         __attribute__nonnull__(1);
 
-PARROT_CAN_RETURN_NULL
-PARROT_WARN_UNUSED_RESULT
-PMC * Parrot_class_lookup_p(PARROT_INTERP, ARGIN(PMC *class_name))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
-
 void Parrot_oo_extract_methods_from_namespace(PARROT_INTERP,
     ARGIN(PMC *self),
     ARGIN(PMC *ns))
@@ -200,10 +184,78 @@ PMC * Parrot_oo_newclass_from_str(PARROT_INTERP, ARGIN(STRING *name))
         __attribute__nonnull__(2);
 
 PARROT_WARN_UNUSED_RESULT
-INTVAL Parrot_oo_register_type(PARROT_INTERP, ARGIN(PMC *name))
+INTVAL Parrot_oo_register_type(PARROT_INTERP,
+    ARGIN(PMC *name),
+    ARGIN(PMC *_namespace))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_Parrot_ComposeRole __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(role) \
+    || PARROT_ASSERT_ARG(exclude) \
+    || PARROT_ASSERT_ARG(alias) \
+    || PARROT_ASSERT_ARG(methods_hash) \
+    || PARROT_ASSERT_ARG(roles_list)
+#define ASSERT_ARGS_Parrot_ComputeMRO_C3 __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(_class)
+#define ASSERT_ARGS_Parrot_find_method_direct __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(_class) \
+    || PARROT_ASSERT_ARG(method_name)
+#define ASSERT_ARGS_Parrot_find_method_with_cache __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(_class) \
+    || PARROT_ASSERT_ARG(method_name)
+#define ASSERT_ARGS_Parrot_get_vtable_index __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_Parrot_invalidate_method_cache \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_Parrot_MMD_method_name __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_Parrot_oo_get_class __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(key)
+#define ASSERT_ARGS_Parrot_oo_get_class_str __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_Parrot_remove_parent __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(removed_class) \
+    || PARROT_ASSERT_ARG(existing_class)
+#define ASSERT_ARGS_destroy_object_cache __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_init_object_cache __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_mark_object_cache __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_Parrot_oo_extract_methods_from_namespace \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(self) \
+    || PARROT_ASSERT_ARG(ns)
+#define ASSERT_ARGS_Parrot_oo_find_vtable_override \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(classobj) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_Parrot_oo_find_vtable_override_for_class \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(classobj) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_Parrot_oo_get_namespace __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(classobj)
+#define ASSERT_ARGS_Parrot_oo_newclass_from_str __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_Parrot_oo_register_type __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(name) \
+    || PARROT_ASSERT_ARG(_namespace)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/oo.c */
 
