@@ -1,5 +1,5 @@
 /*
- * $Id: /mirror/trunk/include/parrot/warnings.h 32919 2008-11-19T17:21:15.952103Z particle  $
+ * $Id: /mirror/trunk/include/parrot/warnings.h 34889 2009-01-03T06:36:42.042670Z infinoid  $
  * Copyright (C) 2002-2007, The Perl Foundation.
  */
 
@@ -68,6 +68,11 @@ PARROT_EXPORT
 void print_pbc_location(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_Parrot_warn __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(message)
+#define ASSERT_ARGS_print_pbc_location __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/warnings.c */
 
