@@ -1,5 +1,5 @@
 # Copyright (C) 2008, The Perl Foundation.
-# $Id: /mirror/trunk/languages/APL/src/parser/actions.pm 31325 2008-09-21T08:47:14.404592Z tene  $
+# $Id: /mirror/trunk/languages/APL/src/parser/actions.pm 35037 2009-01-05T20:46:44.797206Z tene  $
 
 =begin comments
 
@@ -18,11 +18,13 @@ value of the comment is passed as the second argument to the method.
 class APL::Grammar::Actions;
 
 method TOP($/) {
-    my $catchpir := "    get_results '0', $P0\n    $S0 = $P0\n    print $S0\n    exit 1\n";
-    my $past := PAST::Op.new( $( $<statement_list> ),
+    my $catchpir := "    get_results '0', $P0\n    $S0 = $P0\n    print $S0\n    .return ($P0)\n";
+    my $past := PAST::Block.new(
+                    PAST::Op.new( $( $<statement_list> ),
                               PAST::Op.new( :inline( $catchpir) ),
                               :pasttype('try'),
-                              :node($/) );
+                              :node($/) ),
+                        :hll('apl') );
     make $past;
 }
 
