@@ -1,5 +1,6 @@
-# Copyright (C) 2008, The Perl Foundation.
-# $Id: /mirror/trunk/languages/ecmascript/src/parser/actions.pm 33876 2008-12-13T06:37:40.848222Z tewk  $
+# Copyright (C) 2008-2009, The Perl Foundation.
+# $Id: /mirror/trunk/languages/ecmascript/src/parser/actions.pm 35525 2009-01-13T18:50:42.126072Z bernhard  $
+
 class JS::Grammar::Actions;
 
 method TOP($/, $key) {
@@ -9,6 +10,8 @@ method TOP($/, $key) {
     if $key eq 'open' {
         ## create a 'global' current block and stuff it into the scope stack.
         $?BLOCK := PAST::Block.new( :blocktype('declaration'), :node($/) );
+        $?BLOCK.hll('js');
+
         @?BLOCK.unshift($?BLOCK);
     }
     elsif $key eq 'close' {
@@ -138,7 +141,19 @@ method while_statement($/) {
 ##   <step>
 ## }
 ##
-method for1_statement($/) {
+sub c_style_for($/,$var_decl) {
+
+    ## if there are variable declarations in the init portion of the C-style
+    ## for loop, we have to evaluate it first so that they are available
+    ## during the rest of loop
+    my $init;
+    if $var_decl {
+        $init := $( $<init> );
+    }
+    else {
+        if $<init> { $init := $( $<init>[0] ); }
+    }
+
     my $body := $( $<statement> );
 
     ## if there's a step, create a new compound statement node,
@@ -164,13 +179,14 @@ method for1_statement($/) {
 
     ## if there's an init step, it is evaluated before the loop, so
     ## create a compound statement node ($init, $loop).
-    if $<init> {
-        my $init := $( $<init>[0] );
-        make PAST::Stmts.new( $init, $loop, :node($/) );
-    }
-    else {
-        make $loop;
+    if $init {
+        $loop := PAST::Stmts.new( $init, $loop, :node($/) );
     }
+    make $loop;
+}
+
+method for1_statement($/) {
+    c_style_for($/,0);
 }
 
 method for2_statement($/) {
@@ -190,11 +206,7 @@ method for3_statement($/) {
 }
 
 method for4_statement($/) {
-    # XXX todo
-    my $past;
-    my $body := $( $<statement> );
-    $past := $body;
-    make $past;
+    c_style_for($/,1);
 }
 
 method labelled_statement($/) {
@@ -262,7 +274,7 @@ method return_statement($/) {
     make $past;
 }
 
-method variable_statement($/) {
+method variable_declaration_list($/) {
     ## each variable declared in this statement becomes a separate PIR
     ## statement; therefore create a Stmts node.
     my $past := PAST::Stmts.new( :node($/) );
@@ -272,6 +284,10 @@ method variable_statement($/) {
     make $past;
 }
 
+method variable_statement($/) {
+    make $( $<variable_declaration_list> )
+}
+
 method variable_declaration($/) {
     our $?BLOCK;
 
@@ -617,7 +633,7 @@ method new_expression($/) {
     ## past as argument. This is done 'inside out', so the last 'new' is invoked
     ## first, so to say.
     for $<sym> {
-        $past := PAST::Op.new( $past, :name('new'), :pasttype('call'), :node($/) );
+        $past := PAST::Op.new( $past, :name('new'), :pasttype('callmethod'), :node($/) );
     }
     make $past;
 }
@@ -650,71 +666,102 @@ method builtin_literal($/, $key) {
 
 method true($/) {
     # XXX change this into type a ECMAScript type, 'Boolean' or whatever
-    make PAST::Val.new( :returns('Integer'), :value('1'), :node($/) );
+    make PAST::Var.new( :name(~$/), :namespace('JSBoolean'), :scope('package'), :node($/) );
 }
 
 method false($/) {
     # XXX change this into type 'Boolean' or whatever
-    make PAST::Val.new( :returns('Integer'), :value('0'), :node($/) );
+    make PAST::Var.new( :name(~$/), :namespace('JSBoolean'), :scope('package'), :node($/) );
 }
 
 method null($/) {
     # XXX would this work?
-    make PAST::Var.new( :name('null'), :scope('package'), :node($/) );
+    #make PAST::Var.new( :name('null'), :scope('package'), :node($/) );
+    make PAST::Var.new( :name('null'), :namespace('JSNull'), :scope('package'), :node($/) );
 }
 
 method object_literal($/) {
-    my $past := PAST::Op.new( :pasttype('call'), :node($/) );
-    $past.name('Object');
+    my $past := PAST::Stmts.new( :node($/) );
+
+    my $type := PAST::Var.new( :name('JSObject'), :scope('package'), :node($/) );
+    my $objvar := PAST::Var.new(:scope('register'), :name('obj'));
+    $past.push(
+        PAST::Op.new(:pasttype('bind'),
+          PAST::Var.new(:scope('register'), :name('obj'), :isdecl(1)),
+          PAST::Op.new( :pasttype('callmethod'), :name("new"), :node($/), $type),
+          :node($/)));
+
     for $<property> {
-        $past.push( $($_) );
+      $($_).unshift($objvar);
+      $past.push( $($_) );
     }
+    $past.push($objvar);
     make $past;
 }
 
 method property($/) {
-    ## TODO: a property is a key/value pair. The value must be passed as a parameter
-    ## and passed as a :named parameter using the key as a name.
-    ##
-    ## XXX figure out whether this is the way to go, or to use "setattribute", so use
-    ## parrot's actual object system instead of hashtables.
-    ##
-    ## How to solve this, as property_name can be a value and a variable (but I think this is
-    ## is supposed to be an auto-quoted identifier). Check manual.
-    ## For now: this is broken, but it's a start.
     my $key  := $( $<property_name> );
-
-    ## XXX my $key  := PAST::Val.new( $prop, :returns('String'), :node($/) );
     my $val  := $( $<assignment_expression> );
-
-    $val.named($key);
-    make $val;
+    my $past := PAST::Op.new( :inline('    %0[%1] = %2'), $key, $val, :node($/) );
+    make $past;
 }
 
 
 method property_name($/, $key) {
     ## XXX
     my $propname := $( $/{$key} );
-    my $past := PAST::Op.new( :inline('    $S0 = %0'), :node($/) );
-    $past.push($propname);
-    make $past;
+    #my $past := PAST::Op.new( :inline('    $S0 = %0'), :node($/) );
+    #$past.push($propname);
+    #make $past;
+    make $propname;
 }
 
 method array_literal($/) {
-    ## XXX todo
-    my $past := PAST::Op.new( :pasttype('call'), :name('Array'), :node($/) );
+    my $past := PAST::Stmts.new( :node($/) );
 
+    my $type := PAST::Var.new( :name('Array'), :scope('package'), :node($/) );
+    my $objvar := PAST::Var.new(:scope('register'), :name('obj'));
+    $past.push(
+        PAST::Op.new(:pasttype('bind'),
+          PAST::Var.new(:scope('register'), :name('obj'), :isdecl(1)),
+          PAST::Op.new( :pasttype('callmethod'), :name("new"), :node($/), $type),
+          :node($/)));
+    my $i := 0;
+    for $<assignment_expression> {
+      $past.push(
+          PAST::Op.new( :inline('    %0[%1] = %2'), $objvar, $i, $($_), :node($/) ));
+      $i := $i + 1;
+    }
+    $past.push($objvar);
     make $past;
 }
 
 method element_list($/) {
-    ## XXX todo
+    print("el\n");
+    my $past := PAST::Stmts.new( :node($/) );
+    for $<assignment_expression> {
+      _dumper($_);
+    }
+    for $<elision> {
+      _dumper($_);
+    }
+    #for $/.list() {
+    #  _dumper($_);
+      #for $_.list() {
+      #  $past.push( $($_) );
+      #}
+    #}
+    make $past;
 }
 
 method elision($/) {
-    ## return number of commas.
-    my $value := +$<comma>;
-    make PAST::Val.new( :value($value), :returns('Integer'), :node($/) );
+    my $past := PAST::Stmts.new( :node($/) );
+    my $undef := PAST::Var.new( :name('undef'), :namespace('JSUndefined'), :scope('package'), :node($/) );
+
+    for $<comma> {
+      $past.push(PAST::Op.new( :pasttype('callmethod'), :name('append'), $undef, :node($/) ));
+    }
+    make $past;
 }
 
 method str_literal($/) {
