@@ -5,7 +5,7 @@
 # This program is free software. It is subject to the same license
 # as the Parrot interpreter.
 #
-# $Id: /mirror/trunk/languages/jako/lib/Jako/Construct/Block/Bare.pm 16255 2006-12-25T22:20:28.489385Z paultcochrane  $
+# $Id: /mirror/trunk/languages/jako/lib/Jako/Construct/Block/Bare.pm 33921 2008-12-14T16:44:54.014953Z fperrad  $
 #
 
 use strict;
@@ -30,11 +30,9 @@ sub compile {
     my $namespace = "BARE";    # TODO: Don't we need to do better than this?
 
     if ( $self->content ) {
-        $compiler->emit(".namespace ${namespace}");
         $compiler->indent;
         $self->SUPER::compile($compiler);
         $compiler->outdent;
-        $compiler->emit(".endnamespace ${namespace}");
     }
 
     return 1;
