@@ -1,5 +1,5 @@
 # Copyright (C) 2008, The Perl Foundation.
-# $Id: /mirror/trunk/languages/lolcode/src/parser/actions.pm 29554 2008-07-16T15:41:23.069661Z tene  $
+# $Id: /mirror/trunk/languages/lolcode/src/parser/actions.pm 35037 2009-01-05T20:46:44.797206Z tene  $
 
 =begin comments
 
@@ -22,6 +22,7 @@ method TOP($/) {
     $block.symbol('IT', :scope('lexical'));
     my $it := PAST::Var.new( :name( 'IT' ), :scope('lexical'), :viviself('Undef'), :isdecl(1));
     $block.unshift($it);
+    $block.hll('lolcode');
     make $block;
 }
 
@@ -42,7 +43,6 @@ method statement ($/, $key) {
 
 method declare($/) {
     our $?BLOCK;
-    our @?BLOCK;
 
     my $name := ~$<variable><identifier>;
 
@@ -104,7 +104,6 @@ method function($/,$key) {
         $block.blocktype('declaration');
         $?BLOCK.symbol(~$<variable><identifier>, :arity($block.arity()));
 
-
         my $it := PAST::Var.new( :name( 'IT' ), :scope('lexical'), :viviself('Undef'), :isdecl(1));
         $block[1].unshift($it);
 
@@ -359,7 +358,6 @@ method variable ($/) {
     }
     else {
         our $?BLOCK;
-        our @?BLOCK;
 
         my $var := PAST::Var.new( :name( $<identifier> ),
                             :scope('lexical'),
