@@ -1,6 +1,6 @@
 #! perl
 # Copyright (C) 2005-2008, The Perl Foundation.
-# $Id: luac.pl 26743 2008-04-04 14:35:41Z fperrad $
+# $Id: /mirror/trunk/languages/lua/luac.pl 34462 2008-12-27T17:23:27.572097Z fperrad  $
 
 use strict;
 use warnings;
@@ -82,9 +82,5 @@ Display version.
 
 =head1 DESCRIPTION
 
-=head1 AUTHOR
-
-Francois Perrad
-
 =cut
 
