@@ -1,12 +1,8 @@
 # Copyright (C) 2008, The Perl Foundation.
-# $Id: Luad.pm 27321 2008-05-04 13:45:50Z fperrad $
+# $Id: /mirror/trunk/languages/lua/t/Parrot/Test/Luad.pm 34462 2008-12-27T17:23:27.572097Z fperrad  $
 
 package Parrot::Test::Luad;
 
-use strict;
-
-use File::Basename;
-
 require Parrot::Test;
 
 =head1 NAME
@@ -28,6 +24,8 @@ Yet another constructor.
 use strict;
 use warnings;
 
+use File::Spec;
+
 sub new {
     return bless {};
 }
@@ -50,12 +48,12 @@ foreach my $func ( keys %language_test_map ) {
         my $params = $options{params} || q{};
 
         # flatten filenames (don't use directories)
-        my $lang_fn = Parrot::Test::per_test( '.lua', $count );
-        my $luac_fn  = Parrot::Test::per_test( '.luac', $count );
-        my $lua_out_fn = Parrot::Test::per_test( '.parrot_out', $count );
+        my $lang_fn = File::Spec->rel2abs( Parrot::Test::per_test( '.lua', $count ) );
+        my $luac_fn  = File::Spec->rel2abs( Parrot::Test::per_test( '.luac', $count ) );
+        my $lua_out_fn = File::Spec->rel2abs( Parrot::Test::per_test( '.parrot_out', $count ) );
         my @test_prog = (
-            "luac -o languages/${luac_fn} languages/${lang_fn}",
-            "$self->{parrot} languages/lua/luad.pir languages/${luac_fn}",
+            "luac -o ${luac_fn} ${lang_fn}",
+            "$self->{parrot} languages/lua/luad.pir ${luac_fn}",
         );
 
         # This does not create byte code, but lua code
@@ -94,10 +92,6 @@ foreach my $func ( keys %language_test_map ) {
 
 F<languages/lua/t/Parrot/Test/Lua.pm>
 
-=head1 AUTHOR
-
-Francois Perrad
-
 =cut
 
 1;
