@@ -1,5 +1,5 @@
 # Copyright (C) 2007, The Perl Foundation.
-# $Id: /mirror/trunk/languages/perl6/Test.pm 33860 2008-12-12T10:28:45.039663Z moritz  $
+# $Id: /mirror/trunk/languages/perl6/Test.pm 35861 2009-01-20T18:44:36.382732Z moritz  $
 
 ## This is a temporary Test.pm to get us started until we get pugs's Test.pm
 ## working. It's shamelessly stolen & adapted from MiniPerl6 in the pugs repo.
@@ -157,7 +157,7 @@ multi sub is_deeply($this, $that) {
 
 sub _is_deeply( $this, $that) {
 
-    if $this ~~ Array && $that ~~ Array {
+    if $this ~~ List && $that ~~ List {
         return if +$this.values != +$that.values;
         for $this Z $that -> $a, $b {
             return if ! _is_deeply( $a, $b );
@@ -195,10 +195,14 @@ sub eval_exception($code) {
     $eval_exception // $!;
 }
 
-sub proclaim($cond, $desc) {
+sub proclaim(Object $cond, $desc) {
     $testing_started  = 1;
     $num_of_tests_run = $num_of_tests_run + 1;
 
+    if $cond.HOW().isa($cond, Junction) {
+        warn("Junction passed to proclaim");
+    }
+
     unless $cond {
         print "not ";
         $num_of_tests_failed = $num_of_tests_failed + 1
