@@ -1,7 +1,7 @@
 #! perl
 
 # Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/languages/perl6/tools/test_summary.pl 32637 2008-11-13T11:16:12.646966Z bernhard  $
+# $Id: /mirror/trunk/languages/perl6/tools/test_summary.pl 33881 2008-12-13T10:42:03.881331Z bernhard  $
 
 ##  The "make spectest" target tells us how many
 ##  tests we failed (hopefully zero!), but doesn't say how
@@ -47,9 +47,20 @@ for my $tfile (@tfiles) {
     $tname{$tfile} = $tname;
 }
 
-$| = 1;
-printf "%s  plan test pass fail todo skip\n", ' ' x $max;
+my @syn = qw(S02 S03 S04 S05 S06 S09 S10 S12 S13 S16 S17 S29);
+my @col = qw(pass fail todo skip plan spec);
+my %syn;
 my %sum;
+for my $syn (@syn) {
+    $syn{$syn}++;
+    for my $col (@col) {
+        $sum{"$syn-$col"} = 0;
+    }
+}
+
+$| = 1;
+printf "%s  pass fail todo skip test plan\n", ' ' x $max;
+
 my @fail;
 for my $tfile (@tfiles) {
     my $th;
@@ -60,12 +71,14 @@ for my $tfile (@tfiles) {
     }
     close($th);
     my $tname = $tname{$tfile};
-    printf "%s%s..%4d", $tname, '.' x ($max - length($tname)), $plan;
+    my $syn = substr($tname, 0, 3); $syn{$syn}++;
+    printf "%s%s..", $tname, '.' x ($max - length($tname));
     my $cmd = "../../parrot perl6.pbc $tfile";
     my @results = split "\n", `$cmd`;
     my ($test, $pass, $fail, $todo, $skip) = (0,0,0,0,0);
     my (%skip, %todopass, %todofail);
     for (@results) {
+        if    (/^1\.\.(\d+)/) { $plan = $1 if $1 > 0; next; }
         next unless /^(not )?ok +(\d+)/;
         $test++;
         if    (/#\s*SKIP\s*(.*)/i) { $skip++; $skip{$1}++; }
@@ -87,13 +100,14 @@ for my $tfile (@tfiles) {
         push @fail, "$tname aborted $abort test(s)";
         $test += $abort;
     }
-    printf " %4d %4d %4d %4d %4d\n", $test, $pass, $fail, $todo, $skip;
-    $sum{'plan'} += $plan;
-    $sum{'test'} += $test;
-    $sum{'pass'} += $pass;
-    $sum{'fail'} += $fail;
-    $sum{'todo'} += $todo;
-    $sum{'skip'} += $skip;
+    printf "%4d %4d %4d %4d %4d %4d\n",
+        $pass, $fail, $todo, $skip, $test, $plan;
+    $sum{'pass'} += $pass;  $sum{"$syn-pass"} += $pass;
+    $sum{'fail'} += $fail;  $sum{"$syn-fail"} += $fail;
+    $sum{'todo'} += $todo;  $sum{"$syn-todo"} += $todo;
+    $sum{'skip'} += $skip;  $sum{"$syn-skip"} += $skip;
+    $sum{'test'} += $test;  $sum{"$syn-test"} += $test;
+    $sum{'plan'} += $plan;  $sum{"$syn-plan"} += $plan;
     for (keys %skip) {
         printf "    %2d skipped: %s\n", $skip{$_}, $_;
     }
@@ -105,13 +119,37 @@ for my $tfile (@tfiles) {
     }
 }
 
+for my $syn (sort keys %syn) {
+    my $ackcmd = "ack plan t/spec/$syn* -wh";
+    my @results = `$ackcmd`;
+    my $spec = 0;
+    for (@results) {
+        $spec += $1 if /^\s*plan\s+(\d+)/;
+    }
+    $sum{"$syn-spec"} = $spec;
+    $sum{'spec'} += $spec;
+}
+
+my $sumfmt = qq(%-9.9s %6s,%6s,%6s,%6s,%6s,%6s\n);
 print "----------------\n";
+print qq("Synopsis","pass","fail","todo","skip","regr","spec"\n);
+for my $syn (sort keys %syn) {
+    printf $sumfmt, qq("$syn",), map { $sum{"$syn-$_"} } @col;
+}
+
+my $total = scalar(@tfiles).' regression files';
+printf $sumfmt, qq("total",), map { $sum{$_} } @col;
+
+print "----------------\n";
+my $rev = $ENV{'REV'};
+if ($rev) {
+    my $file = scalar(@tfiles);
+    print join(',', $rev, (map { $sum{$_} } @col), $file), "\n";
+    print "[rakudo]: spectest-progress.csv update: ",
+          "$file files, $sum{'pass'} passing, $sum{'fail'} failing\n";
+}
+
 if (@fail) {
     print "Failure summary:\n";
     foreach (@fail) { print "    $_\n"; }
 }
-my $total = scalar(@tfiles)." test files";
-$total .= ' ' x ($max-length($total));
-printf "%s  %4d %4d %4d %4d %4d %4d\n",
-    $total, $sum{'plan'}, $sum{'test'}, $sum{'pass'},
-    $sum{'fail'}, $sum{'todo'}, $sum{'skip'};
