@@ -1,4 +1,4 @@
-# $Id: /mirror/trunk/languages/pipp/lib/Parrot/Test/Pipp.pm 29132 2008-07-06T17:48:31.252967Z bernhard  $
+# $Id: /mirror/trunk/languages/pipp/lib/Parrot/Test/Pipp.pm 34224 2008-12-21T11:50:25.901507Z bernhard  $
 
 # Copyright (C) 2006-2008, The Perl Foundation.
 
@@ -14,8 +14,6 @@ use File::Spec;
 
 use Parrot::Test;
 use Parrot::Test::Pipp::PHP;
-use Parrot::Test::Pipp::Phc;
-use Parrot::Test::Pipp::Antlr3;
 use Parrot::Test::Pipp::PCT;
 
 =head1 NAME
@@ -37,8 +35,7 @@ Use the executable B<pipp> in smoke testing.
 =cut
 
 sub new {
-    my $test_module =  $ENV{PARROT_PIPP_TEST_MODULE}
-                    || 'Parrot::Test::Pipp::PCT';
+    my $test_module =  $ENV{PARROT_PIPP_TEST_MODULE} || 'Parrot::Test::Pipp::PCT';
 
     return bless {}, $test_module;
 }
