@@ -1,4 +1,4 @@
-# $Id: /mirror/trunk/languages/pipp/lib/Parrot/Test/Pipp/PCT.pm 32761 2008-11-16T20:30:30.695363Z bernhard  $
+# $Id: /mirror/trunk/languages/pipp/lib/Parrot/Test/Pipp/PCT.pm 34223 2008-12-21T11:41:29.287996Z bernhard  $
 
 # Copyright (C) 2006-2007, The Perl Foundation.
 
@@ -28,7 +28,7 @@ sub get_test_prog {
     my $lang_fn = Parrot::Test::per_test( '.php', $count );
     $lang_fn =~ s!^pipp/!!; # fix for unified languages testing
 
-    return "$self->{relpath}/parrot $self->{relpath}/languages/pipp/pipp.pbc --variant=pct ${lang_fn}";
+    return "$self->{relpath}/parrot $self->{relpath}/languages/pipp/pipp.pbc ${lang_fn}";
 }
 
 # never skip the reference implementation
