@@ -1,10 +1,12 @@
-# $Id: /mirror/trunk/languages/pynie/src/parser/Actions.pm 31553 2008-09-30T19:05:04.732966Z moritz  $
+# $Id: /mirror/trunk/languages/pynie/src/parser/Actions.pm 35037 2009-01-05T20:46:44.797206Z tene  $
 # Copyright (C) 2007, The Perl Foundation.
 
 class Pynie::Grammar::Actions;
 
 method TOP($/) {
-    make $( $<file_input> );
+    my $block := PAST::Block.new( $( $<file_input> ) );
+    $block.hll('pynie');
+    make $block;
 }
 
 method file_input($/) {
