@@ -1,5 +1,5 @@
 # Copyright (C) 2008, The Perl Foundation.
-# $Id: /mirror/trunk/languages/squaak/src/parser/actions.pm 31325 2008-09-21T08:47:14.404592Z tene  $
+# $Id: /mirror/trunk/languages/squaak/src/parser/actions.pm 34363 2008-12-24T12:30:33.192941Z bernhard  $
 
 
 =begin comments
@@ -157,7 +157,7 @@ method try_statement($/) {
 
     ## get the exception identifier;
     my $exc := $( $<exception> );
-    $exc.isdecl( PAST::Val.new( :value(1) ) );
+    $exc.isdecl(1);
     $exc.scope('lexical');
     $exc.viviself( PAST::Val.new( :value(0) ) );
 
