@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2005, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Configure/Data.pm 30151 2008-08-08T04:33:00.453828Z coke  $
+# $Id: /mirror/trunk/lib/Parrot/Configure/Data.pm 34978 2009-01-05T00:07:29.920573Z jkeenan  $
 
 =pod
 
@@ -236,7 +236,7 @@ sub keys {
     return keys %{ $self->{c} };
 }
 
-=item * C<slurp()>
+=item * C<get_PConfig()>
 
 =over 4
 
@@ -256,7 +256,7 @@ Reference to hash holding main Parrot::Configure data structure.
 
 =cut
 
-sub slurp {
+sub get_PConfig {
     my $self = shift;
     my $res  = eval <<EVAL_CONFIG;
 no strict;
@@ -270,7 +270,7 @@ EVAL_CONFIG
     $self->{c} = $res;
 }
 
-=item * C<slurp_temp()>
+=item * C<get_PConfig_Temp()>
 
 =over 4
 
@@ -292,7 +292,7 @@ structure holding temporary data.
 
 =cut
 
-sub slurp_temp {
+sub get_PConfig_Temp {
     my $self = shift;
     my $res  = eval <<EVAL_CONFIG_TEMP;
 no strict;
