@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2006, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Configure/Options/Test/Prepare.pm 27043 2008-04-19T14:42:57.827175Z jkeenan  $
+# $Id: /mirror/trunk/lib/Parrot/Configure/Options/Test/Prepare.pm 34127 2008-12-19T02:14:09.799525Z jkeenan  $
 package Parrot::Configure::Options::Test::Prepare;
 use strict;
 use warnings;
@@ -33,7 +33,7 @@ sub get_postconfiguration_tests {
         glob("t/postconfigure/*.t"),
         glob("t/tools/pmc2cutils/*.t"),
         glob("t/tools/ops2cutils/*.t"),
-        glob("t/tools/ops2pmutils/*.t"),
+        glob("t/tools/ops2pm/*.t"),
         glob("t/pharness/*.t"),
     );
     return @postconfiguration_tests;
@@ -137,7 +137,7 @@ Returns a list of the tests found in these directories:
     t/postconfigure/
     t/tools/pmc2cutils/
     t/tools/ops2cutils/
-    t/tools/ops2pmutils/
+    t/tools/ops2pm/
     t/pharness/
 
 =back
