@@ -1,9 +1,9 @@
-# Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Distribution.pm 32238 2008-10-27T22:27:47.629249Z kjs  $
+# Copyright (C) 2004-2009, The Perl Foundation.
+# $Id: /mirror/trunk/lib/Parrot/Distribution.pm 35745 2009-01-18T12:09:17.170228Z bernhard  $
 
 =head1 NAME
 
-Parrot::Distribution - Parrot Distribution Directory
+Parrot::Distribution - Info on the Parrot Distribution
 
 =head1 SYNOPSIS
 
@@ -35,6 +35,9 @@ use warnings;
 use ExtUtils::Manifest;
 use File::Spec;
 
+use lib qw( lib );
+use Parrot::BuildUtil ();
+
 use base 'Parrot::Docs::Directory';
 
 =item C<new()>
@@ -50,51 +53,52 @@ Raises an exception if the distribution root is not found.
 
 =cut
 
-## i'm a singleton
-my $dist;
+{
+    my $dist; ## i'm a singleton
 
-sub new {
-    my ($class) = @_;
+    sub new {
+        my ($class) = @_;
 
-    return $dist if defined $dist;
+        return $dist if defined $dist;
 
-    my $self = bless {}, $class;
+        my $self = bless {}, $class;
 
-    return $self->_initialize;
-}
+        return $self->_initialize;
+    }
 
-sub _initialize {
-    my ($self) = @_;
+    sub _initialize {
+        my ($self) = @_;
 
-    my $file = 'README';
-    my $path = '.';
+        my $file = 'README';
+        my $path = '.';
 
-    while ( $self = $self->SUPER::new($path) ) {
-        if (    $self->file_exists_with_name($file)
-            and $self->file_with_name($file)->read =~ m/^This is Parrot/os )
-        {
-            $dist = $self;
-            last;
+        while ( $self = $self->SUPER::new($path) ) {
+            if (    $self->file_exists_with_name($file)
+                and $self->file_with_name($file)->read =~ m/^This is Parrot/os )
+            {
+                $dist = $self;
+                last;
+            }
+
+            $path = $self->parent_path();
         }
 
-        $path = $self->parent_path();
+        # non-object call syntax since $self is undefined
+        _croak( undef, "Failed to find Parrot distribution root\n" )
+            unless $self;
+
+        if ( defined $dist ) {
+            $self->_dist_files(
+                [
+                    sort keys %{
+                        ExtUtils::Manifest::maniread( File::Spec->catfile( $self->path, "MANIFEST" ) )
+                        },
+                ]
+            );
+        }
+
+        return $self;
     }
-
-    # non-object call syntax since $self is undefined
-    _croak( undef, "Failed to find Parrot distribution root\n" )
-        unless $self;
-
-    if ( defined $dist ) {
-        $self->_dist_files(
-            [
-                sort keys %{
-                    ExtUtils::Manifest::maniread( File::Spec->catfile( $self->path, "MANIFEST" ) )
-                    },
-            ]
-        );
-    }
-
-    return $self;
 }
 
 sub _croak {
@@ -134,46 +138,60 @@ BEGIN {
 
 =item C<is_git_co()>
 
-=item C<c_source_file_directories()>
+Check the type of checkout.
 
 =item C<c_header_file_directories()>
 
-=item C<pmc_source_file_directories()>
-
-=item C<yacc_source_file_directories()>
+=item C<c_source_file_directories()>
 
 =item C<lex_source_file_directories()>
 
 =item C<ops_source_file_directories()>
 
+=item C<perl_source_file_directories()>
+
+=item C<pir_source_file_directories()>
+
+=item C<pmc_source_file_directories()>
+
+=item C<yacc_source_file_directories()>
+
 Returns the directories which contain source files of the appropriate filetype.
 
-=item C<c_source_file_with_name($name)>
+=item C<c_header_file_with_name()>
 
-=item C<c_header_file_with_name($name)>
+=item C<c_source_file_with_name()>
 
-=item C<pmc_source_file_with_name($name)>
+=item C<lex_source_file_with_name()>
 
-=item C<yacc_source_file_with_name($name)>
+=item C<ops_source_file_with_name()>
 
-=item C<lex_source_file_with_name($name)>
+=item C<perl_source_file_with_name()>
 
-=item C<ops_source_file_with_name($name)>
+=item C<pir_source_file_with_name()>
+
+=item C<pmc_source_file_with_name()>
+
+=item C<yacc_source_file_with_name()>
 
 Returns the source file with the specified name and of the appropriate filetype.
 
-=item C<c_source_files()>
-
 =item C<c_header_files()>
 
-=item C<pmc_source_files()>
-
-=item C<yacc_source_files()>
+=item C<c_source_files()>
 
 =item C<lex_source_files()>
 
 =item C<ops_source_files()>
 
+=item C<perl_source_files()>
+
+=item C<pir_source_files()>
+
+=item C<pmc_source_files()>
+
+=item C<yacc_source_files()>
+
 Returns a sorted list of the source files listed within the MANIFEST of
 Parrot.  Returns a list of Parrot::IO::File objects of the appropriate filetype.
 
@@ -234,10 +252,11 @@ BEGIN {
 
                 # Filter out ignored directories
                 # and return the results
-                return sort
+                my @dirs = sort
                     map  { $self->directory_with_name($_) }
                     grep { !m|(?:$filter_dir)| }
                     keys %dirs;
+                return @dirs;
             };
 
             *{ $method . '_file_with_name' } = sub {
@@ -272,9 +291,11 @@ BEGIN {
                 # Look through the list of distribution files
                 # for files ending in the proper extension(s)
                 # and return a sorted list of filenames
-                return sort
+                my @files = sort
                     map  { $self->file_with_name($_) }
-                    grep { m|(?i)(?:$filter_ext)| } $self->_dist_files;
+                    grep { m|(?i)(?:$filter_ext)| }
+                    $self->_dist_files;
+                return @files;
             };
         }
     }
@@ -371,20 +392,20 @@ This is to exclude automatically generated C-language files Parrot might have.
             compilers/imcc/imclexer.c
             compilers/imcc/imcparser.c
             compilers/imcc/imcparser.h
-            compilers/pirc/new/main.c
-            compilers/pirc/new/pir.l
-            compilers/pirc/new/pir.y
-            compilers/pirc/new/pasm.l
-            compilers/pirc/new/pasm.y
-            compilers/pirc/new/pircompiler.h
-            compilers/pirc/new/pirlexer.c
-            compilers/pirc/new/pirlexer.h
-            compilers/pirc/new/pirparser.c
-            compilers/pirc/new/pirparser.h
-            compilers/pirc/new/pircompunit.c
-            compilers/pirc/new/pircompunit.h
-            compilers/pirc/new/hdocprep.l
-            compilers/pirc/new/hdocprep.c
+            compilers/pirc/src/main.c
+            compilers/pirc/src/pir.l
+            compilers/pirc/src/pir.y
+            compilers/pirc/src/pasm.l
+            compilers/pirc/src/pasm.y
+            compilers/pirc/src/pircompiler.h
+            compilers/pirc/src/pirlexer.c
+            compilers/pirc/src/pirlexer.h
+            compilers/pirc/src/pirparser.c
+            compilers/pirc/src/pirparser.h
+            compilers/pirc/src/pircompunit.c
+            compilers/pirc/src/pircompunit.h
+            compilers/pirc/src/hdocprep.l
+            compilers/pirc/src/hdocprep.c
             compilers/pirc/macro/lexer.h
             compilers/pirc/macro/macro.h
             compilers/pirc/macro/macro.l
@@ -472,7 +493,6 @@ sub get_perl_exemption_regexp {
     my @paths = map { File::Spec->catdir( $parrot_dir, File::Spec->canonpath($_) ) } qw{
         languages/regex/lib/Regex/Grammar.pm
         languages/pipp/src/pct/actions.pm
-        languages/hq9plus/src/parser/actions.pm
         compilers/nqp/
         compilers/ncigen/src/parser/actions.pm
         lib/Digest/Perl/
@@ -620,7 +640,6 @@ sub perl_script_file_directories {
             WMLScript/build
             dotnet dotnet/build dotnet/tools
             lua
-            m4/tools
             pipp
             python
             regex
@@ -670,14 +689,12 @@ sub perl_module_file_directories {
         map( "languages/$_" => qw<
             APL/t
             BASIC/compiler
-            HQ9plus/lib/Parrot/Test
             WMLScript/build/SRM WMLScript/t/Parrot/Test
             bc/lib/Parrot/Test bc/lib/Parrot/Test/Bc
             dotnet/build/SRM dotnet/t
             jako/lib/Jako
             jako/lib/Jako/Construct
             lua/Lua lua/t/Parrot/Test
-            m4/lib/Parrot/Test m4/lib/Parrot/Test/M4
             parrot_compiler/lib/Parrot/Test
             perl6/t/01-sanity
             pipp/lib/Parrot/Test pipp/lib/Parrot/Test/Pipp
@@ -771,7 +788,7 @@ sub generated_files {
     my $self = shift;
 
     my $generated = ExtUtils::Manifest::maniread('MANIFEST.generated');
-    my $path      = $dist->path();
+    my $path      = $self->path();
 
     return {
         map { File::Spec->catfile( $path, $_ ) => $generated->{$_} }
