@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Docs/Section/C.pm 31708 2008-10-05T14:34:20.774804Z fperrad  $
+# $Id: /mirror/trunk/lib/Parrot/Docs/Section/C.pm 35435 2009-01-11T10:55:39.856979Z cotto  $
 
 =head1 NAME
 
@@ -235,8 +235,7 @@ sub new {
                 'pairs'   => ['resources'],
                 'sources' => ['res_lea']
             ),
-            $self->c_pair_item( '', 'smallobject' ),
-            $self->c_pair_item( '', 'headers' ),
+            $self->c_source_item( '', 'mark_sweep' ),
         ),
         $self->new_group(
             'Garbage Collection',
