@@ -1,5 +1,5 @@
-# Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Docs/Section/Languages.pm 31807 2008-10-08T03:05:51.206433Z coke  $
+# Copyright (C) 2004-2009, The Perl Foundation.
+# $Id: /mirror/trunk/lib/Parrot/Docs/Section/Languages.pm 35745 2009-01-18T12:09:17.170228Z bernhard  $
 
 =head1 NAME
 
@@ -39,7 +39,6 @@ sub new {
         'Language Implementations',
         'languages.html',
         '',
-        $self->new_item( '', 'languages/LANGUAGES_STATUS.pod' ),
         $self->new_item( '', 'languages/t/harness' ),
         $self->new_section( 'abc',         'abc.html',        '', 'languages/abc' ),
         $self->new_section( 'APL',         'apl.html',        '', 'languages/APL' ),
@@ -52,15 +51,12 @@ sub new {
         $self->new_section( 'Cola',        'cola.html',       '', 'languages/cola' ),
         $self->new_section( 'Common Lisp', 'lisp.html',       '', 'languages/lisp' ),
         $self->new_section( '.Net',        'dotnet.html',     '', 'languages/dotnet' ),
-        $self->new_section( 'eclectus',    'eclectus.html',   '', 'languages/eclectus' ),
         $self->new_section( 'ecmascript',  'ecmascript.html', '', 'languages/ecmascript' ),
         $self->new_section( 'forth',       'forth.html',      '', 'languages/forth' ),
-        $self->new_section( 'HQ9plus',     'hq9plus.html',    '', 'languages/hq9plus' ),
         $self->new_section( 'Jako',        'jako.html',       '', 'languages/jako' ),
         $self->new_section( 'lazy-k',      'lazy-k.html',     '', 'languages/lazy-k' ),
         $self->new_section( 'lolcode',     'lolcode.html',    '', 'languages/lolcode' ),
         $self->new_section( 'Lua',         'lua.html',        '', 'languages/lua' ),
-        $self->new_section( 'M4',          'm4.html',         '', 'languages/m4' ),
         $self->new_section( 'Markdown',    'markdown.html',   '', 'languages/markdown' ),
         $self->new_section( 'Ook!',        'ook.html',        '', 'languages/ook' ),
         $self->new_section( 'Perl6',       'perl6.html',      '', 'languages/perl6' ),
