@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2007, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Headerizer.pm 22856 2007-11-17T18:59:11.968114Z bernhard  $
+# $Id: /mirror/trunk/lib/Parrot/Headerizer.pm 32919 2008-11-19T17:21:15.952103Z particle  $
 
 =head1 NAME
 
@@ -52,7 +52,7 @@ sub new {
 
 my %warnings;
 my %valid_macros = map { ( $_, 1 ) } qw(
-    PARROT_API
+    PARROT_EXPORT
     PARROT_INLINE
     PARROT_CAN_RETURN_NULL
     PARROT_CANNOT_RETURN_NULL
@@ -156,7 +156,7 @@ sub function_components_from_declaration {
 
     while ( @lines && ( $lines[0] =~ /^PARROT_/ ) ) {
         my $macro = shift @lines;
-        if ( $macro eq 'PARROT_API' ) {
+        if ( $macro eq 'PARROT_EXPORT' ) {
             $parrot_api = 1;
         }
         elsif ( $macro eq 'PARROT_INLINE' ) {
@@ -175,7 +175,7 @@ sub function_components_from_declaration {
     my $name = $1;
     $args = $2;
 
-    die "Can't have both PARROT_API and PARROT_INLINE on $name\n" if $parrot_inline && $parrot_api;
+    die "Can't have both PARROT_EXPORT and PARROT_INLINE on $name\n" if $parrot_inline && $parrot_api;
 
     my @args = split( /\s*,\s*/, $args );
     for (@args) {
@@ -189,7 +189,7 @@ sub function_components_from_declaration {
     my $is_static = 0;
     $is_static = $2 if $return_type =~ s/^((static)\s+)?//i;
 
-    die "$file $name: Impossible to have both static and PARROT_API" if $parrot_api && $is_static;
+    die "$file $name: Impossible to have both static and PARROT_EXPORT" if $parrot_api && $is_static;
 
     my %macros;
     for my $macro (@macros) {
