@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: Directory.pm 27018 2008-04-17 14:45:47Z coke $
+# $Id: /mirror/trunk/lib/Parrot/IO/Directory.pm 34953 2009-01-04T15:49:15.374383Z petdance  $
 
 =head1 NAME
 
@@ -28,7 +28,7 @@ use base qw( Parrot::IO::Path );
 
 use DirHandle;
 use File::Path;
-use File::Spec;
+use File::Spec ();
 use Parrot::IO::File;
 
 =item C<directory_class()>
@@ -189,7 +189,9 @@ sub file_and_directory_names {
     my $dh   = DirHandle->new( $self->path )
         or die "can't opendir $self->{PATH}: $!";
 
-    return sort grep { $_ ne '.' and $_ ne '..' } $dh->read();
+    my @files = sort grep { $_ ne '.' and $_ ne '..' } $dh->read();
+
+    return @files;
 }
 
 =item C<file_and_directory_paths()>
@@ -213,7 +215,9 @@ These are the full paths of all the files in the directory.
 sub file_paths {
     my $self = shift;
 
-    return sort grep { -f } $self->file_and_directory_paths;
+    my @paths = sort grep { -f } $self->file_and_directory_paths;
+
+    return @paths;
 }
 
 =item C<directory_paths()>
@@ -225,7 +229,9 @@ These are the full paths of all the subdirectories in the directory.
 sub directory_paths {
     my $self = shift;
 
-    return sort grep { -d } $self->file_and_directory_paths;
+    my @paths = sort grep { -d } $self->file_and_directory_paths;
+
+    return @paths;
 }
 
 =item C<file_exists_with_name($name)>
@@ -324,7 +330,9 @@ sub file_suffixes {
         $suffixes{ $file->suffix } = 1;
     }
 
-    return sort keys %suffixes;
+    my @suffixes = sort keys %suffixes;
+
+    return @suffixes;
 }
 
 =item C<files_with_suffix($suffix, $recursive, $ignore)>
