@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/IO/Path.pm 21450 2007-09-21T09:33:12.878294Z paultcochrane  $
+# $Id: /mirror/trunk/lib/Parrot/IO/Path.pm 34218 2008-12-21T06:26:45.601168Z petdance  $
 
 =head1 NAME
 
@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 use File::Path;
-use File::Spec;
+use File::Spec ();
 
 # qw() to avoid the export because we have a stat() method.
 use File::stat qw();
