@@ -1,5 +1,5 @@
 # Copyright (C) 2002, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/OpTrans/CGP.pm 26498 2008-03-19T07:13:39.083170Z chromatic  $
+# $Id: /mirror/trunk/lib/Parrot/OpTrans/CGP.pm 32857 2008-11-18T20:29:57.330043Z chromatic  $
 
 =head1 NAME
 
@@ -106,7 +106,9 @@ relevant C code.
 sub goto_offset {
     my ( $self, $offset ) = @_;
 
-    return "goto **(void **)(cur_opcode += $offset)";
+    # this must be a single expression, in case it's in a single-statement if
+    return "do {\nCONTEXT(interp)->current_pc = CUR_OPCODE + $offset;\n"
+    .      "goto **(void **)(cur_opcode += $offset);\n} while (1)";
 }
 
 =item C<goto_pop()>
