@@ -1,13 +1,13 @@
 # Copyright (C) 2007-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Ops2c/Utils.pm 32919 2008-11-19T17:21:15.952103Z particle  $
+# $Id: /mirror/trunk/lib/Parrot/Ops2c/Utils.pm 34437 2008-12-27T05:50:39.271216Z petdance  $
 package Parrot::Ops2c::Utils;
 use strict;
 use warnings;
 use lib ("lib/");
 use Parrot::OpLib::core;
 use Parrot::OpsFile;
-use File::Spec;
-use IO::File;
+use File::Spec ();
+use IO::File ();
 
 =head1 NAME
 
@@ -945,7 +945,7 @@ static int get_op(const char * name, int full) {
 }
 static void hop_init(void) {
     size_t i;
-    op_info_t * info = $self->{bs}op_lib.op_info_table;
+    op_info_t * const info = $self->{bs}op_lib.op_info_table;
     /* store full names */
     for (i = 0; i < $self->{bs}op_lib.op_count; i++)
         store_op(info + i, 1);
