@@ -1,5 +1,5 @@
-# Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMC.pm 31699 2008-10-05T11:30:01.049343Z allison  $
+# Copyright (C) 2004-2008, The Perl Foundation.
+# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMC.pm 34584 2008-12-29T06:34:25.614488Z petdance  $
 #
 
 =head1 NAME
@@ -27,7 +27,6 @@ use base qw( Exporter );
 our @EXPORT_OK = qw();
 use Storable ();
 use Parrot::PMC;
-use Parrot::Pmc2c::UtilFunctions qw(spew);
 use Parrot::Pmc2c::Method;
 
 sub create {
@@ -172,6 +171,12 @@ sub is_dynamic {
     return 1;
 }
 
+sub export {
+    my ( $self ) = @_;
+
+    return $self->is_dynamic ? 'PARROT_DYNEXT_EXPORT' : 'PARROT_EXPORT';
+}
+
 sub implements_vtable {
     my ( $self, $vt_meth ) = @_;
     return 0 unless $self->has_method($vt_meth);
