@@ -1,6 +1,6 @@
 # Copyright (C) 2004-2008, The Perl Foundation.
 
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMC/RO.pm 29983 2008-08-02T22:45:13.271765Z allison  $
+# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMC/RO.pm 34821 2009-01-02T06:14:49.961174Z petdance  $
 
 =head1 NAME
 
@@ -25,14 +25,11 @@ use strict;
 use warnings;
 use base qw( Parrot::Pmc2c::PMC );
 
-use Parrot::Pmc2c::Emitter;
-use Parrot::Pmc2c::PMCEmitter;
-use Parrot::Pmc2c::Method;
-use Parrot::Pmc2c::MethodEmitter;
-use Parrot::Pmc2c::UtilFunctions
-    qw( gen_ret dont_edit count_newlines dynext_load_code c_code_coda );
+use Parrot::Pmc2c::Emitter ();
+use Parrot::Pmc2c::PMCEmitter ();
+use Parrot::Pmc2c::Method ();
+use Parrot::Pmc2c::UtilFunctions qw( return_statement );
 use Text::Balanced 'extract_bracketed';
-use Parrot::Pmc2c::PCCMETHOD;
 
 =item C<make_RO($type)>
 
@@ -99,24 +96,29 @@ EOC
             $self->add_method($ro_method);
         }
         elsif ( $parent->vtable_method_does_write($vt_method_name) ) {
+            # All parameters passed in are shims, because we're
+            # creating an exception-thrower.
+            my @parameters = split( /\s*,\s*/, $vt_method->parameters );
+            @parameters = map { "SHIM($_)" } @parameters;
+
             my $ro_method = Parrot::Pmc2c::Method->new(
                 {
                     name        => $vt_method_name,
                     parent_name => $parent->name,
                     return_type => $vt_method->return_type,
-                    parameters  => $vt_method->parameters,
+                    parameters  => join( ', ', @parameters ),
                     type        => Parrot::Pmc2c::Method::VTABLE,
+                    pmc_unused  => 1,
                 }
             );
             my $pmcname = $parent->name;
-            my $ret     = gen_ret($ro_method);
+            my $ret     = return_statement($ro_method);
             my $body    = <<EOC;
     Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_WRITE_TO_CONSTCLASS,
             "$vt_method_name() in read-only instance of $pmcname");
 EOC
 
             # don't return after a Parrot_ex_throw_from_c_args
-            #      $body .= "    $ret\n" if $ret;
             $ro_method->body( Parrot::Pmc2c::Emitter->text($body) );
             $self->add_method($ro_method);
         }
