@@ -1,5 +1,5 @@
 # Copyright (C) 2007-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMCEmitter.pm 32010 2008-10-15T18:56:43.255510Z coke  $
+# $Id: /mirror/trunk/lib/Parrot/Pmc2c/PMCEmitter.pm 34584 2008-12-29T06:34:25.614488Z petdance  $
 
 =head1 NAME
 
@@ -25,8 +25,7 @@ use warnings;
 use Parrot::Pmc2c::Emitter;
 use Parrot::Pmc2c::Method;
 use Parrot::Pmc2c::MethodEmitter;
-use Parrot::Pmc2c::UtilFunctions
-    qw( gen_ret dont_edit count_newlines dynext_load_code c_code_coda );
+use Parrot::Pmc2c::UtilFunctions qw( dont_edit dynext_load_code c_code_coda );
 use Text::Balanced 'extract_bracketed';
 use Parrot::Pmc2c::PCCMETHOD;
 use Parrot::Pmc2c::MULTI;
