@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/Pmc2cMain.pm 32878 2008-11-19T00:57:12.447751Z chromatic  $
+# $Id: /mirror/trunk/lib/Parrot/Pmc2c/Pmc2cMain.pm 35535 2009-01-13T20:27:38.306958Z Whiteknight  $
 package Parrot::Pmc2c::Pmc2cMain;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ use Parrot::PMC ();
 use Parrot::Pmc2c::VTable ();
 use Parrot::Pmc2c::Dumper;
 use Parrot::Pmc2c::Library ();
-use Parrot::Pmc2c::UtilFunctions qw( slurp spew filename );
+use Parrot::Pmc2c::UtilFunctions qw( filename );
 use Parrot::Pmc2c::PCCMETHOD ();
 use Parrot::Pmc2c::PMC::default ();
 use Parrot::Pmc2c::PMC::delegate ();
@@ -17,8 +17,8 @@ use Parrot::Pmc2c::PMC::deleg_pmc ();
 use Parrot::Pmc2c::PMC::Null ();
 use Parrot::Pmc2c::PMC::Ref ();
 use Parrot::Pmc2c::PMC::SharedRef ();
-use Parrot::Pmc2c::PMC::STMRef ();
 use Parrot::Pmc2c::PMC::Object ();
+use File::Spec ();
 use Carp;
 
 $SIG{'__WARN__'} = sub { use Carp; warn $_[0]; Carp::confess; };
