@@ -1,13 +1,12 @@
-# Copyright (C) 2004-2006, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/VTable.pm 26316 2008-03-11T09:50:21.102015Z allison  $
+# Copyright (C) 2004-2008, The Perl Foundation.
+# $Id: /mirror/trunk/lib/Parrot/Pmc2c/VTable.pm 34589 2008-12-29T06:55:43.954267Z petdance  $
 package Parrot::Pmc2c::VTable;
 use strict;
 use warnings;
 
 use Storable ();
 use Parrot::Vtable;
-use Parrot::Pmc2c::Method;
-use Parrot::Pmc2c::UtilFunctions qw(spew);
+use Parrot::Pmc2c::Method ();
 use File::Basename;
 use Cwd qw(cwd);
 
