@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Test.pm 33886 2008-12-13T14:31:41.601587Z jkeenan  $
+# $Id: /mirror/trunk/lib/Parrot/Test.pm 35492 2009-01-12T23:46:20.598539Z kjs  $
 
 =head1 NAME
 
@@ -225,7 +225,8 @@ For example:
 
 =item C<slurp_file($file_name)>
 
-Read the whole file $file_name and return the content as a string.
+Read the whole file $file_name and return the content as a string.  This is
+just an alias for C<Parrot::BuildUtil::slurp_file>.
 
 =item C<convert_line_endings($text)>
 
@@ -266,6 +267,8 @@ use File::Spec;
 use File::Basename;
 use Memoize ();
 
+use lib qw( lib );
+use Parrot::BuildUtil ();
 use Parrot::Config;
 
 require Exporter;
@@ -384,22 +387,10 @@ sub write_code_to_file {
     return;
 }
 
-# We can inherit from Test::More, so we do it.
+# We can inherit from other modules, so we do so.
 *plan = \&Test::More::plan;
 *skip = \&Test::More::skip;
-
-# What about File::Slurp?
-sub slurp_file {
-    my ($file_name) = @_;
-
-    open( my $SLURP, '<', $file_name ) or die "open '$file_name': $!";
-    local $/ = undef;
-    my $file = <$SLURP> . '';
-    $file    =~ s/\cM\cJ/\n/g;
-    close $SLURP;
-
-    return $file;
-}
+*slurp_file = \&Parrot::BuildUtil::slurp_file;
 
 sub convert_line_endings {
     my ($text) = @_;
@@ -571,7 +562,6 @@ sub _run_test_file {
         my $exec_f = per_test( '_pbcexe', $test_no );    # Make cleanup and svn:ignore more simple
         $exe_f =~ s@[\\/:]@$PConfig{slash}@g;
 
-        # RT#43751 put this into sub generate_pbc()
         run_command(
             qq{$parrot $args -o $pbc_f "$code_f"},
             CD     => $path_to_parrot,
@@ -750,7 +740,7 @@ sub _generate_test_functions {
                 $args    =~ s/--run-exec//;
                 $cmd       = qq{$parrot $args "$code_f"};
             } elsif ($func =~ /^pirc_/) {
-                $cmd       = qq{$pirc -p "$code_f"};
+                $cmd       = qq{$pirc -b -x "$code_f"};
             }
 
             write_code_to_file( $code, $code_f );
@@ -945,6 +935,7 @@ sub _generate_test_functions {
 
                 my $cmd =
                       "$PConfig{cc} $PConfig{ccflags} $PConfig{cc_debug} "
+                    . ($^O =~ m/MSWin32/ and $PConfig{cc} eq 'cl' ? "-DPARROT_IN_EXTENSION" : "")
                     . " -I./include -c "
                     . "$PConfig{cc_o_out}$obj_f $source_f";
                 my $exit_code = run_command(
@@ -970,7 +961,9 @@ sub _generate_test_functions {
                 my $iculibs = $PConfig{has_icu} ? $PConfig{icu_shared} : q{};
                 my $libparrot =
                     $PConfig{parrot_is_shared}
-                    ? "$PConfig{rpath_blib} -L$PConfig{blib_dir} "
+                    ? ("$PConfig{rpath_blib} " .
+                      (($^O =~ m/MSWin32/ and $PConfig{cc} eq 'cl')
+                         ? "" : "-L$PConfig{blib_dir} "))
                     . (
                       $^O =~ m/MSWin32/
                     ? $PConfig{libparrot_ldflags}
