@@ -1,7 +1,7 @@
 /* atomic/gcc_x86.c
  *  Copyright (C) 2006, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/src/atomic/gcc_x86.c 33627 2008-12-07T08:21:36.967649Z chromatic  $
+ *     $Id: /mirror/trunk/src/atomic/gcc_x86.c 35120 2009-01-07T05:35:06.691952Z infinoid  $
  */
 
 #include "parrot/parrot.h"
@@ -37,8 +37,8 @@ assembly suppport.
 =item C<void * parrot_i386_cmpxchg>
 
 The CMPXCHG assembly instruction is a single cycle x86 instruction
-that compares C<expect> and C<update>. If they are equal, sets
-C<expect> to C<update>. Otherwise sets C<update> to C<ptr>.
+that compares C<expect> and C<*ptr>. If they are equal, sets
+C<*ptr> to C<update>. Otherwise sets C<expect> to C<*ptr>.
 
 =cut
 
@@ -48,9 +48,10 @@ C<expect> to C<update>. Otherwise sets C<update> to C<ptr>.
 PARROT_EXPORT
 PARROT_CANNOT_RETURN_NULL
 void *
-parrot_i386_cmpxchg(ARGMOD(void *volatile *ptr), ARGIN(void *expect),
-                                        ARGIN(void *update))
+parrot_i386_cmpxchg(ARGMOD(void *volatile *ptr), ARGIN_NULLOK(void *expect),
+                                        ARGIN_NULLOK(void *update))
 {
+    ASSERT_ARGS(parrot_i386_cmpxchg)
 #if defined(PARROT_HAS_X86_64_GCC_CMPXCHG)
     __asm__ __volatile__("lock\n"
                          "cmpxchgq %1,%2":"=a"(expect):"q"(update), "m"(*ptr),
@@ -83,6 +84,7 @@ PARROT_EXPORT
 long
 parrot_i386_xadd(ARGIN(volatile long *l), long amount)
 {
+    ASSERT_ARGS(parrot_i386_xadd)
     long result = amount;
 #if defined(PARROT_HAS_X86_64_GCC_CMPXCHG)
     __asm__ __volatile__("lock\n" "xaddq %0, %1" : "=r"(result), "=m"(*l) :
