@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/byteorder.c 30438 2008-08-20T22:40:10.775481Z Whiteknight  $
+$Id: /mirror/trunk/src/byteorder.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -47,6 +47,7 @@ PARROT_CONST_FUNCTION
 INTVAL
 fetch_iv_le(INTVAL w)
 {
+    ASSERT_ARGS(fetch_iv_le)
 #if !PARROT_BIGENDIAN
     return w;
 #else
@@ -84,6 +85,7 @@ PARROT_CONST_FUNCTION
 INTVAL
 fetch_iv_be(INTVAL w)
 {
+    ASSERT_ARGS(fetch_iv_be)
 #if PARROT_BIGENDIAN
     return w;
 #else
@@ -119,6 +121,7 @@ PARROT_CONST_FUNCTION
 opcode_t
 fetch_op_be(opcode_t w)
 {
+    ASSERT_ARGS(fetch_op_be)
 #if PARROT_BIGENDIAN
     return w;
 #else
@@ -156,6 +159,7 @@ PARROT_CONST_FUNCTION
 opcode_t
 fetch_op_le(opcode_t w)
 {
+    ASSERT_ARGS(fetch_op_le)
 #if !PARROT_BIGENDIAN
     return w;
 #else
@@ -203,6 +207,7 @@ Converts a 4-byte big-endian buffer C<b> into a little-endian C<rb>.
 void
 fetch_buf_be_4(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_be_4)
 #if PARROT_BIGENDIAN
     memcpy(rb, b, 4);
 #else
@@ -226,6 +231,7 @@ Converts a 4-byte little-endian buffer C<b> into a big-endian buffer C<rb>.
 void
 fetch_buf_le_4(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_le_4)
 #if !PARROT_BIGENDIAN
     memcpy(rb, b, 4);
 #else
@@ -249,6 +255,7 @@ Converts an 8-byte big-endian buffer C<b> into a little-endian buffer C<rb>
 void
 fetch_buf_be_8(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_be_8)
 #if PARROT_BIGENDIAN
     memcpy(rb, b, 8);
 #else
@@ -276,6 +283,7 @@ Converts an 8-byte little-endian buffer C<b> into a big-endian buffer C<rb>.
 void
 fetch_buf_le_8(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_le_8)
 #if !PARROT_BIGENDIAN
     memcpy(rb, b, 8);
 #else
@@ -303,6 +311,7 @@ Converts a 12-byte little-endian buffer C<b> into a big-endian buffer C<b>.
 void
 fetch_buf_le_12(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_le_12)
 #if !PARROT_BIGENDIAN
     memcpy(rb, b, 12);
 #else
@@ -334,6 +343,7 @@ Converts a 12-byte big-endian buffer C<b> into a little-endian buffer C<b>.
 void
 fetch_buf_be_12(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_be_12)
 #if PARROT_BIGENDIAN
     memcpy(rb, b, 12);
 #else
@@ -365,6 +375,7 @@ Converts a 16-byte little-endian buffer C<b> into a big-endian buffer C<b>.
 void
 fetch_buf_le_16(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_le_16)
 #if !PARROT_BIGENDIAN
     memcpy(rb, b, 16);
 #else
@@ -400,6 +411,7 @@ Converts a 16-byte big-endian buffer C<b> into a little-endian buffer C<b>.
 void
 fetch_buf_be_16(ARGOUT(unsigned char *rb), ARGIN(const unsigned char *b))
 {
+    ASSERT_ARGS(fetch_buf_be_16)
 #if PARROT_BIGENDIAN
     memcpy(rb, b, 16);
 #else
