@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/charset/ascii.c 31650 2008-10-04T14:29:56.249612Z Whiteknight  $
+$Id: /mirror/trunk/src/charset/ascii.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -100,7 +100,8 @@ static STRING * to_ascii(PARROT_INTERP,
     ARGIN(STRING *src),
     ARGMOD_NULLOK(STRING *dest))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
+        __attribute__nonnull__(2)
+        FUNC_MODIFIES(*dest);
 
 PARROT_CANNOT_RETURN_NULL
 static STRING * to_charset(PARROT_INTERP,
@@ -115,7 +116,8 @@ static STRING * to_unicode(PARROT_INTERP,
     ARGMOD_NULLOK(STRING *dest))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
-        FUNC_MODIFIES(*src);
+        FUNC_MODIFIES(*src)
+        FUNC_MODIFIES(*dest);
 
 static void upcase(SHIM_INTERP, ARGIN(STRING *source_string))
         __attribute__nonnull__(2);
@@ -128,6 +130,51 @@ static UINTVAL validate(PARROT_INTERP, ARGIN(STRING *src))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
+#define ASSERT_ARGS_compose __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_decompose __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_downcase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_downcase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_find_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_find_not_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_is_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_set_graphemes __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(insert_string)
+#define ASSERT_ARGS_string_from_codepoint __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_titlecase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_titlecase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_to_ascii __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_to_charset __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_to_unicode __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_upcase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_upcase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_validate __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -148,6 +195,7 @@ STRING *
 ascii_get_graphemes(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(ascii_get_graphemes)
     return ENCODING_GET_BYTES(interp, source_string, offset, count);
 }
 
@@ -166,6 +214,7 @@ static void
 set_graphemes(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL replace_count, ARGMOD(STRING *insert_string))
 {
+    ASSERT_ARGS(set_graphemes)
     ENCODING_SET_BYTES(interp, source_string, offset,
             replace_count, insert_string);
 
@@ -189,6 +238,7 @@ STRING *
 ascii_get_graphemes_inplace(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count, ARGMOD(STRING *dest_string))
 {
+    ASSERT_ARGS(ascii_get_graphemes_inplace)
     return ENCODING_GET_BYTES_INPLACE(interp, source_string,
             offset, count, dest_string);
 }
@@ -208,11 +258,12 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 to_ascii(PARROT_INTERP, ARGIN(STRING *src), ARGMOD_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(to_ascii)
     String_iter iter;
     UINTVAL offs;
     unsigned char *p;
-
     const UINTVAL len = src->strlen;
+
     if (dest) {
         Parrot_reallocate_string(interp, dest, len);
     }
@@ -250,6 +301,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 to_unicode(PARROT_INTERP, ARGMOD(STRING *src), ARGMOD_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(to_unicode)
     if (dest) {
         dest->charset = Parrot_unicode_charset_ptr;
         dest->encoding = CHARSET_GET_PREFERRED_ENCODING(interp, dest);
@@ -277,6 +329,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 to_charset(PARROT_INTERP, ARGIN(STRING *src), ARGIN_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(to_charset)
     const charset_converter_t conversion_func =
         Parrot_find_charset_converter(interp, src->charset, Parrot_ascii_charset_ptr);
 
@@ -304,6 +357,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 compose(PARROT_INTERP, ARGIN(STRING *src))
 {
+    ASSERT_ARGS(compose)
     return string_copy(interp, src);
 }
 
@@ -323,6 +377,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 decompose(PARROT_INTERP, ARGMOD(STRING *src))
 {
+    ASSERT_ARGS(decompose)
     return string_copy(interp, src);
 }
 
@@ -339,6 +394,7 @@ Converts the STRING C<source_string> to all uppercase.
 static void
 upcase(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(upcase)
     const UINTVAL n = source_string->strlen;
 
     if (n) {
@@ -364,6 +420,7 @@ Converts the STRING C<source_string> to all lower-case.
 static void
 downcase(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(downcase)
     const UINTVAL n = source_string->strlen;
 
     if (n) {
@@ -391,6 +448,7 @@ are lower-case.
 static void
 titlecase(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(titlecase)
     const UINTVAL n = source_string->strlen;
 
     if (n) {
@@ -418,6 +476,7 @@ but doesn't modify the rest of the string.
 static void
 upcase_first(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(upcase_first)
     if (source_string->strlen) {
         char * const buffer = source_string->strstart;
         buffer[0] = (char)toupper((unsigned char)buffer[0]);
@@ -438,6 +497,7 @@ but doesn't modify the rest of the characters.
 static void
 downcase_first(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(downcase_first)
     if (source_string->strlen) {
         char * const buffer = source_string->strstart;
         buffer[0] = (char)tolower((unsigned char)buffer[0]);
@@ -458,6 +518,7 @@ but doesn't modify the rest of the string.
 static void
 titlecase_first(SHIM_INTERP, ARGMOD(STRING *source_string))
 {
+    ASSERT_ARGS(titlecase_first)
     if (source_string->strlen) {
         char * const buffer = source_string->strstart;
         buffer[0] = (char)toupper((unsigned char)buffer[0]);
@@ -479,6 +540,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 ascii_compare(PARROT_INTERP, ARGIN(const STRING *lhs), ARGIN(const STRING *rhs))
 {
+    ASSERT_ARGS(ascii_compare)
     const UINTVAL l_len = lhs->strlen;
     const UINTVAL r_len = rhs->strlen;
     const UINTVAL min_len = l_len > r_len ? r_len : l_len;
@@ -527,6 +589,7 @@ INTVAL
 mixed_cs_index(PARROT_INTERP, ARGIN(STRING *src), ARGIN(STRING *search),
     UINTVAL offs)
 {
+    ASSERT_ARGS(mixed_cs_index)
     String_iter src_iter, search_iter;
     UINTVAL len;
     INTVAL start;
@@ -573,6 +636,7 @@ INTVAL
 ascii_cs_index(PARROT_INTERP, ARGIN(STRING *source_string),
         ARGIN(STRING *search_string), UINTVAL offset)
 {
+    ASSERT_ARGS(ascii_cs_index)
     INTVAL retval;
     if (source_string->charset != search_string->charset) {
         return mixed_cs_index(interp, source_string, search_string, offset);
@@ -600,6 +664,7 @@ INTVAL
 ascii_cs_rindex(PARROT_INTERP, ARGIN(STRING *source_string),
         ARGIN(STRING *search_string), UINTVAL offset)
 {
+    ASSERT_ARGS(ascii_cs_rindex)
     INTVAL retval;
 
     if (source_string->charset != search_string->charset)
@@ -627,6 +692,7 @@ PARROT_WARN_UNUSED_RESULT
 static UINTVAL
 validate(PARROT_INTERP, ARGIN(STRING *src))
 {
+    ASSERT_ARGS(validate)
     UINTVAL offset;
     String_iter iter;
 
@@ -655,6 +721,7 @@ PARROT_WARN_UNUSED_RESULT
 static STRING *
 string_from_codepoint(PARROT_INTERP, UINTVAL codepoint)
 {
+    ASSERT_ARGS(string_from_codepoint)
     char real_codepoint = (char)codepoint;
     STRING * const return_string = string_make(interp, &real_codepoint, 1, "ascii", 0);
     return return_string;
@@ -674,6 +741,7 @@ PARROT_WARN_UNUSED_RESULT
 static INTVAL
 is_cclass(PARROT_INTERP, INTVAL flags, ARGIN(const STRING *source_string), UINTVAL offset)
 {
+    ASSERT_ARGS(is_cclass)
     UINTVAL codepoint;
 
     if (offset >= source_string->strlen)
@@ -702,10 +770,10 @@ static INTVAL
 find_cclass(PARROT_INTERP, INTVAL flags, ARGIN(STRING *source_string),
             UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(find_cclass)
     UINTVAL pos = offset;
     UINTVAL end = offset + count;
 
-    PARROT_ASSERT(source_string != 0);
     end = source_string->strlen < end ? source_string->strlen : end;
     for (; pos < end; ++pos) {
         const UINTVAL codepoint = ENCODING_GET_CODEPOINT(interp, source_string, pos);
@@ -730,10 +798,10 @@ static INTVAL
 find_not_cclass(PARROT_INTERP, INTVAL flags, ARGIN(STRING *source_string),
                 UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(find_not_cclass)
     UINTVAL pos = offset;
     UINTVAL end = offset + count;
 
-    PARROT_ASSERT(source_string != 0);
     end = source_string->strlen < end ? source_string->strlen : end;
     for (; pos < end; ++pos) {
         const UINTVAL codepoint = ENCODING_GET_CODEPOINT(interp, source_string, pos);
@@ -759,6 +827,7 @@ PARROT_PURE_FUNCTION
 size_t
 ascii_compute_hash(SHIM_INTERP, ARGIN(const STRING *source_string), size_t seed)
 {
+    ASSERT_ARGS(ascii_compute_hash)
     size_t hashval = seed;
     const char *buffptr = (const char *)source_string->strstart;
     UINTVAL len = source_string->strlen;
@@ -786,6 +855,7 @@ PARROT_CANNOT_RETURN_NULL
 const CHARSET *
 Parrot_charset_ascii_init(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_charset_ascii_init)
     CHARSET * const return_set = Parrot_new_charset(interp);
     static const CHARSET base_set = {
         "ascii",
@@ -833,6 +903,7 @@ PARROT_CANNOT_RETURN_NULL
 STRING *
 charset_cvt_ascii_to_binary(PARROT_INTERP, ARGIN(STRING *src), ARGIN_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(charset_cvt_ascii_to_binary)
     if (dest) {
         UINTVAL offs;
 
@@ -864,6 +935,7 @@ STRING *
 charset_cvt_ascii_to_iso_8859_1(PARROT_INTERP, ARGIN(STRING *src),
     ARGIN_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(charset_cvt_ascii_to_iso_8859_1)
     if (dest) {
         UINTVAL offs;
 
