@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/charset/binary.c 31652 2008-10-04T15:43:54.842458Z Whiteknight  $
+$Id: /mirror/trunk/src/charset/binary.c 35337 2009-01-09T14:56:44.162523Z infinoid  $
 
 =head1 NAME
 
@@ -28,8 +28,10 @@ This file implements the charset functions for binary data
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 
 static INTVAL compare(SHIM_INTERP,
-    SHIM(const STRING *lhs),
-    SHIM(const STRING *rhs));
+    ARGIN(const STRING *lhs),
+    ARGIN(const STRING *rhs))
+        __attribute__nonnull__(2)
+        __attribute__nonnull__(3);
 
 PARROT_CANNOT_RETURN_NULL
 static STRING* compose(PARROT_INTERP, SHIM(STRING *source_string))
@@ -106,6 +108,40 @@ static void upcase_first(PARROT_INTERP, SHIM(STRING *source_string))
         __attribute__nonnull__(1);
 
 static UINTVAL validate(SHIM_INTERP, SHIM(STRING *source_string));
+#define ASSERT_ARGS_compare __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(lhs) \
+    || PARROT_ASSERT_ARG(rhs)
+#define ASSERT_ARGS_compose __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_cs_index __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_cs_rindex __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_decompose __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_downcase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_downcase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_find_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_find_not_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_is_cclass __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_set_graphemes __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(insert_string)
+#define ASSERT_ARGS_string_from_codepoint __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_titlecase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_titlecase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_to_charset __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_upcase __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_upcase_first __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_validate __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -132,6 +168,7 @@ static void
 set_graphemes(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL replace_count, ARGMOD(STRING *insert_string))
 {
+    ASSERT_ARGS(set_graphemes)
     ENCODING_SET_BYTES(interp, source_string, offset,
             replace_count, insert_string);
 }
@@ -151,6 +188,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 to_charset(PARROT_INTERP, ARGIN(STRING *src), ARGIN_NULLOK(STRING *dest))
 {
+    ASSERT_ARGS(to_charset)
     charset_converter_t conversion_func =
         Parrot_find_charset_converter(interp, src->charset, Parrot_binary_charset_ptr);
 
@@ -176,6 +214,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 compose(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(compose)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't compose binary data");
 }
 
@@ -194,6 +233,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 decompose(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(decompose)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't decompose binary data");
 }
 
@@ -211,6 +251,7 @@ upper case.
 static void
 upcase(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(upcase)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't upcase binary data");
 }
 
@@ -228,6 +269,7 @@ lower-case.
 static void
 downcase(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(downcase)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't downcase binary data");
 }
 
@@ -245,6 +287,7 @@ title case.
 static void
 titlecase(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(titlecase)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't titlecase binary data");
 }
 
@@ -262,6 +305,7 @@ binary string to uppercase.
 static void
 upcase_first(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(upcase_first)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't upcase binary data");
 }
 
@@ -279,6 +323,7 @@ of the binary string to lowercase.
 static void
 downcase_first(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(downcase_first)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't downcase binary data");
 }
 
@@ -296,6 +341,7 @@ of binary data to title case.
 static void
 titlecase_first(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(titlecase_first)
     EXCEPTION(EXCEPTION_INVALID_CHARTYPE, "Can't titlecase binary data");
 }
 
@@ -303,16 +349,22 @@ titlecase_first(PARROT_INTERP, SHIM(STRING *source_string))
 
 =item C<static INTVAL compare>
 
-Returns 0. We can't directly compare two binary buffers (yet).
+Compare the two buffers, first by size, then with memcmp.
 
 =cut
 
 */
 
 static INTVAL
-compare(SHIM_INTERP, SHIM(const STRING *lhs), SHIM(const STRING *rhs))
+compare(SHIM_INTERP, ARGIN(const STRING *lhs), ARGIN(const STRING *rhs))
 {
-    return 0;
+    ASSERT_ARGS(compare)
+    const UINTVAL l_len = lhs->strlen;
+    const UINTVAL r_len = rhs->strlen;
+    if (l_len != r_len)
+        return l_len - r_len;
+
+    return memcmp(lhs->strstart, rhs->strstart, l_len);
 }
 
 /*
@@ -330,6 +382,7 @@ static INTVAL
 cs_index(SHIM_INTERP, SHIM(STRING *source_string),
         SHIM(STRING *search_string), SHIM(UINTVAL offset))
 {
+    ASSERT_ARGS(cs_index)
     return -1;
 }
 
@@ -348,6 +401,7 @@ static INTVAL
 cs_rindex(SHIM_INTERP, SHIM(STRING *source_string),
         SHIM(STRING *search_string), SHIM(UINTVAL offset))
 {
+    ASSERT_ARGS(cs_rindex)
     return -1;
 }
 
@@ -365,6 +419,7 @@ Returns 1. All sequential data is valid binary data.
 static UINTVAL
 validate(SHIM_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(validate)
     return 1;
 }
 
@@ -382,6 +437,7 @@ static INTVAL
 is_cclass(SHIM_INTERP, SHIM(INTVAL flags), SHIM(const STRING *source_string),
         SHIM(UINTVAL offset))
 {
+    ASSERT_ARGS(is_cclass)
     return 0;
 }
 
@@ -399,6 +455,7 @@ static INTVAL
 find_cclass(SHIM_INTERP, SHIM(INTVAL flags),
             SHIM(STRING *source_string), UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(find_cclass)
     return offset + count;
 }
 
@@ -416,6 +473,7 @@ static INTVAL
 find_not_cclass(SHIM_INTERP, SHIM(INTVAL flags),
                SHIM(STRING *source_string), UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(find_not_cclass)
     return offset + count;
 }
 
@@ -433,6 +491,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 string_from_codepoint(PARROT_INTERP, UINTVAL codepoint)
 {
+    ASSERT_ARGS(string_from_codepoint)
     STRING *return_string;
     char real_codepoint = (char)codepoint;
     return_string = string_make(interp, &real_codepoint, 1, "binary", 0);
@@ -455,6 +514,7 @@ PARROT_CANNOT_RETURN_NULL
 const CHARSET *
 Parrot_charset_binary_init(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_charset_binary_init)
     CHARSET * const return_set = Parrot_new_charset(interp);
     static const CHARSET base_set = {
         "binary",
