@@ -1,7 +1,7 @@
 /* binary.h
  *  Copyright (C) 2004-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/src/charset/binary.h 27459 2008-05-12T02:15:12.435938Z petdance  $
+ *     $Id: /mirror/trunk/src/charset/binary.h 34889 2009-01-03T06:36:42.042670Z infinoid  $
  *  Overview:
  *     This is the header for the binary charset functions
  *  Data Structure and Algorithms:
@@ -20,6 +20,8 @@ PARROT_CANNOT_RETURN_NULL
 const CHARSET * Parrot_charset_binary_init(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_Parrot_charset_binary_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/charset/binary.c */
 
