@@ -1,7 +1,7 @@
 /* iso_8859_1.h
  *  Copyright (C) 2004-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: iso-8859-1.h 27452 2008-05-12 02:15:12Z petdance $
+ *     $Id: /mirror/trunk/src/charset/iso-8859-1.h 34890 2009-01-03T06:58:47.331194Z infinoid  $
  *  Overview:
  *     This is the header for the iso_8859-1 charset functions
  *  Data Structure and Algorithms:
@@ -22,12 +22,20 @@ STRING * charset_cvt_iso_8859_1_to_ascii(PARROT_INTERP,
     ARGIN(STRING *src),
     ARGMOD_NULLOK(STRING *dest))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
+        __attribute__nonnull__(2)
+        FUNC_MODIFIES(*dest);
 
 PARROT_CANNOT_RETURN_NULL
 const CHARSET * Parrot_charset_iso_8859_1_init(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_charset_cvt_iso_8859_1_to_ascii \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(src)
+#define ASSERT_ARGS_Parrot_charset_iso_8859_1_init \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/charset/iso-8859-1.c */
 
