@@ -1,7 +1,7 @@
 /* unicode.h
  *  Copyright (C) 2005-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/src/charset/unicode.h 27459 2008-05-12T02:15:12.435938Z petdance  $
+ *     $Id: /mirror/trunk/src/charset/unicode.h 34889 2009-01-03T06:36:42.042670Z infinoid  $
  *  Overview:
  *     This is the header for the unicode charset functions
  *  Data Structure and Algorithms:
@@ -25,6 +25,8 @@ PARROT_CANNOT_RETURN_NULL
 const CHARSET * Parrot_charset_unicode_init(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_Parrot_charset_unicode_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/charset/unicode.c */
 
