@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2002-2008, The Perl Foundation.
 License:  Artistic 2.0, see README and LICENSE for details
-$Id: /mirror/trunk/src/datatypes.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/datatypes.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -40,6 +40,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 Parrot_get_datatype_enum(PARROT_INTERP, ARGIN(const STRING *type_name))
 {
+    ASSERT_ARGS(Parrot_get_datatype_enum)
     char * const type = string_to_cstring(interp, type_name);
     int i;
 
@@ -71,6 +72,7 @@ PARROT_CANNOT_RETURN_NULL
 STRING *
 Parrot_get_datatype_name(PARROT_INTERP, INTVAL type)
 {
+    ASSERT_ARGS(Parrot_get_datatype_name)
     const char * const s =
         (type < enum_first_type || type >= enum_last_type)
             ? "illegal"
