@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/dynext.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/dynext.c 35819 2009-01-20T05:19:27.074079Z chromatic  $
 
 =head1 NAME
 
@@ -39,12 +39,11 @@ static STRING * clone_string_into(
 PARROT_WARN_UNUSED_RESULT
 PARROT_CAN_RETURN_NULL
 static STRING * get_path(PARROT_INTERP,
-    ARGMOD(STRING *lib),
+    ARGMOD_NULLOK(STRING *lib),
     ARGOUT(void **handle),
     ARGIN(STRING *wo_ext),
     ARGIN_NULLOK(STRING *ext))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
         __attribute__nonnull__(3)
         __attribute__nonnull__(4)
         FUNC_MODIFIES(*lib)
@@ -65,11 +64,10 @@ static PMC * make_string_pmc(PARROT_INTERP, ARGIN(STRING *string))
 PARROT_CANNOT_RETURN_NULL
 static PMC * run_init_lib(PARROT_INTERP,
     ARGIN(void *handle),
-    ARGIN(STRING *lib_name),
+    ARGIN_NULLOK(STRING *lib_name),
     ARGIN(STRING *wo_ext))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
-        __attribute__nonnull__(3)
         __attribute__nonnull__(4);
 
 static void set_cstring_prop(PARROT_INTERP,
@@ -86,13 +84,40 @@ static void store_lib_pmc(PARROT_INTERP,
     ARGIN(PMC *lib_pmc),
     ARGIN(STRING *path),
     ARGIN(STRING *type),
-    ARGIN(STRING *lib_name))
+    ARGIN_NULLOK(STRING *lib_name))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
         __attribute__nonnull__(3)
-        __attribute__nonnull__(4)
-        __attribute__nonnull__(5);
+        __attribute__nonnull__(4);
 
+#define ASSERT_ARGS_clone_string_into __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(d) \
+    || PARROT_ASSERT_ARG(s) \
+    || PARROT_ASSERT_ARG(value)
+#define ASSERT_ARGS_get_path __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(handle) \
+    || PARROT_ASSERT_ARG(wo_ext)
+#define ASSERT_ARGS_is_loaded __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(path)
+#define ASSERT_ARGS_make_string_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(string)
+#define ASSERT_ARGS_run_init_lib __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(handle) \
+    || PARROT_ASSERT_ARG(wo_ext)
+#define ASSERT_ARGS_set_cstring_prop __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(lib_pmc) \
+    || PARROT_ASSERT_ARG(what) \
+    || PARROT_ASSERT_ARG(name)
+#define ASSERT_ARGS_store_lib_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(lib_pmc) \
+    || PARROT_ASSERT_ARG(path) \
+    || PARROT_ASSERT_ARG(type)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -114,6 +139,7 @@ static void
 set_cstring_prop(PARROT_INTERP, ARGMOD(PMC *lib_pmc), ARGIN(const char *what),
         ARGIN(STRING *name))
 {
+    ASSERT_ARGS(set_cstring_prop)
     STRING * const key  = const_string(interp, what);
     PMC    * const prop = constant_pmc_new(interp, enum_class_String);
 
@@ -133,8 +159,9 @@ Store a C<ParrotLibrary> PMC in the interpreter's C<iglobals>.
 
 static void
 store_lib_pmc(PARROT_INTERP, ARGIN(PMC *lib_pmc), ARGIN(STRING *path),
-        ARGIN(STRING *type), ARGIN(STRING *lib_name))
+        ARGIN(STRING *type), ARGIN_NULLOK(STRING *lib_name))
 {
+    ASSERT_ARGS(store_lib_pmc)
     PMC * const iglobals = interp->iglobals;
     PMC * const dyn_libs = VTABLE_get_pmc_keyed_int(interp, iglobals,
             IGLOBALS_DYN_LIBS);
@@ -165,6 +192,7 @@ PARROT_CAN_RETURN_NULL
 static PMC*
 is_loaded(PARROT_INTERP, ARGIN(STRING *path))
 {
+    ASSERT_ARGS(is_loaded)
     PMC * const iglobals = interp->iglobals;
     PMC * const dyn_libs = VTABLE_get_pmc_keyed_int(interp, iglobals,
             IGLOBALS_DYN_LIBS);
@@ -187,9 +215,10 @@ Return path and handle of a dynamic lib, setting lib_name to just the filestem
 PARROT_WARN_UNUSED_RESULT
 PARROT_CAN_RETURN_NULL
 static STRING *
-get_path(PARROT_INTERP, ARGMOD(STRING *lib), ARGOUT(void **handle),
+get_path(PARROT_INTERP, ARGMOD_NULLOK(STRING *lib), ARGOUT(void **handle),
         ARGIN(STRING *wo_ext), ARGIN_NULLOK(STRING *ext))
 {
+    ASSERT_ARGS(get_path)
     STRING *path, *full_name;
     const char *err = NULL;    /* buffer returned from Parrot_dlerror */
 
@@ -311,6 +340,7 @@ Parrot_init_lib(PARROT_INTERP,
                 ARGIN_NULLOK(PMC *(*load_func)(PARROT_INTERP)),
                 ARGIN_NULLOK(void (*init_func)(PARROT_INTERP, ARGIN_NULLOK(PMC *))))
 {
+    ASSERT_ARGS(Parrot_init_lib)
     PMC *lib_pmc = NULL;
 
     if (load_func)
@@ -342,12 +372,12 @@ Calls the necessary initialization routines, if any.
 PARROT_CANNOT_RETURN_NULL
 static PMC *
 run_init_lib(PARROT_INTERP, ARGIN(void *handle),
-        ARGIN(STRING *lib_name), ARGIN(STRING *wo_ext))
+        ARGIN_NULLOK(STRING *lib_name), ARGIN(STRING *wo_ext))
 {
+    ASSERT_ARGS(run_init_lib)
     STRING *type;
     PMC *(*load_func)(PARROT_INTERP);
     void (*init_func)(PARROT_INTERP, PMC *);
-    char *cinit_func_name;
     PMC *lib_pmc;
 
     /*
@@ -356,24 +386,22 @@ run_init_lib(PARROT_INTERP, ARGIN(void *handle),
      */
     Parrot_block_GC_mark(interp);
 
-    /* get load_func */
     if (lib_name) {
-        STRING * const load_func_name = Parrot_sprintf_c(interp,
+        STRING * const load_name       = Parrot_sprintf_c(interp,
                                         "Parrot_lib_%Ss_load", lib_name);
-        char * const cload_func_name = string_to_cstring(interp, load_func_name);
-        STRING *init_func_name;
-
-        load_func    = (PMC * (*)(PARROT_INTERP))
-            (Parrot_dlsym(handle, cload_func_name));
+        STRING * const init_func_name  = Parrot_sprintf_c(interp,
+                                        "Parrot_lib_%Ss_init", lib_name);
+        char   * const cload_func_name = string_to_cstring(interp, load_name);
+        char   * const cinit_func_name = string_to_cstring(interp, init_func_name);
 
+        /* get load_func */
+        load_func       = (PMC * (*)(PARROT_INTERP))
+            D2FPTR(Parrot_dlsym(handle, cload_func_name));
         string_cstring_free(cload_func_name);
 
         /* get init_func */
-        init_func_name  = Parrot_sprintf_c(interp, "Parrot_lib_%Ss_init",
-                                          lib_name);
-        cinit_func_name = string_to_cstring(interp, init_func_name);
-        init_func      = (void (*)(PARROT_INTERP, PMC *))(Parrot_dlsym(handle,
-                    cinit_func_name));
+        init_func       = (void (*)(PARROT_INTERP, PMC *))
+            D2FPTR(Parrot_dlsym(handle, cinit_func_name));
         string_cstring_free(cinit_func_name);
     }
     else {
@@ -422,9 +450,10 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 clone_string_into(ARGMOD(Interp *d), ARGIN(Interp *s), ARGIN(PMC *value))
 {
-    STRING * const orig = VTABLE_get_string(s, value);
-    char * const raw_str = string_to_cstring(s, orig);
-    STRING * const ret =
+    ASSERT_ARGS(clone_string_into)
+    STRING * const  orig   = VTABLE_get_string(s, value);
+    char   * const raw_str = string_to_cstring(s, orig);
+    STRING * const   ret   =
         string_make_direct(d, raw_str, strlen(raw_str),
             PARROT_DEFAULT_ENCODING, PARROT_DEFAULT_CHARSET,
             PObj_constant_FLAG);
@@ -447,7 +476,8 @@ PARROT_CANNOT_RETURN_NULL
 static PMC *
 make_string_pmc(PARROT_INTERP, ARGIN(STRING *string))
 {
-    PMC * const ret = VTABLE_new_from_string(interp,
+    ASSERT_ARGS(make_string_pmc)
+    PMC * const ret = VTABLE_instantiate_str(interp,
         interp->vtables[enum_class_String]->pmc_class,
         string, PObj_constant_FLAG);
     return ret;
@@ -470,14 +500,19 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 Parrot_clone_lib_into(ARGMOD(Interp *d), ARGMOD(Interp *s), ARGIN(PMC *lib_pmc))
 {
+    ASSERT_ARGS(Parrot_clone_lib_into)
+    STRING * const filename = CONST_STRING(s, "_filename");
+    STRING * const libname  = CONST_STRING(s, "_lib_name");
+    STRING * const type_str = CONST_STRING(s, "_type");
+    STRING * const ops      = CONST_STRING(s, "Ops");
+
     STRING * const wo_ext = clone_string_into(d, s,
-        VTABLE_getprop(s, lib_pmc, CONST_STRING(s, "_filename")));
+        VTABLE_getprop(s, lib_pmc, filename));
     STRING * const lib_name = clone_string_into(d, s,
-        VTABLE_getprop(s, lib_pmc, CONST_STRING(s, "_lib_name")));
+        VTABLE_getprop(s, lib_pmc, libname));
     void * const handle = PMC_data(lib_pmc);
     STRING * const type =
-        VTABLE_get_string(s, VTABLE_getprop(s, lib_pmc, CONST_STRING(s, "_type")));
-    STRING * const ops  = CONST_STRING(s, "Ops");
+        VTABLE_get_string(s, VTABLE_getprop(s, lib_pmc, type_str));
 
     if (!string_equal(s, type, ops)) {
         /* we can't clone oplibs in the normal way, since they're actually
@@ -545,6 +580,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 Parrot_load_lib(PARROT_INTERP, ARGIN_NULLOK(STRING *lib), SHIM(PMC *initializer))
 {
+    ASSERT_ARGS(Parrot_load_lib)
     void   *handle;
     PMC    *lib_pmc;
     STRING *path;
