@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/embed.c 33941 2008-12-15T05:08:57.768251Z cotto  $
+$Id: /mirror/trunk/src/embed.c 35758 2009-01-18T22:33:50.020854Z julianalbo  $
 
 =head1 NAME
 
@@ -53,6 +53,22 @@ static PMC* setup_argv(PARROT_INTERP, int argc, ARGIN(char **argv))
         __attribute__nonnull__(1)
         __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_calibrate __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_op_name __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_print_debug __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_print_profile __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_prof_sort_f __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(a) \
+    || PARROT_ASSERT_ARG(b)
+#define ASSERT_ARGS_set_current_sub __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_setup_argv __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(argv)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -575,9 +591,11 @@ PARROT_CANNOT_RETURN_NULL
 static PMC*
 setup_argv(PARROT_INTERP, int argc, ARGIN(char **argv))
 {
+    ASSERT_ARGS(setup_argv)
     INTVAL i;
     PMC   *userargv;
 
+
     if (Interp_debug_TEST(interp, PARROT_START_DEBUG_FLAG)) {
         Parrot_io_eprintf(interp,
             "*** Parrot VM: Setting up ARGV array.  Current argc: %d ***\n",
@@ -621,6 +639,7 @@ Sort function for profile data. Sorts by time.
 static int
 prof_sort_f(ARGIN(const void *a), ARGIN(const void *b))
 {
+    ASSERT_ARGS(prof_sort_f)
     const FLOATVAL timea = ((const ProfData *)a)->time;
     const FLOATVAL timeb = ((const ProfData *)b)->time;
 
@@ -648,6 +667,7 @@ PARROT_CANNOT_RETURN_NULL
 static const char *
 op_name(PARROT_INTERP, int k)
 {
+    ASSERT_ARGS(op_name)
     switch (k) {
         case PARROT_PROF_DOD_p1:
             return "DOD_mark_root";
@@ -683,6 +703,7 @@ measured with time C<parrot -b>.
 static FLOATVAL
 calibrate(PARROT_INTERP)
 {
+    ASSERT_ARGS(calibrate)
     size_t   count  = 1000000;
     size_t   n      = count;
     opcode_t code[] = { 1 };      /* noop */
@@ -713,6 +734,7 @@ Prints out a profile listing.
 static void
 print_profile(PARROT_INTERP, SHIM(int status), SHIM(void *p))
 {
+    ASSERT_ARGS(print_profile)
     RunProfile * const profile = interp->profile;
 
     if (profile) {
@@ -796,6 +818,7 @@ Prints GC info.
 static void
 print_debug(PARROT_INTERP, SHIM(int status), SHIM(void *p))
 {
+    ASSERT_ARGS(print_debug)
     if (Interp_debug_TEST(interp, PARROT_MEM_STAT_DEBUG_FLAG)) {
         /* Give souls brave enough to activate debugging an earful about GC. */
 
@@ -823,6 +846,7 @@ PARROT_CANNOT_RETURN_NULL
 static PMC*
 set_current_sub(PARROT_INTERP)
 {
+    ASSERT_ARGS(set_current_sub)
     opcode_t i;
     PMC *sub_pmc;
 
@@ -1053,7 +1077,7 @@ Parrot_disassemble(PARROT_INTERP)
         if (debugs && curr_mapping < num_mappings) {
             if (op_code_seq_num == interp->code->debugs->mappings[curr_mapping]->offset) {
                 const int filename_const_offset =
-                    interp->code->debugs->mappings[curr_mapping]->u.filename;
+                    interp->code->debugs->mappings[curr_mapping]->filename;
                 Parrot_io_printf(interp, "Current Source Filename %Ss\n",
                         interp->code->const_table->constants[filename_const_offset]->u.string);
                 curr_mapping++;
