@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/encoding.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/encoding.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -31,6 +31,10 @@ static INTVAL register_encoding(PARROT_INTERP,
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_register_encoding __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(encodingname) \
+    || PARROT_ASSERT_ARG(encoding)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -66,6 +70,7 @@ C<all_encodings> array.
 void
 parrot_init_encodings_2(void)
 {
+    ASSERT_ARGS(parrot_init_encodings_2)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -87,6 +92,7 @@ Deinitialize encodings and free all memory used by them.
 void
 parrot_deinit_encodings(void)
 {
+    ASSERT_ARGS(parrot_deinit_encodings)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -114,6 +120,7 @@ PARROT_CANNOT_RETURN_NULL
 ENCODING *
 Parrot_new_encoding(SHIM_INTERP)
 {
+    ASSERT_ARGS(Parrot_new_encoding)
     return mem_allocate_typed(ENCODING);
 }
 
@@ -134,6 +141,7 @@ PARROT_CAN_RETURN_NULL
 const ENCODING *
 Parrot_find_encoding(SHIM_INTERP, ARGIN(const char *encodingname))
 {
+    ASSERT_ARGS(Parrot_find_encoding)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -148,7 +156,7 @@ Parrot_find_encoding(SHIM_INTERP, ARGIN(const char *encodingname))
 =item C<const ENCODING * Parrot_load_encoding>
 
 Loads an encoding. Currently throws an exception because we cannot load
-encodings. See RT#58186.
+encodings. See RT #58186.
 
 =cut
 
@@ -156,14 +164,19 @@ encodings. See RT#58186.
 
 /* Yep, this needs to be a char * parameter -- it's tough to load in
    encodings and such for strings if we can't be sure we've got enough
-   info set up to actually build strings... */
+   info set up to actually build strings...
+
+    Also remember to use PARROT_WARN_UNUSED_RESULT and
+    PARROT_CANNOT_RETURN_NULL when this actually works.
+ */
 
 PARROT_EXPORT
-PARROT_WARN_UNUSED_RESULT
+PARROT_DOES_NOT_RETURN
 PARROT_CANNOT_RETURN_NULL
 const ENCODING *
 Parrot_load_encoding(PARROT_INTERP, ARGIN(const char *encodingname))
 {
+    ASSERT_ARGS(Parrot_load_encoding)
     UNUSED(encodingname);
     Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
         "Can't load encodings yet");
@@ -184,6 +197,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 Parrot_encoding_number(PARROT_INTERP, ARGIN(const STRING *encodingname))
 {
+    ASSERT_ARGS(Parrot_encoding_number)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -210,6 +224,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 Parrot_encoding_number_of_str(SHIM_INTERP, ARGIN(const STRING *src))
 {
+    ASSERT_ARGS(Parrot_encoding_number_of_str)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -237,6 +252,7 @@ PARROT_CAN_RETURN_NULL
 STRING*
 Parrot_encoding_name(SHIM_INTERP, INTVAL number_of_encoding)
 {
+    ASSERT_ARGS(Parrot_encoding_name)
     if (number_of_encoding >= all_encodings->n_encodings)
         return NULL;
     return all_encodings->enc[number_of_encoding].name;
@@ -258,6 +274,7 @@ PARROT_CAN_RETURN_NULL
 const ENCODING*
 Parrot_get_encoding(SHIM_INTERP, INTVAL number_of_encoding)
 {
+    ASSERT_ARGS(Parrot_get_encoding)
     if (number_of_encoding >= all_encodings->n_encodings)
         return NULL;
     return all_encodings->enc[number_of_encoding].encoding;
@@ -280,6 +297,7 @@ PARROT_CAN_RETURN_NULL
 const char *
 Parrot_encoding_c_name(SHIM_INTERP, INTVAL number_of_encoding)
 {
+    ASSERT_ARGS(Parrot_encoding_c_name)
     if (number_of_encoding >= all_encodings->n_encodings)
         return NULL;
     return all_encodings->enc[number_of_encoding].encoding->name;
@@ -300,6 +318,7 @@ static INTVAL
 register_encoding(PARROT_INTERP, ARGIN(const char *encodingname),
         ARGIN(ENCODING *encoding))
 {
+    ASSERT_ARGS(register_encoding)
     const int n = all_encodings->n_encodings;
     int i;
 
@@ -340,6 +359,7 @@ INTVAL
 Parrot_register_encoding(PARROT_INTERP, ARGIN(const char *encodingname),
         ARGIN(ENCODING *encoding))
 {
+    ASSERT_ARGS(Parrot_register_encoding)
     if (!all_encodings) {
         all_encodings = mem_allocate_typed(All_encodings);
         all_encodings->n_encodings = 0;
@@ -383,6 +403,7 @@ INTVAL
 Parrot_make_default_encoding(SHIM_INTERP, SHIM(const char *encodingname),
         ARGIN(ENCODING *encoding))
 {
+    ASSERT_ARGS(Parrot_make_default_encoding)
     Parrot_default_encoding_ptr = encoding;
     return 1;
 }
@@ -403,6 +424,7 @@ PARROT_CANNOT_RETURN_NULL
 const ENCODING *
 Parrot_default_encoding(SHIM_INTERP)
 {
+    ASSERT_ARGS(Parrot_default_encoding)
     return Parrot_default_encoding_ptr;
 }
 
@@ -418,13 +440,15 @@ throws an exception.
 */
 
 PARROT_EXPORT
+PARROT_DOES_NOT_RETURN
 encoding_converter_t
 Parrot_find_encoding_converter(PARROT_INTERP, ARGIN(ENCODING *lhs), ARGIN(ENCODING *rhs))
 {
+    ASSERT_ARGS(Parrot_find_encoding_converter)
     UNUSED(lhs);
     UNUSED(rhs);
 
-    /* XXX Apparently unwritten RT#58188 */
+    /* XXX Apparently unwritten RT #58188 */
     Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
         "Can't find encoding converters yet.");
 }
