@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2004-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/encodings/fixed_8.c 29983 2008-08-02T22:45:13.271765Z allison  $
+$Id: /mirror/trunk/src/encodings/fixed_8.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -156,6 +156,60 @@ static STRING * to_encoding(PARROT_INTERP,
     SHIM(STRING *dest))
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_become_encoding __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_bytes __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_codepoints __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_fixed8_get_next __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(iter)
+#define ASSERT_ARGS_fixed8_set_next __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(iter)
+#define ASSERT_ARGS_fixed8_set_position __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(iter)
+#define ASSERT_ARGS_get_byte __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_get_bytes __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_get_bytes_inplace __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(return_string)
+#define ASSERT_ARGS_get_codepoint __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_get_codepoints __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_get_codepoints_inplace __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(dest_string)
+#define ASSERT_ARGS_iter_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(src) \
+    || PARROT_ASSERT_ARG(iter)
+#define ASSERT_ARGS_set_byte __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_set_bytes __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(new_bytes)
+#define ASSERT_ARGS_set_codepoint __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string)
+#define ASSERT_ARGS_set_codepoints __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(source_string) \
+    || PARROT_ASSERT_ARG(new_codepoints)
+#define ASSERT_ARGS_to_encoding __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -180,6 +234,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 to_encoding(PARROT_INTERP, SHIM(STRING *src), SHIM(STRING *dest))
 {
+    ASSERT_ARGS(to_encoding)
     UNIMPL;
 }
 
@@ -199,6 +254,7 @@ static UINTVAL
 get_codepoint(PARROT_INTERP, ARGIN(const STRING *source_string),
         UINTVAL offset)
 {
+    ASSERT_ARGS(get_codepoint)
     return get_byte(interp, source_string, offset);
 }
 
@@ -216,6 +272,7 @@ static void
 set_codepoint(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL codepoint)
 {
+    ASSERT_ARGS(set_codepoint)
     set_byte(interp, source_string, offset, codepoint);
 }
 
@@ -233,6 +290,7 @@ PARROT_WARN_UNUSED_RESULT
 static UINTVAL
 get_byte(PARROT_INTERP, ARGIN(const STRING *source_string), UINTVAL offset)
 {
+    ASSERT_ARGS(get_byte)
     unsigned char *contents = (unsigned char *)source_string->strstart;
 
     if (offset >= source_string->bufused) {
@@ -259,6 +317,7 @@ static void
 set_byte(PARROT_INTERP, ARGIN(const STRING *source_string),
         UINTVAL offset, UINTVAL byte)
 {
+    ASSERT_ARGS(set_byte)
     unsigned char *contents;
 
     if (offset >= source_string->bufused)
@@ -286,6 +345,7 @@ static STRING *
 get_codepoints(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(get_codepoints)
     STRING * const return_string = get_bytes(interp, source_string,
             offset, count);
     return_string->charset = source_string->charset;
@@ -308,6 +368,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING *
 get_bytes(PARROT_INTERP, ARGIN(STRING *source_string), UINTVAL offset, UINTVAL count)
 {
+    ASSERT_ARGS(get_bytes)
     STRING * const return_string = Parrot_make_COW_reference(interp,
             source_string);
     return_string->encoding = source_string->encoding;
@@ -340,7 +401,7 @@ static STRING *
 get_codepoints_inplace(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count, ARGMOD(STRING *dest_string))
 {
-
+    ASSERT_ARGS(get_codepoints_inplace)
     return get_bytes_inplace(interp, source_string, offset,
             count, dest_string);
 }
@@ -362,6 +423,7 @@ static STRING *
 get_bytes_inplace(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count, ARGMOD(STRING *return_string))
 {
+    ASSERT_ARGS(get_bytes_inplace)
     Parrot_reuse_COW_reference(interp, source_string, return_string);
 
     return_string->strstart = (char *)return_string->strstart + offset ;
@@ -387,6 +449,7 @@ static void
 set_codepoints(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count, ARGMOD(STRING *new_codepoints))
 {
+    ASSERT_ARGS(set_codepoints)
     set_bytes(interp, source_string, offset, count, new_codepoints);
 }
 
@@ -405,6 +468,7 @@ static void
 set_bytes(PARROT_INTERP, ARGIN(STRING *source_string),
         UINTVAL offset, UINTVAL count, ARGMOD(STRING *new_bytes))
 {
+    ASSERT_ARGS(set_bytes)
     string_replace(interp, source_string, offset, count, new_bytes, NULL);
 }
 
@@ -421,6 +485,7 @@ Unconditionally makes the string be in this encoding, if that's valid
 static void
 become_encoding(PARROT_INTERP, SHIM(STRING *source_string))
 {
+    ASSERT_ARGS(become_encoding)
     UNIMPL;
 }
 
@@ -438,6 +503,7 @@ Returns the number of codepoints in string C<src>.
 static UINTVAL
 codepoints(PARROT_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(codepoints)
     return bytes(interp, source_string);
 }
 
@@ -454,6 +520,7 @@ Returns the number of bytes in string C<src>.
 static UINTVAL
 bytes(SHIM_INTERP, ARGIN(STRING *source_string))
 {
+    ASSERT_ARGS(bytes)
     return source_string->bufused;
 }
 
@@ -474,6 +541,7 @@ Moves the string iterator C<i> to the next codepoint.
 static UINTVAL
 fixed8_get_next(PARROT_INTERP, ARGMOD(String_iter *iter))
 {
+    ASSERT_ARGS(fixed8_get_next)
     const UINTVAL c = get_byte(interp, iter->str, iter->charpos++);
     iter->bytepos++;
     return c;
@@ -493,6 +561,7 @@ next position in the string.
 static void
 fixed8_set_next(PARROT_INTERP, ARGMOD(String_iter *iter), UINTVAL c)
 {
+    ASSERT_ARGS(fixed8_set_next)
     set_byte(interp, iter->str, iter->charpos++, c);
     iter->bytepos++;
 }
@@ -510,6 +579,7 @@ Moves the string iterator C<i> to the position C<n> in the string.
 static void
 fixed8_set_position(SHIM_INTERP, ARGMOD(String_iter *iter), UINTVAL pos)
 {
+    ASSERT_ARGS(fixed8_set_position)
     iter->bytepos = iter->charpos = pos;
     PARROT_ASSERT(pos <= PObj_buflen(iter->str));
 }
@@ -528,6 +598,7 @@ Initializes for string C<src> the string iterator C<iter>.
 static void
 iter_init(SHIM_INTERP, ARGIN(const STRING *src), ARGOUT(String_iter *iter))
 {
+    ASSERT_ARGS(iter_init)
     iter->str             = src;
     iter->bytepos         = iter->charpos        = 0;
     iter->get_and_advance = fixed8_get_next;
@@ -549,6 +620,7 @@ PARROT_CANNOT_RETURN_NULL
 ENCODING *
 Parrot_encoding_fixed_8_init(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_encoding_fixed_8_init)
     ENCODING * const return_encoding = Parrot_new_encoding(interp);
 
     ENCODING base_encoding = {
