@@ -1,7 +1,7 @@
 /* utf8.h
  *  Copyright (C) 2004-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: utf8.h 27452 2008-05-12 02:15:12Z petdance $
+ *     $Id: /mirror/trunk/src/encodings/utf8.h 34889 2009-01-03T06:36:42.042670Z infinoid  $
  *  Overview:
  *     This is the header for the utf8 variable-width encoding.
  *  Data Structure and Algorithms:
@@ -20,6 +20,8 @@ PARROT_CANNOT_RETURN_NULL
 ENCODING * Parrot_encoding_utf8_init(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_Parrot_encoding_utf8_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/encodings/utf8.c */
 
