@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/exit.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/exit.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -40,6 +40,7 @@ PARROT_EXPORT
 void
 Parrot_on_exit(PARROT_INTERP, NOTNULL(exit_handler_f function), ARGIN_NULLOK(void *arg))
 {
+    ASSERT_ARGS(Parrot_on_exit)
     /* RT#46403  we might want locking around the list access.   I'm sure this
      * will be the least of the threading issues. */
 
@@ -66,6 +67,7 @@ PARROT_DOES_NOT_RETURN
 void
 Parrot_exit(PARROT_INTERP, int status)
 {
+    ASSERT_ARGS(Parrot_exit)
     /* call all the exit handlers */
     /* we are well "below" the runloop now, where lo_var_ptr
      * is set usually - exit handlers may run some resource-hungry
