@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/gc/memory.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/gc/memory.c 35806 2009-01-19T22:31:16.548456Z infinoid  $
 
 =head1 NAME
 
@@ -43,6 +43,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem_sys_allocate(size_t size)
 {
+    ASSERT_ARGS(mem_sys_allocate)
     void * const ptr = malloc(size);
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Allocated %i at %p\n", size, ptr);
@@ -69,6 +70,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem__internal_allocate(size_t size, ARGIN(const char *file), int line)
 {
+    ASSERT_ARGS(mem__internal_allocate)
     void * const ptr = malloc((size_t)size);
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Internal malloc %i at %p (%s/%d)\n",
@@ -99,6 +101,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem_sys_allocate_zeroed(size_t size)
 {
+    ASSERT_ARGS(mem_sys_allocate_zeroed)
     void * const ptr = calloc(1, (size_t)size);
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Allocated %i at %p\n", size, ptr);
@@ -125,6 +128,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem__internal_allocate_zeroed(size_t size, ARGIN(const char *file), int line)
 {
+    ASSERT_ARGS(mem__internal_allocate_zeroed)
     void * const ptr = calloc(1, (size_t)size);
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Internal malloc %i at %p (%s/%d)\n",
@@ -156,6 +160,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem_sys_realloc(ARGFREE(void *from), size_t size)
 {
+    ASSERT_ARGS(mem_sys_realloc)
     void *ptr;
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Freed %p (realloc -- %i bytes)\n", from, size);
@@ -191,6 +196,7 @@ PARROT_CANNOT_RETURN_NULL
 void *
 mem_sys_realloc_zeroed(ARGFREE(void *from), size_t size, size_t old_size)
 {
+    ASSERT_ARGS(mem_sys_realloc_zeroed)
     void *ptr;
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Freed %p (realloc -- %i bytes)\n", from, size);
@@ -227,6 +233,7 @@ void *
 mem__internal_realloc(ARGFREE(void *from), size_t size,
         ARGIN(const char *file), int line)
 {
+    ASSERT_ARGS(mem__internal_realloc)
     void * const ptr = realloc(from, size);
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "internal free of %p (realloc -- %i bytes) (%s/%d)\n",
@@ -263,6 +270,7 @@ void *
 mem__internal_realloc_zeroed(ARGFREE(void *from), size_t size, size_t old_size,
     ARGIN(const char *file), int line)
 {
+    ASSERT_ARGS(mem__internal_realloc_zeroed)
     void * const ptr = realloc(from, size);
 #  ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "internal free of %p (realloc -- %i bytes) (%s/%d)\n",
@@ -297,6 +305,7 @@ PARROT_EXPORT
 void
 mem_sys_free(ARGFREE(void *from))
 {
+    ASSERT_ARGS(mem_sys_free)
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Freed %p\n", from);
 #endif
@@ -319,6 +328,7 @@ C<STDERR>.
 void
 mem__internal_free(ARGFREE(void *from), ARGIN(const char *file), int line)
 {
+    ASSERT_ARGS(mem__internal_free)
 #ifdef DETAIL_MEMORY_DEBUG
     fprintf(stderr, "Internal free of %p (%s/%d)\n", from, file, line);
 #else
@@ -336,16 +346,22 @@ Initializes the memory allocator and the garbage collection subsystem.
 Calls the initialization function associated with each collector, which
 is determined at compile time.
 
+The "stacktop" parameter is required; it provides an upper bound for
+stack scanning during a garbage collection run.
+
 =cut
 
 */
 
 void
-mem_setup_allocator(PARROT_INTERP)
+mem_setup_allocator(PARROT_INTERP, ARGIN(void *stacktop))
 {
+    ASSERT_ARGS(mem_setup_allocator)
     interp->arena_base = mem_allocate_zeroed_typed(Arenas);
     interp->arena_base->sized_header_pools = NULL;
 
+    interp->lo_var_ptr = stacktop;
+
 #if PARROT_GC_MS
     Parrot_gc_ms_init(interp);
 #endif
