@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/inter_call.c 33154 2008-11-24T00:31:21.469398Z chromatic  $
+$Id: /mirror/trunk/src/inter_call.c 35699 2009-01-17T09:12:33.923488Z cotto  $
 
 =head1 NAME
 
@@ -170,12 +170,11 @@ static const char * set_context_sig_params(PARROT_INTERP,
 static void set_context_sig_returns(PARROT_INTERP,
     ARGMOD(Parrot_Context *ctx),
     ARGMOD(opcode_t **indexes),
-    ARGIN(const char *ret_x),
+    ARGIN_NULLOK(const char *ret_x),
     ARGMOD(PMC *result_list))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
         __attribute__nonnull__(3)
-        __attribute__nonnull__(4)
         __attribute__nonnull__(5)
         FUNC_MODIFIES(*ctx)
         FUNC_MODIFIES(*indexes)
@@ -230,6 +229,102 @@ static void too_many(PARROT_INTERP,
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_check_for_opt_flag __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_check_named __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_clone_key_arg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_commit_last_arg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(n_regs_used) \
+    || PARROT_ASSERT_ARG(sigs) \
+    || PARROT_ASSERT_ARG(indexes) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_commit_last_arg_sig_object __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(n_regs_used) \
+    || PARROT_ASSERT_ARG(sigs) \
+    || PARROT_ASSERT_ARG(indexes) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(sig_obj)
+#define ASSERT_ARGS_convert_arg_from_int __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_convert_arg_from_num __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_convert_arg_from_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_convert_arg_from_str __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_count_signature_elements __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(signature) \
+    || PARROT_ASSERT_ARG(args_sig) \
+    || PARROT_ASSERT_ARG(results_sig)
+#define ASSERT_ARGS_fetch_arg_op __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_fetch_arg_sig __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_init_call_stats __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_init_first_dest_named __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_locate_named_named __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_next_arg_sig __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(sti)
+#define ASSERT_ARGS_null_val __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_set_context_sig_params __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(signature) \
+    || PARROT_ASSERT_ARG(n_regs_used) \
+    || PARROT_ASSERT_ARG(sigs) \
+    || PARROT_ASSERT_ARG(indexes) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(sig_obj)
+#define ASSERT_ARGS_set_context_sig_returns __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(indexes) \
+    || PARROT_ASSERT_ARG(result_list)
+#define ASSERT_ARGS_set_context_sig_returns_varargs \
+     __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(indexes) \
+    || PARROT_ASSERT_ARG(ret_x) \
+    || PARROT_ASSERT_ARG(returns)
+#define ASSERT_ARGS_set_retval_util __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sig) \
+    || PARROT_ASSERT_ARG(ctx) \
+    || PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_start_flatten __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st) \
+    || PARROT_ASSERT_ARG(p_arg)
+#define ASSERT_ARGS_store_arg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(st)
+#define ASSERT_ARGS_too_few __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st) \
+    || PARROT_ASSERT_ARG(action)
+#define ASSERT_ARGS_too_many __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(st) \
+    || PARROT_ASSERT_ARG(action)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -264,6 +359,7 @@ void
 Parrot_init_arg_nci(PARROT_INTERP, ARGOUT(call_state *st),
     ARGIN(const char *sig))
 {
+    ASSERT_ARGS(Parrot_init_arg_nci)
     init_call_stats(st);
 
     if (PMC_IS_NULL(interp->args_signature))
@@ -292,6 +388,7 @@ PARROT_EXPORT
 void
 Parrot_init_ret_nci(PARROT_INTERP, ARGOUT(call_state *st), ARGIN(const char *sig))
 {
+    ASSERT_ARGS(Parrot_init_ret_nci)
     Parrot_Context *ctx                 = CONTEXT(interp);
     PMC            * const current_cont = ctx->current_cont;
 
@@ -333,9 +430,10 @@ These functions return 0 if no arguments are present, or 1 on success.
 PARROT_EXPORT
 int
 Parrot_init_arg_indexes_and_sig_pmc(SHIM_INTERP, ARGIN(Parrot_Context *ctx),
-        ARGIN_NULLOK(opcode_t *indexes), ARGIN_NULLOK(PMC* sig_pmc),
+        ARGIN_NULLOK(opcode_t *indexes), ARGIN_NULLOK(PMC *sig_pmc),
         ARGMOD(call_state_item *sti))
 {
+    ASSERT_ARGS(Parrot_init_arg_indexes_and_sig_pmc)
     if (!sig_pmc && indexes) {
         ++indexes;
         sig_pmc = ctx->constants[*indexes]->u.key;
@@ -382,6 +480,7 @@ int
 Parrot_init_arg_op(PARROT_INTERP, ARGIN(Parrot_Context *ctx),
     ARGIN_NULLOK(opcode_t *pc), ARGIN(call_state_item *sti))
 {
+    ASSERT_ARGS(Parrot_init_arg_op)
     PMC *sig_pmc = PMCNULL;
 
     if (pc) {
@@ -412,6 +511,7 @@ Parrot_init_arg_sig(SHIM_INTERP, ARGIN(Parrot_Context *ctx),
     ARGIN(const char *sig), ARGIN_NULLOK(void *ap),
     ARGMOD(call_state_item *sti))
 {
+    ASSERT_ARGS(Parrot_init_arg_sig)
     sti->used = 1;
     sti->i    = 0;
     sti->n    = 0;
@@ -447,6 +547,7 @@ fetches the first arg from the flattened set.
 static void
 start_flatten(PARROT_INTERP, ARGMOD(call_state *st), ARGIN(PMC *p_arg))
 {
+    ASSERT_ARGS(start_flatten)
     if (PARROT_ARG_NAME_ISSET(st->src.sig)) {
 
         /* src ought to be an hash */
@@ -458,8 +559,6 @@ start_flatten(PARROT_INTERP, ARGMOD(call_state *st), ARGIN(PMC *p_arg))
         st->key              = pmc_new(interp, enum_class_Key);
         PMC_int_val(st->key) = 0;
         PMC_data(st->key)    = (void *)INITBucketIndex;
-
-        dod_register_pmc(interp, st->key);
     }
     else {
         /* src ought to be an array */
@@ -492,6 +591,7 @@ type of argument/parameter to get next.  The index gets increased elsewhere.
 static void
 next_arg_sig(ARGMOD(call_state_item *sti))
 {
+    ASSERT_ARGS(next_arg_sig)
     switch (sti->mode & CALL_S_D_MASK) {
         case CALL_STATE_OP:
             sti->sig = SIG_ITEM(sti->u.op.signature, sti->i);
@@ -534,6 +634,7 @@ Fetches the next argument from the signature in the given call state.
 static int
 fetch_arg_sig(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(fetch_arg_sig)
     va_list * const ap = (va_list *)(st->src.u.sig.ap);
 
     switch (st->src.sig & PARROT_ARG_TYPE_MASK) {
@@ -551,7 +652,6 @@ fetch_arg_sig(PARROT_INTERP, ARGMOD(call_state *st))
                 UVal_pmc(st->val) = CONTEXT(interp)->current_object;
             else {
                 UVal_pmc(st->val) = va_arg(*ap, PMC *);
-                dod_register_pmc(interp, UVal_pmc(st->val));
             }
 
             if (st->src.sig & PARROT_ARG_FLATTEN) {
@@ -567,9 +667,6 @@ fetch_arg_sig(PARROT_INTERP, ARGMOD(call_state *st))
                 st->src.used = 1;
                 retval       = Parrot_fetch_arg(interp, st);
 
-                if (!PMC_IS_NULL(st->key))
-                    dod_unregister_pmc(interp, st->key);
-
                 return retval;
             }
             break;
@@ -595,6 +692,7 @@ Fetches an argument from the appropriate context.
 static int
 fetch_arg_op(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(fetch_arg_op)
     const int    constant = PARROT_ARG_CONSTANT_ISSET(st->src.sig);
     const INTVAL idx      = st->src.u.op.pc[st->src.i];
 
@@ -634,9 +732,6 @@ fetch_arg_op(PARROT_INTERP, ARGMOD(call_state *st))
                 st->src.used = 1;
                 retval       = Parrot_fetch_arg(interp, st);
 
-                if (!PMC_IS_NULL(st->key))
-                    dod_unregister_pmc(interp, st->key);
-
                 return retval;
             }
             break;
@@ -666,6 +761,7 @@ PARROT_EXPORT
 int
 Parrot_fetch_arg(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(Parrot_fetch_arg)
     if (!st->src.used)
         return 1;
 
@@ -698,9 +794,6 @@ Parrot_fetch_arg(PARROT_INTERP, ARGMOD(call_state *st))
         if (st->src.slurp_i == st->src.slurp_n) {
             st->src.mode &= ~CALL_STATE_FLATTEN;
 
-            if (!PMC_IS_NULL(st->key))
-                dod_unregister_pmc(interp, st->key);
-
             st->key = PMCNULL;
             st->src.i++;
         }
@@ -745,6 +838,7 @@ PARROT_EXPORT
 int
 Parrot_fetch_arg_nci(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(Parrot_fetch_arg_nci)
     next_arg_sig(&st->dest);
 
     if (st->dest.sig & PARROT_ARG_SLURPY_ARRAY) {
@@ -760,7 +854,6 @@ Parrot_fetch_arg_nci(PARROT_INTERP, ARGMOD(call_state *st))
         }
 
         UVal_pmc(st->val) = slurped;
-        dod_register_pmc(interp, slurped);
     }
     else {
         Parrot_fetch_arg(interp, st);
@@ -785,6 +878,7 @@ Autoboxes an int into the expected container type.
 static void
 convert_arg_from_int(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(convert_arg_from_int)
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_FLOATVAL:
             UVal_num(st->val) = (FLOATVAL)UVal_int(st->val);
@@ -799,7 +893,6 @@ convert_arg_from_int(PARROT_INTERP, ARGMOD(call_state *st))
 
             VTABLE_set_integer_native(interp, d, UVal_int(st->val));
             UVal_pmc(st->val) = d;
-            dod_register_pmc(interp, d);
             }
             break;
         default:
@@ -820,6 +913,7 @@ Autoboxes a num into the expected container type.
 static void
 convert_arg_from_num(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(convert_arg_from_num)
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
             UVal_int(st->val) = (INTVAL)UVal_num(st->val);
@@ -834,7 +928,6 @@ convert_arg_from_num(PARROT_INTERP, ARGMOD(call_state *st))
 
             VTABLE_set_number_native(interp, d, UVal_num(st->val));
             UVal_pmc(st->val) = d;
-            dod_register_pmc(interp, d);
             }
             break;
         default:
@@ -856,6 +949,7 @@ Autoboxes a string primitive to the expected container type.
 static void
 convert_arg_from_str(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(convert_arg_from_str)
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
             UVal_int(st->val) = string_to_int(interp, UVal_str(st->val));
@@ -870,7 +964,6 @@ convert_arg_from_str(PARROT_INTERP, ARGMOD(call_state *st))
 
             VTABLE_set_string_native(interp, d, UVal_str(st->val));
             UVal_pmc(st->val) = d;
-            dod_register_pmc(interp, d);
             }
             break;
         default:
@@ -891,6 +984,7 @@ Unboxes a PMC to the expected primitive type.
 static void
 convert_arg_from_pmc(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(convert_arg_from_pmc)
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
             UVal_int(st->val) = VTABLE_get_integer(interp, UVal_pmc(st->val));
@@ -921,6 +1015,7 @@ Otherwise moves on.
 static void
 check_for_opt_flag(ARGMOD(call_state *st), int has_arg)
 {
+    ASSERT_ARGS(check_for_opt_flag)
     INTVAL idx;
     call_state_item * const dest = &st->dest;
 
@@ -964,6 +1059,7 @@ tailcalled function or method.
 static void
 clone_key_arg(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(clone_key_arg)
     PMC *key = UVal_pmc(st->val);
 
     if (!key)
@@ -1000,6 +1096,7 @@ Initializes dest calling state for the first named arg.
 static void
 init_first_dest_named(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(init_first_dest_named)
     int i, n_named;
 
     if (st->dest.mode & CALL_STATE_SIG)
@@ -1030,7 +1127,6 @@ init_first_dest_named(PARROT_INTERP, ARGMOD(call_state *st))
              * otherwise it may get collected. */
             st->dest.slurp = pmc_new(interp,
                 Parrot_get_ctx_HLL_type(interp, enum_class_Hash));
-            dod_register_pmc(interp, st->dest.slurp);
 
             /* pass the slurpy hash */
             idx = st->dest.u.op.pc[i];
@@ -1064,6 +1160,7 @@ Locates a destination argument name, returning 0 if not found.
 static int
 locate_named_named(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(locate_named_named)
     int i;
     int n_named = -1;
 
@@ -1117,6 +1214,7 @@ Stores the next argument in the destination register appropriately.
 static void
 store_arg(ARGIN(const call_state *st), INTVAL idx)
 {
+    ASSERT_ARGS(store_arg)
     switch (st->dest.sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:
             CTX_REG_INT(st->dest.ctx, idx) = UVal_int(st->val);
@@ -1152,6 +1250,7 @@ PARROT_EXPORT
 int
 Parrot_store_arg(SHIM_INTERP, ARGIN(const call_state *st))
 {
+    ASSERT_ARGS(Parrot_store_arg)
     INTVAL idx;
     if (st->dest.i >= st->dest.n)
         return 0;
@@ -1178,6 +1277,7 @@ Throws an exception if there are too few arguments passed.
 static void
 too_few(PARROT_INTERP, ARGIN(const call_state *st), ARGIN(const char *action))
 {
+    ASSERT_ARGS(too_few)
     const int max_expected_args = st->params;
     const int min_expected_args = max_expected_args - st->optionals;
 
@@ -1204,6 +1304,7 @@ Throws an exception if there are too many arguments passed.
 static void
 too_many(PARROT_INTERP, ARGIN(const call_state *st), ARGIN(const char *action))
 {
+    ASSERT_ARGS(too_many)
     const int max_expected_args = st->params;
     const int min_expected_args = max_expected_args - st->optionals;
 
@@ -1230,6 +1331,7 @@ Adds a null value to the appropriate register.
 static void
 null_val(int sig, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(null_val)
     switch (sig & PARROT_ARG_TYPE_MASK) {
         case PARROT_ARG_INTVAL:   UVal_int(st->val) = 0;       break;
         case PARROT_ARG_FLOATVAL: UVal_num(st->val) = 0.0;     break;
@@ -1263,6 +1365,7 @@ or
 static void
 check_named(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(check_named)
     int i;
     int n_named = -1;
 
@@ -1346,6 +1449,7 @@ Sets the default values of the passed C<call_state>.
 static void
 init_call_stats(ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(init_call_stats)
     /* initial guess, adjusted for :flat args */
     st->n_actual_args = st->src.n;
 
@@ -1373,6 +1477,7 @@ PARROT_EXPORT
 void
 Parrot_process_args(PARROT_INTERP, ARGMOD(call_state *st), arg_pass_t param_or_result)
 {
+    ASSERT_ARGS(Parrot_process_args)
     int n_named;
     int err_check = 1;
     call_state_item *src, *dest;
@@ -1415,7 +1520,7 @@ Parrot_process_args(PARROT_INTERP, ARGMOD(call_state *st), arg_pass_t param_or_r
 
             /*
              * Workaround for several argument passing problems
-             * RT#54860 y otros
+             * RT #54860 y otros
              * Save current value while setting the optional
              */
             UnionVal old_value;
@@ -1489,7 +1594,6 @@ Parrot_process_args(PARROT_INTERP, ARGMOD(call_state *st), arg_pass_t param_or_r
 
         /* Must register this PMC or it may get collected when only the struct
          * references it. */
-        dod_register_pmc(interp, array);
         CTX_REG_PMC(st->dest.ctx, idx) = array;
 
         while (Parrot_fetch_arg(interp, st)) {
@@ -1507,7 +1611,6 @@ Parrot_process_args(PARROT_INTERP, ARGMOD(call_state *st), arg_pass_t param_or_r
         }
 
         dest->i++;
-        dod_unregister_pmc(interp, array);
     }
 
     /* is there another argument? if we're throwing errors, that's an error */
@@ -1559,10 +1662,6 @@ Parrot_process_args(PARROT_INTERP, ARGMOD(call_state *st), arg_pass_t param_or_r
     }
 
     check_named(interp, st);
-
-    /* we may or may not have registered this pmc */
-    if (dest->slurp)
-        dod_unregister_pmc(interp, dest->slurp);
 }
 
 
@@ -1580,6 +1679,7 @@ PARROT_EXPORT
 void
 Parrot_convert_arg(PARROT_INTERP, ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(Parrot_convert_arg)
     /* register key args have to be cloned */
     if ((st->src.sig & PARROT_ARG_TYPE_MASK) == PARROT_ARG_PMC)
         clone_key_arg(interp, st);
@@ -1623,9 +1723,10 @@ PARROT_EXPORT
 void
 parrot_pass_args(PARROT_INTERP,
         ARGMOD(Parrot_Context *src_ctx), ARGMOD(Parrot_Context *dest_ctx),
-        ARGMOD(opcode_t *src_indexes),     ARGMOD(opcode_t *dest_indexes),
+        ARGMOD_NULLOK(opcode_t *src_indexes), ARGMOD_NULLOK(opcode_t *dest_indexes),
         arg_pass_t param_or_result)
 {
+    ASSERT_ARGS(parrot_pass_args)
     call_state st;
     PMC *src_signature, *dest_signature;
 
@@ -1652,8 +1753,6 @@ parrot_pass_args(PARROT_INTERP,
 
     /* If we created a slurpy, we had to DOD register it so it did not get
      * collected during arg processing; we'll now unregister it. */
-    if (st.dest.slurp)
-        dod_unregister_pmc(interp, st.dest.slurp);
 }
 
 
@@ -1674,6 +1773,7 @@ opcode_t *
 parrot_pass_args_fromc(PARROT_INTERP, ARGIN(const char *sig),
         ARGMOD(opcode_t *dest), ARGIN(Parrot_Context *old_ctxp), va_list ap)
 {
+    ASSERT_ARGS(parrot_pass_args_fromc)
     call_state st;
 
     Parrot_init_arg_op(interp, CONTEXT(interp), dest, &st.dest);
@@ -1698,6 +1798,7 @@ static int
 set_retval_util(PARROT_INTERP, ARGIN(const char *sig),
     ARGIN(Parrot_Context *ctx), ARGMOD(call_state *st))
 {
+    ASSERT_ARGS(set_retval_util)
     opcode_t * const src_pc = interp->current_returns;
     int              todo   = Parrot_init_arg_op(interp, ctx, src_pc, &st->src);
 
@@ -1734,6 +1835,7 @@ PARROT_CAN_RETURN_NULL
 void *
 set_retval(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
 {
+    ASSERT_ARGS(set_retval)
     call_state st;
 
     if (!sig_ret || sig_ret == 'v')
@@ -1746,7 +1848,6 @@ set_retval(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
         case 'P':
             if (set_retval_util(interp, "P", ctx, &st)) {
                 PMC *retval = UVal_pmc(st.val);
-                dod_unregister_pmc(interp, retval);
                 return (void *)retval;
             }
         default:
@@ -1768,6 +1869,7 @@ Handles an INTVAL return value, returning its value if present and 0 otherwise.
 INTVAL
 set_retval_i(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
 {
+    ASSERT_ARGS(set_retval_i)
     call_state st;
 
     if (sig_ret != 'I')
@@ -1795,6 +1897,7 @@ otherwise.
 FLOATVAL
 set_retval_f(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
 {
+    ASSERT_ARGS(set_retval_f)
     call_state st;
 
     if (sig_ret != 'N')
@@ -1824,6 +1927,7 @@ PARROT_WARN_UNUSED_RESULT
 STRING*
 set_retval_s(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
 {
+    ASSERT_ARGS(set_retval_s)
     call_state st;
 
     if (sig_ret != 'S')
@@ -1853,6 +1957,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC*
 set_retval_p(PARROT_INTERP, int sig_ret, ARGIN(Parrot_Context *ctx))
 {
+    ASSERT_ARGS(set_retval_p)
     call_state st;
 
     if (sig_ret != 'P')
@@ -1883,6 +1988,7 @@ commit_last_arg(PARROT_INTERP, int index, int cur,
     ARGMOD(opcode_t **indexes), ARGMOD(Parrot_Context *ctx),
     ARGIN_NULLOK(PMC *pmc), ARGIN(va_list *list))
 {
+    ASSERT_ARGS(commit_last_arg)
     int reg_offset = 0;
 
     /* invocant already commited, just return */
@@ -1948,6 +2054,7 @@ static Parrot_Context *
 count_signature_elements(PARROT_INTERP, ARGIN(const char *signature),
     ARGMOD(PMC *args_sig), ARGMOD(PMC *results_sig), int flag)
 {
+    ASSERT_ARGS(count_signature_elements)
     const char  *x;
     unsigned int seen_arrow  = 0;
 
@@ -1997,13 +2104,24 @@ count_signature_elements(PARROT_INTERP, ARGIN(const char *signature),
                 break;
             case 'P':
                 arg_ret_cnt[seen_arrow]++;
-                max_regs[seen_arrow * 4 + REGNO_PMC]++;
+                {
+                    /* Lookahead to see if PMC is marked as invocant */
+                    if (*(++x) == 'i') {
+                        max_regs[REGNO_PMC]++;
+                    }
+                    else {
+                        x--; /* Undo lookahead */
+                        max_regs[seen_arrow * 4 + REGNO_PMC]++;
+                    }
+                }
                 break;
             case 'f':
             case 'n':
             case 's':
             case 'o':
             case 'p':
+            /* case 'l': */ /* lookahead parameter */
+            case 'i':
                 break;
             default:
                 Parrot_ex_throw_from_c_args(interp, NULL,
@@ -2032,8 +2150,8 @@ count_signature_elements(PARROT_INTERP, ARGIN(const char *signature),
 
 =item C<static void commit_last_arg_sig_object>
 
-Called by Parrot_pcc_invoke_sub_from_sig_object when it reaches the end of each
-arg in the arg signature.  See C<Parrot_pcc_invoke_sub_from_sig_object> for
+Called by Parrot_pcc_invoke_from_sig_object when it reaches the end of each
+arg in the arg signature.  See C<Parrot_pcc_invoke_from_sig_object> for
 signature syntax.
 
 =cut
@@ -2046,6 +2164,7 @@ commit_last_arg_sig_object(PARROT_INTERP, int index, int cur,
     ARGMOD(opcode_t **indexes), ARGMOD(Parrot_Context *ctx),
     ARGIN(PMC *sig_obj))
 {
+    ASSERT_ARGS(commit_last_arg_sig_object)
     int reg_offset = 0;
 
     /* calculate arg's register offset */
@@ -2057,7 +2176,22 @@ commit_last_arg_sig_object(PARROT_INTERP, int index, int cur,
         case PARROT_ARG_STRING:
             reg_offset = n_regs_used[seen_arrow * 4 + REGNO_STR]++; break;
         case PARROT_ARG_PMC :
-            reg_offset = n_regs_used[seen_arrow * 4 + REGNO_PMC]++; break;
+            if (cur & PARROT_ARG_INVOCANT) {
+                if (seen_arrow == 0 && index == 0) {
+                    n_regs_used[REGNO_PMC]++;
+                    reg_offset = 0;
+                }
+                else {
+                    Parrot_ex_throw_from_c_args(interp, NULL,
+                            EXCEPTION_INVALID_OPERATION,
+                            "Parrot_pcc_invoke: Only the first parameter can be an invocant %d, %d",
+                            seen_arrow, index);
+                }
+            }
+            else {
+                reg_offset = n_regs_used[seen_arrow * 4 + REGNO_PMC]++;
+            }
+            break;
         default:
             Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_INVALID_OPERATION,
                 "Parrot_PCCINVOKE: invalid reg type");
@@ -2084,11 +2218,14 @@ commit_last_arg_sig_object(PARROT_INTERP, int index, int cur,
                 break;
             case PARROT_ARG_PMC:
                 CTX_REG_PMC(ctx, reg_offset) = VTABLE_get_pmc_keyed_int(interp, sig_obj, index);
+                if (cur & PARROT_ARG_INVOCANT) {
+                    interp->current_object = CTX_REG_PMC(ctx, reg_offset);
+                }
                 break;
             default:
                 Parrot_ex_throw_from_c_args(interp, NULL,
                     EXCEPTION_INVALID_OPERATION,
-                    "Parrot_pcc_invoke_sub_from_sig_object: invalid reg type");
+                    "Parrot_pcc_invoke_from_sig_object: invalid reg type");
         }
     }
 }
@@ -2105,9 +2242,11 @@ for the return signature C<ret_x> and a list of return parameters C<result_list>
 */
 
 static void
-set_context_sig_returns(PARROT_INTERP, ARGMOD(Parrot_Context *ctx),
-    ARGMOD(opcode_t **indexes), ARGIN(const char *ret_x), ARGMOD(PMC *result_list))
+set_context_sig_returns(PARROT_INTERP,
+    ARGMOD(Parrot_Context *ctx), ARGMOD(opcode_t **indexes),
+    ARGIN_NULLOK(const char *ret_x), ARGMOD(PMC *result_list))
 {
+    ASSERT_ARGS(set_context_sig_returns)
     const char   *x;
     STRING       *empty_string = CONST_STRING(interp, "");
     unsigned int  index        = 0;
@@ -2146,7 +2285,7 @@ set_context_sig_returns(PARROT_INTERP, ARGMOD(Parrot_Context *ctx),
                 default:
                     Parrot_ex_throw_from_c_args(interp, NULL,
                         EXCEPTION_INVALID_OPERATION,
-                        "Parrot_pcc_invoke_sub_from_sig_object: invalid reg type %c!", *x);
+                        "Parrot_pcc_invoke_from_sig_object: invalid reg type %c!", *x);
             }
 
             /* invalidate the CPointer's pointers so that GC doesn't try to
@@ -2179,6 +2318,7 @@ static void
 set_context_sig_returns_varargs(PARROT_INTERP, ARGMOD(Parrot_Context *ctx),
     ARGMOD(opcode_t **indexes), ARGIN(const char *ret_x), ARGMOD(va_list returns))
 {
+    ASSERT_ARGS(set_context_sig_returns_varargs)
     unsigned int index = 0;
     unsigned int seen_arrow = 1;
     const char *x;
@@ -2228,7 +2368,7 @@ set_context_sig_returns_varargs(PARROT_INTERP, ARGMOD(Parrot_Context *ctx),
 
 Sets the subroutine arguments in the C<ctx> context, according to the
 signature string C<signature>. Currently this function is only called
-from C<Parrot_pcc_invoke_sub_from_sig_object>, but eventually when
+from C<Parrot_pcc_invoke_from_sig_object>, but eventually when
 things are unified enough it should be called from C<Parrot_PCCINVOKE>
 as well. The only difference currently between the two implementations
 are the calls to C<commit_last_arg_sig_object> and C<commit_last_arg>.
@@ -2244,6 +2384,7 @@ set_context_sig_params(PARROT_INTERP, ARGIN(const char *signature),
     ARGMOD(opcode_t **indexes), ARGMOD(Parrot_Context *ctx),
     ARGMOD(PMC *sig_obj))
 {
+    ASSERT_ARGS(set_context_sig_params)
     /* second loop through signature to build all index and arg_flag
      * loop also assigns args(up to the ->) to registers */
     int index      = -1;
@@ -2296,7 +2437,7 @@ set_context_sig_params(PARROT_INTERP, ARGIN(const char *signature),
                 default:
                   Parrot_ex_throw_from_c_args(interp, NULL,
                     EXCEPTION_INVALID_OPERATION,
-                    "Parrot_pcc_invoke_sub_from_sig_object: invalid reg type %c!", *x);
+                    "Parrot_pcc_invoke_from_sig_object: invalid reg type %c!", *x);
             }
 
         }
@@ -2308,10 +2449,12 @@ set_context_sig_params(PARROT_INTERP, ARGIN(const char *signature),
                 case 's': cur |= PARROT_ARG_SLURPY_ARRAY; break;
                 case 'o': cur |= PARROT_ARG_OPTIONAL;     break;
                 case 'p': cur |= PARROT_ARG_OPT_FLAG;     break;
+                case 'l': cur |= PARROT_ARG_LOOKAHEAD;    break;
+                case 'i': cur |= PARROT_ARG_INVOCANT;     break;
                 default:
                     Parrot_ex_throw_from_c_args(interp, NULL,
                         EXCEPTION_INVALID_OPERATION,
-                        "Parrot_pcc_invoke_sub_from_sig_object: invalid adverb type %c!", *x);
+                        "Parrot_pcc_invoke_from_sig_object: invalid adverb type %c!", *x);
             }
         }
     }
@@ -2344,14 +2487,14 @@ void
 Parrot_pcc_invoke_sub_from_c_args(PARROT_INTERP, ARGIN(PMC *sub_obj),
         ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_pcc_invoke_sub_from_c_args)
     PMC *sig_obj;
     va_list args;
     va_start(args, sig);
-    sig_obj = Parrot_build_sig_object_from_varargs(interp, sig, args);
+    sig_obj = Parrot_build_sig_object_from_varargs(interp, PMCNULL, sig, args);
     va_end(args);
 
-    Parrot_pcc_invoke_sub_from_sig_object(interp, sub_obj, sig_obj);
-    dod_unregister_pmc(interp, sig_obj);
+    Parrot_pcc_invoke_from_sig_object(interp, sub_obj, sig_obj);
 }
 
 /*
@@ -2384,6 +2527,8 @@ Signatures:
   s slurpy
   o optional
   p opt flag
+  l lookahead parameter (next positional, or next named if no positionals)
+  i invocant
 
   -> is the separator between args and results, similar to type theory
   notation.
@@ -2414,6 +2559,7 @@ void
 Parrot_PCCINVOKE(PARROT_INTERP, ARGIN(PMC* pmc), ARGMOD(STRING *method_name),
         ARGIN(const char *signature), ...)
 {
+    ASSERT_ARGS(Parrot_PCCINVOKE)
 #define PCC_ARG_MAX 1024
     /* variables from PCCINVOKE impl in PCCMETHOD.pm */
     /* args INSP, returns INSP */
@@ -2532,6 +2678,7 @@ Parrot_PCCINVOKE(PARROT_INTERP, ARGIN(PMC* pmc), ARGMOD(STRING *method_name),
                 case 's': cur |= PARROT_ARG_SLURPY_ARRAY; break;
                 case 'o': cur |= PARROT_ARG_OPTIONAL;     break;
                 case 'p': cur |= PARROT_ARG_OPT_FLAG;     break;
+                /* case 'l': cur |= PARROT_ARG_LOOKAHEAD;    break; */
                 default:
                     Parrot_ex_throw_from_c_args(interp, NULL,
                         EXCEPTION_INVALID_OPERATION,
@@ -2563,7 +2710,7 @@ Parrot_PCCINVOKE(PARROT_INTERP, ARGIN(PMC* pmc), ARGMOD(STRING *method_name),
     pccinvoke_meth               = VTABLE_find_method(interp, pmc, method_name);
 
     if (PMC_IS_NULL(pccinvoke_meth))
-        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_METH_NOT_FOUND,
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_METHOD_NOT_FOUND,
             "Method '%Ss' not found", method_name);
     else
         VTABLE_invoke(interp, pccinvoke_meth, NULL);
@@ -2579,7 +2726,49 @@ Parrot_PCCINVOKE(PARROT_INTERP, ARGIN(PMC* pmc), ARGMOD(STRING *method_name),
 
 /*
 
-=item C<void Parrot_pcc_invoke_sub_from_sig_object>
+=item C<void Parrot_pcc_invoke_method_from_c_args>
+
+Makes a method call given the name of the method and the arguments as a
+C variadic argument list. C<pmc> is the invocant, C<method_name> is the
+string name of the method, C<signature> is a C string describing the
+signature of the invocation, according to the Parrot calling
+conventions.  The variadic argument list contains the input arguments
+followed by the output results in the same order that they appear in the
+function signature.
+
+=cut
+
+*/
+
+PARROT_EXPORT
+void
+Parrot_pcc_invoke_method_from_c_args(PARROT_INTERP, ARGIN(PMC* pmc),
+        ARGMOD(STRING *method_name),
+        ARGIN(const char *signature), ...)
+{
+    ASSERT_ARGS(Parrot_pcc_invoke_method_from_c_args)
+    PMC *sig_obj;
+    PMC *sub_obj;
+    va_list args;
+    va_start(args, signature);
+    sig_obj = Parrot_build_sig_object_from_varargs(interp, pmc, signature, args);
+    va_end(args);
+
+    /* Find the subroutine object as a named method on pmc */
+    sub_obj = VTABLE_find_method(interp, pmc, method_name);
+    if (PMC_IS_NULL(sub_obj))
+         Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_METHOD_NOT_FOUND,
+             "Method '%Ss' not found", method_name);
+
+    /* Invoke the subroutine object with the given CallSignature object */
+    Parrot_pcc_invoke_from_sig_object(interp, sub_obj, sig_obj);
+    dod_unregister_pmc(interp, sig_obj);
+
+}
+
+/*
+
+=item C<void Parrot_pcc_invoke_from_sig_object>
 
 Follows the same conventions as C<Parrot_PCCINVOKE>, but the subroutine object
 to invoke is passed as an argument rather than looked up by name, and the
@@ -2591,9 +2780,10 @@ signature string and call arguments are passed in a CallSignature PMC.
 
 PARROT_EXPORT
 void
-Parrot_pcc_invoke_sub_from_sig_object(PARROT_INTERP, ARGIN(PMC *sub_obj),
+Parrot_pcc_invoke_from_sig_object(PARROT_INTERP, ARGIN(PMC *sub_obj),
         ARGIN(PMC *sig_obj))
 {
+    ASSERT_ARGS(Parrot_pcc_invoke_from_sig_object)
 #define PCC_ARG_MAX 1024
     /* variables from PCCINVOKE impl in PCCMETHOD.pm */
     /* args INSP, returns INSP */
@@ -2605,7 +2795,7 @@ Parrot_pcc_invoke_sub_from_sig_object(PARROT_INTERP, ARGIN(PMC *sub_obj),
 
     /* create the signature string, and the various PMCs that are needed to
        store all the parameters and parameter counts. */
-    char *signature         = string_to_cstring(interp, VTABLE_get_string(interp, sig_obj));
+    char * const signature  = string_to_cstring(interp, VTABLE_get_string(interp, sig_obj));
     PMC * const args_sig    = temporary_pmc_new(interp, enum_class_FixedIntegerArray);
     PMC * const results_sig = temporary_pmc_new(interp, enum_class_FixedIntegerArray);
     PMC * const ret_cont    = new_ret_continuation_pmc(interp, NULL);
@@ -2625,7 +2815,6 @@ Parrot_pcc_invoke_sub_from_sig_object(PARROT_INTERP, ARGIN(PMC *sub_obj),
     /* args_sig, results_sig */
     PMC *sigs[2];
 
-    const char *x;
     const char *ret_x  = NULL;
 
     indexes[0] = arg_indexes;
@@ -2658,10 +2847,12 @@ Parrot_pcc_invoke_sub_from_sig_object(PARROT_INTERP, ARGIN(PMC *sub_obj),
     /* Invoke the function */
     dest = VTABLE_invoke(interp, sub_obj, NULL);
 
-    /* PIR Subs need runops to run their opcodes. */
-    if (sub_obj->vtable->base_type == enum_class_Sub) {
-        INTVAL old_core  = interp->run_core;
-        opcode_t offset  = dest - interp->code->base.data;
+    /* PIR Subs need runops to run their opcodes. Methods and NCI subs
+     * don't. */
+    if (sub_obj->vtable->base_type == enum_class_Sub
+            && PMC_IS_NULL(interp->current_object)) {
+        const INTVAL old_core = interp->run_core;
+        const opcode_t offset = dest - interp->code->base.data;
 
         /* can't re-enter the runloop from here with PIC cores: RT #60048 */
         if (interp->run_core == PARROT_CGP_CORE
