@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/inter_cb.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/inter_cb.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -46,6 +46,13 @@ static void verify_CD(ARGIN(char *external_data), ARGMOD(PMC *user_data))
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*user_data);
 
+#define ASSERT_ARGS_callback_CD __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(external_data) \
+    || PARROT_ASSERT_ARG(user_data)
+#define ASSERT_ARGS_verify_CD __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(external_data) \
+    || PARROT_ASSERT_ARG(user_data)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -66,6 +73,7 @@ PMC*
 Parrot_make_cb(PARROT_INTERP, ARGMOD(PMC* sub), ARGIN(PMC* user_data),
         ARGIN(STRING *cb_signature))
 {
+    ASSERT_ARGS(Parrot_make_cb)
     PMC *cb, *cb_sig;
     int type;
     char * sig_str;
@@ -152,6 +160,7 @@ Verify user_data PMC then continue with callback_CD
 static void
 verify_CD(ARGIN(char *external_data), ARGMOD(PMC *user_data))
 {
+    ASSERT_ARGS(verify_CD)
     PARROT_INTERP = NULL;
     size_t i;
 
@@ -214,6 +223,7 @@ Common callback function handler. See pdd16.
 static void
 callback_CD(PARROT_INTERP, ARGIN(char *external_data), ARGMOD(PMC *user_data))
 {
+    ASSERT_ARGS(callback_CD)
 
     PMC *passed_interp;       /* the interp that originated the CB */
     PMC *passed_synchronous;  /* flagging synchronous execution */
@@ -276,6 +286,7 @@ void
 Parrot_run_callback(PARROT_INTERP,
         ARGMOD(PMC* user_data), ARGIN(char* external_data))
 {
+    ASSERT_ARGS(Parrot_run_callback)
     PMC     *signature;
     PMC     *sub;
     STRING  *sig_str;
@@ -371,6 +382,7 @@ PARROT_EXPORT
 void
 Parrot_callback_C(ARGIN(char *external_data), ARGMOD(PMC *user_data))
 {
+    ASSERT_ARGS(Parrot_callback_C)
     verify_CD(external_data, user_data);
 }
 
@@ -378,6 +390,7 @@ PARROT_EXPORT
 void
 Parrot_callback_D(ARGMOD(PMC *user_data), ARGIN(char *external_data))
 {
+    ASSERT_ARGS(Parrot_callback_D)
     verify_CD(external_data, user_data);
 }
 
