@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/inter_create.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/inter_create.c 35806 2009-01-19T22:31:16.548456Z infinoid  $
 
 =head1 NAME
 
@@ -36,6 +36,10 @@ static int is_env_var_set(ARGIN(const char* var))
 static void setup_default_compreg(PARROT_INTERP)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_is_env_var_set __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(var)
+#define ASSERT_ARGS_setup_default_compreg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -63,6 +67,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 is_env_var_set(ARGIN(const char* var))
 {
+    ASSERT_ARGS(is_env_var_set)
     int free_it, retval;
     char* const value = Parrot_getenv(var, &free_it);
     if (value == NULL)
@@ -89,6 +94,7 @@ Setup default compiler for PASM.
 static void
 setup_default_compreg(PARROT_INTERP)
 {
+    ASSERT_ARGS(setup_default_compreg)
     STRING * const pasm1 = CONST_STRING(interp, "PASM1");
 
     /* register the nci compiler object */
@@ -110,6 +116,8 @@ PARROT_CANNOT_RETURN_NULL
 Parrot_Interp
 make_interpreter(ARGIN_NULLOK(Interp *parent), INTVAL flags)
 {
+    ASSERT_ARGS(make_interpreter)
+    int stacktop;
     Interp *interp;
 
     /* Get an empty interpreter from system memory */
@@ -160,7 +168,7 @@ make_interpreter(ARGIN_NULLOK(Interp *parent), INTVAL flags)
     }
 
     /* Set up the memory allocation system */
-    mem_setup_allocator(interp);
+    mem_setup_allocator(interp, (void*)&stacktop);
     Parrot_block_GC_mark(interp);
     Parrot_block_GC_sweep(interp);
 
@@ -173,9 +181,6 @@ make_interpreter(ARGIN_NULLOK(Interp *parent), INTVAL flags)
     /* Set up the MMD struct */
     interp->binop_mmd_funcs = NULL;
 
-    /* Go and init the MMD tables */
-    Parrot_mmd_add_function(interp, MMD_USER_FIRST - 1, (funcptr_t)NULL);
-
     /* MMD cache for builtins. */
     interp->op_mmd_cache = Parrot_mmd_cache_create(interp);
 
@@ -289,6 +294,7 @@ PARROT_EXPORT
 void
 Parrot_destroy(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_destroy)
 #ifdef ATEXIT_DESTROY
     UNUSED(interp);
 #else
@@ -312,6 +318,7 @@ Note that C<exit_code> is ignored.
 void
 Parrot_really_destroy(PARROT_INTERP, SHIM(int exit_code), SHIM(void *arg))
 {
+    ASSERT_ARGS(Parrot_really_destroy)
     /* wait for threads to complete if needed; terminate the event loop */
     if (!interp->parent_interpreter) {
         Parrot_cx_runloop_end(interp);
@@ -343,13 +350,6 @@ Parrot_really_destroy(PARROT_INTERP, SHIM(int exit_code), SHIM(void *arg))
 
     Parrot_do_dod_run(interp, GC_finish_FLAG);
 
-#if STM_PROFILE
-    if (interp->thread_data && interp->thread_data->stm_log
-    && !interp->parent_interpreter
-    &&  Interp_debug_TEST(interp, PARROT_THREAD_DEBUG_FLAG))
-        Parrot_STM_dump_profile(interp);
-#endif
-
     /*
      * that doesn't get rid of constant PMCs like these in vtable->data
      * so if such a PMC needs destroying, we get a memory leak, like for
@@ -381,22 +381,6 @@ Parrot_really_destroy(PARROT_INTERP, SHIM(int exit_code), SHIM(void *arg))
                 Interp_flags_TEST(interp, PARROT_DESTROY_FLAG)))
         return;
 
-    if (interp->thread_data && interp->thread_data->stm_log) {
-        while (Parrot_STM_transaction_depth(interp) > 0) {
-            /* XXX */
-            fprintf(stderr, "interpreter %p had pending transaction on exit\n",
-                    (void *) interp);
-            Parrot_STM_abort(interp);
-        }
-#if STM_PROFILE
-        if (interp->parent_interpreter
-            && interp->thread_data->state & THREAD_STATE_JOINED)
-            Parrot_STM_merge_profile(interp->parent_interpreter,
-                                     interp);
-#endif
-        Parrot_STM_destroy(interp);
-    }
-
     if (interp->parent_interpreter
     &&  interp->thread_data
     && (interp->thread_data->state & THREAD_STATE_JOINED)) {
@@ -459,7 +443,6 @@ Parrot_really_destroy(PARROT_INTERP, SHIM(int exit_code), SHIM(void *arg))
 
         /* free vtables */
         parrot_free_vtables(interp);
-        Parrot_mmd_destroy(interp);
 
         /* dynop libs */
         if (interp->n_libs > 0) {
