@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/inter_run.c 33224 2008-11-25T17:14:34.022529Z pmichaud  $
+$Id: /mirror/trunk/src/inter_run.c 35409 2009-01-11T03:55:39.964567Z allison  $
 
 =head1 NAME
 
@@ -39,6 +39,10 @@ static Parrot_Context * runops_args(PARROT_INTERP,
         __attribute__nonnull__(2)
         __attribute__nonnull__(5);
 
+#define ASSERT_ARGS_runops_args __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sub) \
+    || PARROT_ASSERT_ARG(sig)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -61,6 +65,7 @@ Run parrot ops. Set exception handler and/or resume after exception.
 void
 runops(PARROT_INTERP, size_t offs)
 {
+    ASSERT_ARGS(runops)
     volatile size_t offset            = offs;
     const    int    old_runloop_id    = interp->current_runloop_id;
     const    int    our_runloop_level = ++interp->current_runloop_level;
@@ -133,6 +138,7 @@ PARROT_CANNOT_RETURN_NULL
 Parrot_Context *
 Parrot_runops_fromc(PARROT_INTERP, ARGIN(PMC *sub))
 {
+    ASSERT_ARGS(Parrot_runops_fromc)
     opcode_t offset, *dest;
     Parrot_Context *ctx;
 
@@ -140,7 +146,7 @@ Parrot_runops_fromc(PARROT_INTERP, ARGIN(PMC *sub))
     PMC * const ret_c    = new_ret_continuation_pmc(interp, NULL);
     interp->current_cont = ret_c;
 #if defined GC_VERBOSE && GC_VERBOSE
-    PObj_report_SET(ret_c);     /* s. also dod.c */
+    PObj_report_SET(ret_c);     /* s. also src/gc/api.c */
 #endif
     /* invoke the sub, which places the context of the sub in the
      * interpreter, and switches code segments if needed
@@ -187,6 +193,7 @@ static Parrot_Context *
 runops_args(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         SHIM(STRING *meth), ARGIN(const char *sig), va_list ap)
 {
+    ASSERT_ARGS(runops_args)
     opcode_t offset, *dest;
     Parrot_Context *ctx;
 
@@ -216,7 +223,8 @@ runops_args(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
                 "too many arguments in runops_args");
 
         new_sig[0] = 'O';
-        strcpy(new_sig + 1, sig + 1);
+        /* -1 from the end, +1 for the nul at the end */
+        memcpy(new_sig+1, sig+1, len);
         sig_p = new_sig;
     }
 
@@ -262,6 +270,7 @@ PARROT_CAN_RETURN_NULL
 void *
 Parrot_run_meth_fromc(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj), SHIM(STRING *meth))
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc)
     Parrot_Context *ctx;
     opcode_t offset, *dest;
 
@@ -297,6 +306,7 @@ PARROT_CAN_RETURN_NULL
 PMC *
 Parrot_runops_fromc_args(PARROT_INTERP, ARGIN(PMC *sub), ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_args)
     va_list args;
     Parrot_Context *ctx;
     PMC *retval;
@@ -328,6 +338,7 @@ void *
 Parrot_runops_fromc_args_event(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_args_event)
     va_list args;
     Parrot_Context *ctx;
     void *retval;
@@ -372,6 +383,7 @@ INTVAL
 Parrot_runops_fromc_args_reti(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_args_reti)
     va_list args;
     Parrot_Context *ctx;
     INTVAL retval;
@@ -402,6 +414,7 @@ FLOATVAL
 Parrot_runops_fromc_args_retf(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_args_retf)
     va_list args;
     Parrot_Context *ctx;
     FLOATVAL retval;
@@ -433,6 +446,7 @@ void*
 Parrot_run_meth_fromc_args(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_args)
     va_list args;
     Parrot_Context *ctx;
     void* retval;
@@ -463,6 +477,7 @@ INTVAL
 Parrot_run_meth_fromc_args_reti(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_args_reti)
     va_list args;
     Parrot_Context *ctx;
     INTVAL retval;
@@ -493,6 +508,7 @@ FLOATVAL
 Parrot_run_meth_fromc_args_retf(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), ...)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_args_retf)
     va_list args;
     Parrot_Context *ctx;
     FLOATVAL retval;
@@ -524,6 +540,7 @@ void *
 Parrot_runops_fromc_arglist(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_arglist)
     void* retval;
     Parrot_Context * const ctx = runops_args(interp, sub, PMCNULL, NULL, sig, args);
 
@@ -550,6 +567,7 @@ INTVAL
 Parrot_runops_fromc_arglist_reti(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_arglist_reti)
     INTVAL retval;
     Parrot_Context * const ctx = runops_args(interp, sub, PMCNULL, NULL, sig, args);
 
@@ -576,6 +594,7 @@ FLOATVAL
 Parrot_runops_fromc_arglist_retf(PARROT_INTERP, ARGIN(PMC *sub),
         ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_runops_fromc_arglist_retf)
     FLOATVAL retval;
     Parrot_Context * const ctx = runops_args(interp, sub, PMCNULL, NULL, sig, args);
 
@@ -603,6 +622,7 @@ void*
 Parrot_run_meth_fromc_arglist(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_arglist)
     Parrot_Context *ctx;
     void* retval;
 
@@ -632,6 +652,7 @@ INTVAL
 Parrot_run_meth_fromc_arglist_reti(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_arglist_reti)
     INTVAL retval;
     Parrot_Context * const ctx = runops_args(interp, sub, obj, meth, sig, args);
 
@@ -659,6 +680,7 @@ FLOATVAL
 Parrot_run_meth_fromc_arglist_retf(PARROT_INTERP, ARGIN(PMC *sub), ARGIN_NULLOK(PMC *obj),
         ARGIN(STRING *meth), ARGIN(const char *sig), va_list args)
 {
+    ASSERT_ARGS(Parrot_run_meth_fromc_arglist_retf)
     FLOATVAL retval;
     Parrot_Context * const ctx = runops_args(interp, sub, obj, meth, sig, args);
 
@@ -688,6 +710,7 @@ PARROT_EXPORT
 void
 new_runloop_jump_point(PARROT_INTERP)
 {
+    ASSERT_ARGS(new_runloop_jump_point)
     Parrot_runloop *jump_point;
 
     if (interp->runloop_jmp_free_list) {
@@ -715,6 +738,7 @@ PARROT_EXPORT
 void
 free_runloop_jump_point(PARROT_INTERP)
 {
+    ASSERT_ARGS(free_runloop_jump_point)
     Parrot_runloop * const jump_point = interp->current_runloop;
     interp->current_runloop           = jump_point->prev;
     jump_point->prev                  = interp->runloop_jmp_free_list;
@@ -735,6 +759,7 @@ associated free list for the specified interpreter.
 void
 destroy_runloop_jump_points(PARROT_INTERP)
 {
+    ASSERT_ARGS(destroy_runloop_jump_points)
     really_destroy_runloop_jump_points(interp->current_runloop);
     really_destroy_runloop_jump_points(interp->runloop_jmp_free_list);
 }
@@ -754,6 +779,7 @@ it encounters NULL. Used by C<destroy_runloop_jump_points>.
 void
 really_destroy_runloop_jump_points(ARGIN_NULLOK(Parrot_runloop *jump_point))
 {
+    ASSERT_ARGS(really_destroy_runloop_jump_points)
     while (jump_point) {
         Parrot_runloop * const prev = jump_point->prev;
         mem_sys_free(jump_point);
