@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/interpreter.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/interpreter.c 35806 2009-01-19T22:31:16.548456Z infinoid  $
 
 =head1 NAME
 
@@ -126,6 +126,41 @@ static void stop_prederef(PARROT_INTERP)
 static void turn_ev_check(PARROT_INTERP, int on)
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_dynop_register_switch __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+#define ASSERT_ARGS_dynop_register_xx __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_get_core_op_lib_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_get_dynamic_op_lib_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(lib)
+#define ASSERT_ARGS_init_prederef __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_load_prederef __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_notify_func_table __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(table)
+#define ASSERT_ARGS_prederef_args __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(pc_prederef) \
+    || PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc) \
+    || PARROT_ASSERT_ARG(opinfo)
+#define ASSERT_ARGS_runops_cgp __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_runops_exec __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_runops_jit __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_runops_switch __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_stop_prederef __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_turn_ev_check __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -149,6 +184,7 @@ static void
 prederef_args(ARGMOD(void **pc_prederef), PARROT_INTERP,
         ARGIN(opcode_t *pc), ARGIN(const op_info_t *opinfo))
 {
+    ASSERT_ARGS(prederef_args)
     const PackFile_ConstTable * const const_table = interp->code->const_table;
 
     const int regs_n = CONTEXT(interp)->n_regs_used[REGNO_NUM];
@@ -346,6 +382,7 @@ handler thread.
 static void
 turn_ev_check(PARROT_INTERP, int on)
 {
+    ASSERT_ARGS(turn_ev_check)
     const Prederef * const pi = &interp->code->prederef;
     size_t i;
 
@@ -381,6 +418,7 @@ PARROT_CANNOT_RETURN_NULL
 static oplib_init_f
 get_core_op_lib_init(PARROT_INTERP, int which)
 {
+    ASSERT_ARGS(get_core_op_lib_init)
     oplib_init_f init_func;
     switch (which) {
         case PARROT_SWITCH_CORE:
@@ -431,6 +469,7 @@ PARROT_CANNOT_RETURN_NULL
 static oplib_init_f
 get_dynamic_op_lib_init(SHIM_INTERP, ARGIN(const PMC *lib))
 {
+    ASSERT_ARGS(get_dynamic_op_lib_init)
     return (oplib_init_f)D2FPTR(PMC_struct_val(lib));
 }
 
@@ -448,6 +487,7 @@ C<< interp->op_lib >> = prederefed oplib.
 static void
 load_prederef(PARROT_INTERP, int which)
 {
+    ASSERT_ARGS(load_prederef)
     const oplib_init_f init_func = get_core_op_lib_init(interp, which);
 
     int (*get_op)(const char * name, int full);
@@ -478,6 +518,7 @@ Initialize: load prederef C<func_table>, file prederef.code.
 static void
 init_prederef(PARROT_INTERP, int which)
 {
+    ASSERT_ARGS(init_prederef)
     load_prederef(interp, which);
     if (!interp->code->prederef.code) {
         void        *pred_func;
@@ -545,6 +586,7 @@ for run-core changes, but we don't know the old run core.
 static void
 stop_prederef(PARROT_INTERP)
 {
+    ASSERT_ARGS(stop_prederef)
     interp->op_func_table = PARROT_CORE_OPLIB_INIT(1)->op_func_table;
 
     if (interp->evc_func_table) {
@@ -688,6 +730,7 @@ PARROT_CAN_RETURN_NULL
 static opcode_t *
 runops_jit(PARROT_INTERP, ARGIN(opcode_t *pc))
 {
+    ASSERT_ARGS(runops_jit)
 #if JIT_CAPABLE
 #  ifdef PARROT_EXEC_OS_AIX
     /* AIX calling convention requires that function-call-by-ptr be made
@@ -729,6 +772,7 @@ PARROT_CAN_RETURN_NULL
 static opcode_t *
 runops_exec(PARROT_INTERP, ARGIN(opcode_t *pc))
 {
+    ASSERT_ARGS(runops_exec)
 #if EXEC_CAPABLE
     opcode_t *code_start;
     UINTVAL   code_size;          /* in opcodes */
@@ -783,6 +827,7 @@ PARROT_CANNOT_RETURN_NULL
 static opcode_t *
 runops_cgp(PARROT_INTERP, ARGIN(opcode_t *pc))
 {
+    ASSERT_ARGS(runops_cgp)
 #ifdef HAVE_COMPUTED_GOTO
     opcode_t * const code_start = (opcode_t *)interp->code->base.data;
     opcode_t        *pc_prederef;
@@ -817,6 +862,7 @@ PARROT_CANNOT_RETURN_NULL
 static opcode_t *
 runops_switch(PARROT_INTERP, ARGIN(opcode_t *pc))
 {
+    ASSERT_ARGS(runops_switch)
     opcode_t * const code_start = (opcode_t *)interp->code->base.data;
     opcode_t        *pc_prederef;
 
@@ -843,14 +889,8 @@ evaluation of opcode continues.
 void
 runops_int(PARROT_INTERP, size_t offset)
 {
-    int lo_var_ptr;
     opcode_t *(*core) (PARROT_INTERP, opcode_t *) = NULL;
 
-    /* if we are entering the run loop the first time, set the stack pointer so
-     * that we can scan the stack for GCable pointers */
-    if (!interp->lo_var_ptr)
-        interp->lo_var_ptr = (void *)&lo_var_ptr;
-
     /* setup event function ptrs */
     if (!interp->save_func_table)
         Parrot_setup_event_func_ptrs(interp);
@@ -1127,6 +1167,7 @@ static void
 dynop_register_xx(PARROT_INTERP,
         size_t n_old, size_t n_new, oplib_init_f init_func)
 {
+    ASSERT_ARGS(dynop_register_xx)
     const size_t n_tot    = n_old + n_new;
     op_func_t   *ops_addr = NULL;
     op_lib_t    *cg_lib   = init_func(1);
@@ -1239,6 +1280,7 @@ object.
 static void
 dynop_register_switch(size_t n_old, size_t n_new)
 {
+    ASSERT_ARGS(dynop_register_switch)
     op_lib_t * const lib = PARROT_CORE_SWITCH_OPLIB_INIT(1);
     lib->op_count        = n_old + n_new;
 }
@@ -1257,6 +1299,7 @@ Tell the interpreter's running core about the new function table.
 static void
 notify_func_table(PARROT_INTERP, ARGIN(op_func_t* table), int on)
 {
+    ASSERT_ARGS(notify_func_table)
     const oplib_init_f init_func = get_core_op_lib_init(interp, interp->run_core);
 
     init_func((long) table);
