@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/io/buffer.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/io/buffer.c 35879 2009-01-21T00:48:20.581419Z chromatic  $
 
 =head1 NAME
 
@@ -28,6 +28,8 @@ This file implements a collection of utility functions for I/O buffering.
 static INTVAL io_is_end_of_line(ARGIN(const char *c))
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_io_is_end_of_line __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(c)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -45,6 +47,7 @@ Initialize buffering on STDOUT and STDIN.
 INTVAL
 Parrot_io_init_buffer(PARROT_INTERP)
 {
+    ASSERT_ARGS(Parrot_io_init_buffer)
     if (Parrot_io_STDOUT(interp))
         Parrot_io_setlinebuf(interp, Parrot_io_STDOUT(interp));
 
@@ -67,6 +70,7 @@ Set the buffering mode for the filehandle.
 void
 Parrot_io_setbuf(PARROT_INTERP, ARGMOD(PMC *filehandle), size_t bufsize)
 {
+    ASSERT_ARGS(Parrot_io_setbuf)
     INTVAL filehandle_flags = Parrot_io_get_flags(interp, filehandle);
     INTVAL         buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
     unsigned char *buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
@@ -136,6 +140,7 @@ Set the file handle to line buffering mode.
 INTVAL
 Parrot_io_setlinebuf(PARROT_INTERP, ARGMOD(PMC *filehandle))
 {
+    ASSERT_ARGS(Parrot_io_setlinebuf)
     INTVAL filehandle_flags = Parrot_io_get_flags(interp, filehandle);
 
     /* already linebuffering */
@@ -167,6 +172,7 @@ Flush the I/O buffer for a given filehandle object.
 INTVAL
 Parrot_io_flush_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle))
 {
+    ASSERT_ARGS(Parrot_io_flush_buffer)
     long wrote;
     size_t to_write;
     STRING fake;
@@ -226,6 +232,7 @@ The buffer layer's C<Fill> function.
 size_t
 Parrot_io_fill_readbuf(PARROT_INTERP, ARGMOD(PMC *filehandle))
 {
+    ASSERT_ARGS(Parrot_io_fill_readbuf)
     size_t   got;
     STRING   fake;
     STRING  *s    = &fake;
@@ -254,6 +261,7 @@ Parrot_io_fill_readbuf(PARROT_INTERP, ARGMOD(PMC *filehandle))
     return got;
 }
 
+
 /*
 
 =item C<size_t Parrot_io_read_buffer>
@@ -268,12 +276,12 @@ size_t
 Parrot_io_read_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
               ARGIN(STRING **buf))
 {
-    unsigned char *out_buf;
-    STRING *s;
-    size_t len;
-    size_t current = 0;
-    INTVAL buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
-    unsigned char *buffer_start, *buffer_next, *buffer_end;
+    ASSERT_ARGS(Parrot_io_read_buffer)
+    unsigned char *out_buf, *buffer_start, *buffer_next, *buffer_end;
+    STRING        *s;
+    size_t         len;
+    size_t         current      = 0;
+    INTVAL         buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
 
     /* write buffer flush */
     if (buffer_flags & PIO_BF_WRITEBUF) {
@@ -286,25 +294,27 @@ Parrot_io_read_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
     buffer_end   = Parrot_io_get_buffer_end(interp, filehandle);
 
     /* line buffered read */
-    if (Parrot_io_get_flags(interp, filehandle) & PIO_F_LINEBUF) {
+    if (Parrot_io_get_flags(interp, filehandle) & PIO_F_LINEBUF)
         return Parrot_io_readline_buffer(interp, filehandle, buf);
-    }
 
     if (*buf == NULL) {
         *buf = new_string_header(interp, 0);
         (*buf)->bufused = len = 2048;
     }
-    s = *buf;
+
+    s   = *buf;
     len = s->bufused;
-    if (!s->strstart) {
+
+    if (!s->strstart)
         Parrot_allocate_string(interp, s, len);
-    }
+
     out_buf = (unsigned char *)s->strstart;
+
     /* read Data from buffer */
     if (buffer_flags & PIO_BF_READBUF) {
         const size_t avail = buffer_end - buffer_next;
+        current            = avail < len ? avail : len;
 
-        current = avail < len ? avail : len;
         memcpy(out_buf, buffer_next, current);
         buffer_next += current;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
@@ -315,6 +325,7 @@ Parrot_io_read_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
         if (current == avail) {
             buffer_flags &= ~PIO_BF_READBUF;
             Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
+
             /* Reset next and end */
             Parrot_io_set_buffer_end(interp, filehandle, NULL);
             Parrot_io_set_buffer_next(interp, filehandle, buffer_start);
@@ -337,8 +348,8 @@ Parrot_io_read_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
         size_t got;
 
         if (len >= Parrot_io_get_buffer_size(interp, filehandle)) {
-            STRING  fake;
-            STRING *sf = &fake;
+            STRING     fake;
+            STRING    *sf = &fake;
 
             fake.strstart = (char *)out_buf;
             fake.bufused  = len;
@@ -395,13 +406,11 @@ size_t
 Parrot_io_peek_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
         ARGOUT(STRING **buf))
 {
-    UINTVAL len   = 1;
-    size_t  avail = 0;
-
+    ASSERT_ARGS(Parrot_io_peek_buffer)
+    unsigned char *buffer_next;
+    STRING * const s            = Parrot_io_make_string(interp, buf, 1);
+    UINTVAL        len          = 1;
     INTVAL         buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
-    unsigned char *buffer_next, *buffer_end;
-
-    STRING * const s = Parrot_io_make_string(interp, buf, 1);
 
     /* write buffer flush */
     if (buffer_flags & PIO_BF_WRITEBUF) {
@@ -410,28 +419,16 @@ Parrot_io_peek_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
     }
 
     buffer_next  = Parrot_io_get_buffer_next(interp, filehandle);
-    buffer_end   = Parrot_io_get_buffer_end(interp, filehandle);
-
-    /* read Data from buffer */
-    if (buffer_flags & PIO_BF_READBUF) {
-        avail = buffer_end - buffer_next;
-
-        /* if we have data available, copy out the next byte */
-        if (avail) {
-ret_string:
-            memcpy(s->strstart, buffer_next, len);
-            s->bufused = s->strlen = len;
-            return len;
-        }
-    }
 
     /* (re)fill the buffer */
     if (! (buffer_flags & PIO_BF_READBUF)) {
         size_t got;
-        /* exception if we're unbuffered */
-        if (Parrot_io_get_buffer_size(interp, filehandle) == 0)
-            Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_PIO_ERROR,
-                "Can't peek at unbuffered I/O");
+
+        /* promote to buffered if unbuffered */
+        if (Parrot_io_get_buffer_size(interp, filehandle) == 0) {
+            Parrot_io_setbuf(interp, filehandle, 1);
+            return Parrot_io_peek_buffer(interp, filehandle, buf);
+        }
 
         /* Parrot_io_fill_readbuf() can return -1, but len should be positive */
         got = Parrot_io_fill_readbuf(interp, filehandle);
@@ -446,9 +443,13 @@ ret_string:
     }
 
     /* if we got any data, then copy out the next byte */
-    goto ret_string;
+    memmove(s->strstart, buffer_next, len);
+    s->bufused = s->strlen = len;
+
+    return len;
 }
 
+
 /*
 
 =item C<size_t Parrot_io_readline_buffer>
@@ -463,6 +464,7 @@ that is what is required.
 size_t
 Parrot_io_readline_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGOUT(STRING **buf))
 {
+    ASSERT_ARGS(Parrot_io_readline_buffer)
     size_t l;
     unsigned char *out_buf;
     unsigned char *buf_start;
@@ -564,21 +566,22 @@ The buffer layer's C<Write> function.
 size_t
 Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
 {
-    size_t avail;
-    void * const buffer = s->strstart;
-    size_t len = s->bufused;
-    int need_flush;
-
-    INTVAL         buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
-    unsigned char *buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
-    unsigned char *buffer_next  = Parrot_io_get_buffer_next(interp, filehandle);
-    size_t         buffer_size  = Parrot_io_get_buffer_size(interp, filehandle);
+    ASSERT_ARGS(Parrot_io_write_buffer)
+    void          * const buffer       = s->strstart;
+    unsigned char * const buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
+    unsigned char *       buffer_next  = Parrot_io_get_buffer_next(interp, filehandle);
+    const size_t          buffer_size  = Parrot_io_get_buffer_size(interp, filehandle);
+    INTVAL                buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
+    const size_t          len          = s->bufused;
+    int                   need_flush;
+    size_t                avail;
 
     if (len <= 0)
         return 0;
-    if (buffer_flags & PIO_BF_WRITEBUF) {
+
+    if (buffer_flags & PIO_BF_WRITEBUF)
         avail = buffer_size - (buffer_next - buffer_start);
-    }
+
     else if (buffer_flags & PIO_BF_READBUF) {
         buffer_flags &= ~PIO_BF_READBUF;
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
@@ -586,22 +589,24 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
         avail = buffer_size;
     }
-    else {
+    else
         avail = buffer_size;
-    }
+
     /* If we are line buffered, check for newlines.
-     * If any, we should flush
-     */
+     * If any, we should flush */
     need_flush = 0;
+
     if (Parrot_io_get_flags(interp, filehandle) & PIO_F_LINEBUF) {
         /* scan from end, it's likely that EOL is at end of string */
         const char *p = (char*)buffer + len - 1;
-        size_t i;
-        for (i = 0; i < len; ++i, --p)
+        size_t      i;
+
+        for (i = 0; i < len; ++i, --p) {
             if (io_is_end_of_line(p)) {
                 need_flush = 1;
                 break;
             }
+        }
     }
 
     /*
@@ -612,22 +617,24 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
      */
     if (need_flush || len >= buffer_size) {
         long wrote;
+
         /* Write through, skip buffer. */
         Parrot_io_flush(interp, filehandle);
         wrote = PIO_WRITE(interp, filehandle, s);
+
         if (wrote == (long)len) {
             Parrot_io_set_file_position(interp, filehandle, (wrote +
                         Parrot_io_get_file_position(interp, filehandle)));
             return wrote;
         }
-        else {
-            return (size_t)-1; /* Write error */
-        }
+        /* Write error */
+        else
+            return (size_t)-1;
     }
     else if (avail > len) {
         buffer_flags |= PIO_BF_WRITEBUF;
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
-        memcpy(buffer_next, buffer, len);
+        memmove(buffer_next, buffer, len);
         buffer_next += len;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
         Parrot_io_set_file_position(interp, filehandle, (len +
@@ -639,15 +646,16 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
 
         buffer_flags |= PIO_BF_WRITEBUF;
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
+
         /* Fill remainder, flush, then try to buffer more */
-        memcpy(buffer_next, buffer, avail);
+        memmove(buffer_next, buffer, avail);
         buffer_next += avail;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
         Parrot_io_set_file_position(interp, filehandle, (avail +
                     Parrot_io_get_file_position(interp, filehandle)));
         Parrot_io_flush(interp, filehandle);
         buffer_next = Parrot_io_get_buffer_next(interp, filehandle);
-        memcpy(buffer_start, ((const char *)buffer + avail), diff);
+        memmove(buffer_start, ((const char *)buffer + avail), diff);
         Parrot_io_set_buffer_start(interp, filehandle, buffer_start);
         buffer_next += diff;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
@@ -657,6 +665,7 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
     }
 }
 
+
 /*
 
 =item C<PIOOFF_T Parrot_io_seek_buffer>
@@ -671,6 +680,7 @@ PIOOFF_T
 Parrot_io_seek_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
         PIOOFF_T offset, INTVAL whence)
 {
+    ASSERT_ARGS(Parrot_io_seek_buffer)
     PIOOFF_T newpos;
     PIOOFF_T file_pos = Parrot_io_get_file_position(interp, filehandle);
     unsigned char *buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
@@ -729,6 +739,7 @@ the new architecture.
 static INTVAL
 io_is_end_of_line(ARGIN(const char *c))
 {
+    ASSERT_ARGS(io_is_end_of_line)
     if ((*(c)) == '\n')
         return 1;
 
