@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/key.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/key.c 35697 2009-01-17T09:02:00.190698Z cotto  $
 
 =head1 NAME
 
@@ -40,6 +40,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new(PARROT_INTERP)
 {
+    ASSERT_ARGS(key_new)
     return pmc_new(interp, enum_class_Key);
 }
 
@@ -60,6 +61,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new_integer(PARROT_INTERP, INTVAL value)
 {
+    ASSERT_ARGS(key_new_integer)
     PMC * const key = pmc_new(interp, enum_class_Key);
 
     PObj_get_FLAGS(key) |= KEY_integer_FLAG;
@@ -85,10 +87,11 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new_number(PARROT_INTERP, FLOATVAL value)
 {
+    ASSERT_ARGS(key_new_number)
     PMC * const key = pmc_new(interp, enum_class_Key);
 
     PObj_get_FLAGS(key) |= KEY_number_FLAG;
-    PMC_num_val(key)     = value;
+    VTABLE_set_number_native(interp, key, value);
 
     return key;
 }
@@ -110,6 +113,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new_string(PARROT_INTERP, ARGIN(STRING *value))
 {
+    ASSERT_ARGS(key_new_string)
     PMC * const key = pmc_new(interp, enum_class_Key);
 
     PObj_get_FLAGS(key) |= KEY_string_FLAG;
@@ -136,6 +140,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new_cstring(PARROT_INTERP, ARGIN_NULLOK(const char *value))
 {
+    ASSERT_ARGS(key_new_cstring)
     return key_new_string(interp, string_from_cstring(interp, value, 0));
 }
 
@@ -156,6 +161,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_new_pmc(PARROT_INTERP, ARGIN(PMC *value))
 {
+    ASSERT_ARGS(key_new_pmc)
     PMC * const key = pmc_new(interp, enum_class_Key);
 
     PObj_get_FLAGS(key) |= KEY_pmc_FLAG;
@@ -177,6 +183,7 @@ PARROT_EXPORT
 void
 key_set_integer(SHIM_INTERP, ARGMOD(PMC *key), INTVAL value)
 {
+    ASSERT_ARGS(key_set_integer)
     PObj_get_FLAGS(key) &= ~KEY_type_FLAGS;
     PObj_get_FLAGS(key) |=  KEY_integer_FLAG;
     PMC_int_val(key)     = value;
@@ -199,6 +206,7 @@ PARROT_EXPORT
 void
 key_set_register(SHIM_INTERP, ARGMOD(PMC *key), INTVAL value, INTVAL flag)
 {
+    ASSERT_ARGS(key_set_register)
     PObj_get_FLAGS(key) &= ~KEY_type_FLAGS;
     PObj_get_FLAGS(key) |=  KEY_register_FLAG | flag;
     PMC_int_val(key)     = value;
@@ -219,11 +227,12 @@ Set the number C<value> in C<key>.
 
 PARROT_EXPORT
 void
-key_set_number(SHIM_INTERP, ARGMOD(PMC *key), FLOATVAL value)
+key_set_number(PARROT_INTERP, ARGMOD(PMC *key), FLOATVAL value)
 {
+    ASSERT_ARGS(key_set_number)
     PObj_get_FLAGS(key) &= ~KEY_type_FLAGS;
     PObj_get_FLAGS(key) |=  KEY_number_FLAG;
-    PMC_num_val(key)     = value;
+    VTABLE_set_number_native(interp, key, value);
 
     return;
 }
@@ -243,6 +252,7 @@ PARROT_EXPORT
 void
 key_set_string(SHIM_INTERP, ARGMOD(PMC *key), ARGIN(STRING *value))
 {
+    ASSERT_ARGS(key_set_string)
     PObj_get_FLAGS(key) &= ~KEY_type_FLAGS;
     PObj_get_FLAGS(key) |=  KEY_string_FLAG;
     PMC_str_val(key)     = value;
@@ -265,6 +275,7 @@ PARROT_EXPORT
 void
 key_set_pmc(PARROT_INTERP, ARGMOD(PMC *key), ARGIN(PMC *value))
 {
+    ASSERT_ARGS(key_set_pmc)
     PObj_get_FLAGS(key) &= ~KEY_type_FLAGS;
     PObj_get_FLAGS(key) |=  KEY_pmc_FLAG;
 
@@ -291,6 +302,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 key_type(SHIM_INTERP, ARGIN(const PMC *key))
 {
+    ASSERT_ARGS(key_type)
     return (PObj_get_FLAGS(key) & KEY_type_FLAGS) & ~KEY_register_FLAG;
 }
 
@@ -312,6 +324,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 key_integer(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_integer)
     if (VTABLE_isa(interp, key, CONST_STRING(interp, "Key"))) {
         switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
         case KEY_hash_iterator_FLAGS:
@@ -366,9 +379,10 @@ PARROT_WARN_UNUSED_RESULT
 FLOATVAL
 key_number(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_number)
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
     case KEY_number_FLAG:
-        return PMC_num_val(key);
+        return VTABLE_get_number(interp, key);
     case KEY_number_FLAG | KEY_register_FLAG:
         return REG_NUM(interp, PMC_int_val(key));
     case KEY_pmc_FLAG:
@@ -402,6 +416,7 @@ PARROT_CANNOT_RETURN_NULL
 STRING *
 key_string(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_string)
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
         /* remember to COW strings instead of returning them directly */
         case KEY_string_FLAG:
@@ -452,6 +467,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_pmc(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_pmc)
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
     case KEY_pmc_FLAG | KEY_register_FLAG:
         return REG_PMC(interp, PMC_int_val(key));
@@ -477,6 +493,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 key_next(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_next)
     return VTABLE_isa(interp, key, CONST_STRING(interp, "Key")) && key->pmc_ext
         ? (PMC *)PMC_data(key)
         : NULL;
@@ -504,6 +521,7 @@ PARROT_IGNORABLE_RESULT
 PMC *
 key_append(SHIM_INTERP, ARGMOD(PMC *key1), ARGIN(PMC *key2))
 {
+    ASSERT_ARGS(key_append)
     PMC *tail = key1;
 
     while (PMC_data(tail)) {
@@ -530,6 +548,7 @@ PARROT_EXPORT
 void
 key_mark(PARROT_INTERP, ARGIN(PMC *key))
 {
+    ASSERT_ARGS(key_mark)
     const UINTVAL flags = PObj_get_FLAGS(key) & KEY_type_FLAGS;
 
     if (flags == KEY_string_FLAG)
@@ -567,6 +586,7 @@ PARROT_WARN_UNUSED_RESULT
 STRING *
 key_set_to_string(PARROT_INTERP, ARGIN_NULLOK(PMC *key))
 {
+    ASSERT_ARGS(key_set_to_string)
     STRING * const semicolon = CONST_STRING(interp, " ; ");
     STRING * const quote     = CONST_STRING(interp, "'");
     STRING        *value     = string_from_cstring(interp, "[ ", 2);
