@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2002-2008, The Perl Foundation.
 License:  Artistic 2.0, see README and LICENSE for details
-$Id: /mirror/trunk/src/list.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/list.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -250,12 +250,11 @@ static void * list_item(PARROT_INTERP,
 
 static void list_set(PARROT_INTERP,
     ARGMOD(List *list),
-    ARGIN(void *item),
+    ARGIN_NULLOK(void *item),
     INTVAL type,
     INTVAL idx)
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
-        __attribute__nonnull__(3)
         FUNC_MODIFIES(*list);
 
 static UINTVAL rebuild_chunk_list(PARROT_INTERP, ARGMOD(List *list))
@@ -290,6 +289,44 @@ static void split_chunk(PARROT_INTERP,
         FUNC_MODIFIES(*list)
         FUNC_MODIFIES(*chunk);
 
+#define ASSERT_ARGS_add_chunk __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_alloc_next_size __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_allocate_chunk __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_get_chunk __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list) \
+    || PARROT_ASSERT_ARG(idx)
+#define ASSERT_ARGS_list_append __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_list_item __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_list_set __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_rebuild_chunk_list __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_rebuild_chunk_ptrs __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_rebuild_fix_ends __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_rebuild_other __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_rebuild_sparse __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(list)
+#define ASSERT_ARGS_split_chunk __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(list) \
+    || PARROT_ASSERT_ARG(chunk)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -318,6 +355,7 @@ PARROT_WARN_UNUSED_RESULT
 static List_chunk *
 allocate_chunk(PARROT_INTERP, ARGIN(List *list), UINTVAL items, UINTVAL size)
 {
+    ASSERT_ARGS(allocate_chunk)
     List_chunk *chunk;
 
     Parrot_block_GC_mark(interp);
@@ -353,6 +391,7 @@ counts chunks and fixes C<prev> pointers.
 static void
 rebuild_chunk_ptrs(ARGMOD(List *list), int cut)
 {
+    ASSERT_ARGS(rebuild_chunk_ptrs)
     List_chunk *chunk, *prev;
     UINTVAL len = 0, start = list->start;
     UINTVAL cap;
@@ -402,6 +441,7 @@ Combines together adjacent sparse chunks in C<list>.
 static void
 rebuild_sparse(ARGMOD(List *list))
 {
+    ASSERT_ARGS(rebuild_sparse)
     List_chunk *chunk = list->first;
     List_chunk *prev = NULL;
     int changes = 0;
@@ -433,6 +473,7 @@ Combines together adjacent irregular chunks in C<list>.
 static void
 rebuild_other(PARROT_INTERP, ARGMOD(List *list))
 {
+    ASSERT_ARGS(rebuild_other)
     List_chunk *chunk = list->first;
     List_chunk *prev = NULL;
     int changes = 0;
@@ -501,6 +542,7 @@ Called by C<rebuild_chunk_list()>.
 static void
 rebuild_fix_ends(ARGMOD(List *list))
 {
+    ASSERT_ARGS(rebuild_fix_ends)
     List_chunk * const chunk = list->first;
 
     /* first is irregular, next is empty */
@@ -531,6 +573,7 @@ and computes list statistics.
 static UINTVAL
 rebuild_chunk_list(PARROT_INTERP, ARGMOD(List *list))
 {
+    ASSERT_ARGS(rebuild_chunk_list)
     List_chunk *chunk, *prev, *first;
     UINTVAL len;
 
@@ -646,36 +689,40 @@ PARROT_CANNOT_RETURN_NULL
 static List_chunk *
 alloc_next_size(PARROT_INTERP, ARGMOD(List *list), int where, UINTVAL idx)
 {
+    ASSERT_ARGS(alloc_next_size)
     UINTVAL items, size;
     List_chunk *new_chunk;
     const int much = idx - list->cap >= MIN_ITEMS;
     int do_sparse = (INTVAL)idx - (INTVAL)list->cap >= 10 * MAX_ITEMS;
 
     if (list->item_type == enum_type_sized) {
-        items = list->items_per_chunk;
-        size = items * list->item_size;
+        do_sparse = 0;
+        items     = list->items_per_chunk;
+        size      = items * list->item_size;
+
         list->grow_policy = items == MAX_ITEMS ?
             enum_grow_fixed : enum_grow_mixed;
-        do_sparse = 0;
     }
     else if (do_sparse) {
         PARROT_ASSERT(where);
         /* don't add sparse chunk at start of list */
         if (!list->n_chunks) {
-            list->grow_policy = enum_grow_fixed;
-            /* if wee need more, the next allocation will allocate the rest */
-            items = MAX_ITEMS;
-            size = items * list->item_size;
             do_sparse = 0;
+            items     = MAX_ITEMS;
+
+            /* if we need more, the next allocation will allocate the rest */
+            size = items * list->item_size;
+            list->grow_policy = enum_grow_fixed;
         }
         else {
+            /* allocate a dummy chunk holding many items virtually */
+            size  = list->item_size;
             items = idx - list->cap - 1;
+
             /* round down this function will then be called again, to add the
              * final real chunk, with the rest of the needed size */
             items &= ~(MAX_ITEMS - 1);
             list->grow_policy = enum_grow_mixed;
-            /* allocate a dummy chunk holding many items virtually */
-            size = list->item_size;
         }
     }
     /* initial size for empty lists grow_policy is not yet known or was
@@ -746,15 +793,17 @@ PARROT_CANNOT_RETURN_NULL
 static List_chunk *
 add_chunk(PARROT_INTERP, ARGMOD(List *list), int where, UINTVAL idx)
 {
+    ASSERT_ARGS(add_chunk)
     List_chunk * const chunk = where ? list->last : list->first;
     List_chunk * const new_chunk = alloc_next_size(interp, list, where, idx);
 
     if (where) {                /* at end */
         if (chunk)
             chunk->next = new_chunk;
-        list->last = new_chunk;
         if (!list->first)
             list->first = new_chunk;
+
+        list->last = new_chunk;
     }
     else {
         new_chunk->next = chunk;
@@ -783,6 +832,7 @@ PARROT_WARN_UNUSED_RESULT
 UINTVAL
 ld(UINTVAL x)
 {
+    ASSERT_ARGS(ld)
     UINTVAL m;                  /* bit position of highest set bit of m */
 
     /* On intel, use BSRL instruction to find highest bit */
@@ -876,6 +926,7 @@ PARROT_CANNOT_RETURN_NULL
 static List_chunk *
 get_chunk(PARROT_INTERP, ARGMOD(List *list), ARGMOD(UINTVAL *idx))
 {
+    ASSERT_ARGS(get_chunk)
     List_chunk *chunk;
     UINTVAL i;
 
@@ -995,6 +1046,7 @@ would make C<MAX_ITEMS> sized real chunks.
 static void
 split_chunk(PARROT_INTERP, ARGMOD(List *list), ARGMOD(List_chunk *chunk), UINTVAL ix)
 {
+    ASSERT_ARGS(split_chunk)
     /* allocate space at idx */
     if (chunk->items <= MAX_ITEMS) {
         /* it fits, just allocate */
@@ -1057,8 +1109,10 @@ Sets C<item> of type C<type> in chunk at C<idx>.
 */
 
 static void
-list_set(PARROT_INTERP, ARGMOD(List *list), ARGIN(void *item), INTVAL type, INTVAL idx)
+list_set(PARROT_INTERP, ARGMOD(List *list), ARGIN_NULLOK(void *item),
+        INTVAL type, INTVAL idx)
 {
+    ASSERT_ARGS(list_set)
     const INTVAL oidx = idx;
     List_chunk *chunk = get_chunk(interp, list, (UINTVAL *)&idx);
 
@@ -1127,6 +1181,7 @@ PARROT_CANNOT_RETURN_NULL
 static void *
 list_item(PARROT_INTERP, ARGMOD(List *list), int type, INTVAL idx)
 {
+    ASSERT_ARGS(list_item)
     List_chunk * const chunk = get_chunk(interp, list, (UINTVAL *)&idx);
     /* if this is a sparse chunk return -1, the caller may decide to return 0
      * or undef or whatever */
@@ -1176,6 +1231,7 @@ Adds one or more chunks to end of list.
 static void
 list_append(PARROT_INTERP, ARGMOD(List *list), ARGIN_NULLOK(void *item), int type, UINTVAL idx)
 {
+    ASSERT_ARGS(list_append)
     /* initially, list may be empty, also used by assign */
     while (idx >= list->cap)
         add_chunk(interp, list, enum_add_at_end, idx);
@@ -1207,6 +1263,7 @@ PARROT_CANNOT_RETURN_NULL
 List *
 list_new(PARROT_INTERP, PARROT_DATA_TYPE type)
 {
+    ASSERT_ARGS(list_new)
     List * const list = (List *)new_bufferlike_header(interp, sizeof (*list));
 
     list->item_type = type;
@@ -1254,6 +1311,7 @@ PARROT_EXPORT
 void
 list_pmc_new(PARROT_INTERP, ARGMOD(PMC *container))
 {
+    ASSERT_ARGS(list_pmc_new)
     List * const l = list_new(interp, enum_type_PMC);
     l->container = container;
     PMC_data(container) = l;
@@ -1284,6 +1342,7 @@ PARROT_CANNOT_RETURN_NULL
 List *
 list_new_init(PARROT_INTERP, PARROT_DATA_TYPE type, ARGIN(PMC *init))
 {
+    ASSERT_ARGS(list_new_init)
     List  *list;
     PMC   *user_array;
     PMC   *multi_key       = NULL;
@@ -1371,6 +1430,7 @@ PARROT_EXPORT
 void
 list_pmc_new_init(PARROT_INTERP, ARGMOD(PMC *container), ARGIN(PMC *init))
 {
+    ASSERT_ARGS(list_pmc_new_init)
     List * const l = list_new_init(interp, enum_type_PMC, init);
     l->container = container;
     PMC_data(container) = l;
@@ -1398,6 +1458,7 @@ PARROT_CANNOT_RETURN_NULL
 List *
 list_clone(PARROT_INTERP, ARGIN(const List *other))
 {
+    ASSERT_ARGS(list_clone)
     List *l;
     List_chunk *chunk, *prev;
     UINTVAL i;
@@ -1472,6 +1533,7 @@ PARROT_EXPORT
 void
 list_mark(PARROT_INTERP, ARGMOD(List *list))
 {
+    ASSERT_ARGS(list_mark)
     List_chunk *chunk;
 
     for (chunk = list->first; chunk; chunk = chunk->next) {
@@ -1511,6 +1573,7 @@ PARROT_EXPORT
 void
 list_visit(PARROT_INTERP, ARGIN(List *list), ARGMOD(void *pinfo))
 {
+    ASSERT_ARGS(list_visit)
     List_chunk *chunk;
     visit_info * const info = (visit_info*) pinfo;
     UINTVAL idx;
@@ -1549,6 +1612,7 @@ PARROT_PURE_FUNCTION
 INTVAL
 list_length(SHIM_INTERP, ARGIN(const List *list))
 {
+    ASSERT_ARGS(list_length)
     return list->length;
 }
 
@@ -1566,6 +1630,7 @@ PARROT_EXPORT
 void
 list_set_length(PARROT_INTERP, ARGMOD(List *list), INTVAL len)
 {
+    ASSERT_ARGS(list_set_length)
     if (len < 0)
         len += list->length;
     if (len >= 0) {
@@ -1605,6 +1670,7 @@ PARROT_EXPORT
 void
 list_insert(PARROT_INTERP, ARGMOD(List *list), INTVAL idx, INTVAL n_items)
 {
+    ASSERT_ARGS(list_insert)
     List_chunk *chunk;
 
     PARROT_ASSERT(idx >= 0);
@@ -1678,6 +1744,7 @@ PARROT_EXPORT
 void
 list_delete(PARROT_INTERP, ARGMOD(List *list), INTVAL idx, INTVAL n_items)
 {
+    ASSERT_ARGS(list_delete)
     List_chunk *chunk;
 
     PARROT_ASSERT(idx >= 0);
@@ -1758,8 +1825,9 @@ Pushes C<item> of type C<type> on to the end of the list.
 
 PARROT_EXPORT
 void
-list_push(PARROT_INTERP, ARGMOD(List *list), ARGIN(void *item), int type)
+list_push(PARROT_INTERP, ARGMOD(List *list), ARGIN_NULLOK(void *item), int type)
 {
+    ASSERT_ARGS(list_push)
     const INTVAL idx = list->start + list->length++;
 
     list_append(interp, list, item, type, idx);
@@ -1779,6 +1847,7 @@ PARROT_EXPORT
 void
 list_unshift(PARROT_INTERP, ARGMOD(List *list), ARGIN(void *item), int type)
 {
+    ASSERT_ARGS(list_unshift)
     List_chunk *chunk;
 
     if (list->start == 0) {
@@ -1806,6 +1875,7 @@ PARROT_CAN_RETURN_NULL
 void *
 list_pop(PARROT_INTERP, ARGMOD(List *list), int type)
 {
+    ASSERT_ARGS(list_pop)
     UINTVAL idx;
     void *ret;
     List_chunk *chunk = list->last;
@@ -1844,6 +1914,7 @@ PARROT_CAN_RETURN_NULL
 void *
 list_shift(PARROT_INTERP, ARGMOD(List *list), int type)
 {
+    ASSERT_ARGS(list_shift)
     void *ret;
     UINTVAL idx;
     List_chunk *chunk = list->first;
@@ -1880,8 +1951,9 @@ Assigns C<item> of type C<type> to index C<idx>.
 
 PARROT_EXPORT
 void
-list_assign(PARROT_INTERP, ARGMOD(List *list), INTVAL idx, ARGIN(void *item), int type)
+list_assign(PARROT_INTERP, ARGMOD(List *list), INTVAL idx, ARGIN_NULLOK(void *item), int type)
 {
+    ASSERT_ARGS(list_assign)
     const INTVAL length = list->length;
 
     if (idx < -length)
@@ -1913,6 +1985,7 @@ PARROT_WARN_UNUSED_RESULT
 void *
 list_get(PARROT_INTERP, ARGMOD(List *list), INTVAL idx, int type)
 {
+    ASSERT_ARGS(list_get)
     const INTVAL length = list->length;
 
     if (idx >= length || -idx > length) {
@@ -1942,6 +2015,7 @@ void
 list_splice(PARROT_INTERP, ARGMOD(List *list), ARGIN_NULLOK(List *value_list),
         INTVAL offset, INTVAL count)
 {
+    ASSERT_ARGS(list_splice)
     const INTVAL value_length = value_list ? value_list->length : 0;
     const INTVAL length = list->length;
     const int type = list->item_type;
