@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/longopt.c 32919 2008-11-19T17:21:15.952103Z particle  $
+$Id: /mirror/trunk/src/longopt.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -48,6 +48,16 @@ static int longopt_get_shortopt(PARROT_INTERP,
         __attribute__nonnull__(5)
         FUNC_MODIFIES(* info_buf);
 
+#define ASSERT_ARGS_longopt_get_longopt __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(argv) \
+    || PARROT_ASSERT_ARG(options) \
+    || PARROT_ASSERT_ARG(info_buf)
+#define ASSERT_ARGS_longopt_get_shortopt __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(argv) \
+    || PARROT_ASSERT_ARG(options) \
+    || PARROT_ASSERT_ARG(info_buf)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -78,6 +88,7 @@ longopt_get(PARROT_INTERP, int argc, ARGIN(const char* argv[]),
             ARGIN(const struct longopt_opt_decl options[]),
             ARGMOD(struct longopt_opt_info* info_buf))
 {
+    ASSERT_ARGS(longopt_get)
     const int dex = info_buf->opt_index;
 
     info_buf->opt_id = 0;
@@ -126,6 +137,7 @@ longopt_get_longopt(PARROT_INTERP, int argc, ARGIN(const char* argv[]),
                     ARGIN(const struct longopt_opt_decl options[]),
                     ARGMOD(struct longopt_opt_info* info_buf))
 {
+    ASSERT_ARGS(longopt_get_longopt)
     const int dex = info_buf->opt_index;
     int optlen = 0;
     const struct longopt_opt_decl* dptr;
@@ -220,6 +232,7 @@ longopt_get_shortopt(PARROT_INTERP, int argc, ARGIN(const char* argv[]),
                      ARGIN(const struct longopt_opt_decl options[]),
                      ARGMOD(struct longopt_opt_info* info_buf))
 {
+    ASSERT_ARGS(longopt_get_shortopt)
     const int dex = info_buf->opt_index;
     const struct longopt_opt_decl* dptr;
     const char* pos;
