@@ -2,7 +2,7 @@
 Copyright (C) 2001-2008, The Perl Foundation.
 This program is free software. It is subject to the same license as
 Parrot itself.
-$Id: /mirror/trunk/src/packdump.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/packdump.c 35694 2009-01-17T04:47:44.432084Z infinoid  $
 
 =head1 NAME
 
@@ -38,6 +38,12 @@ static void PackFile_Constant_dump(PARROT_INTERP,
 static void pobj_flag_dump(PARROT_INTERP, ARGIN_NULLOK(long flags))
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_PackFile_Constant_dump __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(ct) \
+    || PARROT_ASSERT_ARG(self)
+#define ASSERT_ARGS_pobj_flag_dump __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -56,6 +62,7 @@ PARROT_EXPORT
 void
 PackFile_ConstTable_dump(PARROT_INTERP, ARGIN(const PackFile_ConstTable *self))
 {
+    ASSERT_ARGS(PackFile_ConstTable_dump)
     opcode_t i;
 
     for (i = 0; i < self->const_count; i++) {
@@ -112,12 +119,13 @@ static const char *flag_bit_names[] =
     "is_object"
 };
 
-static void
-pobj_flag_dump(PARROT_INTERP, ARGIN_NULLOK(long flags))
 /* Given a word of flags, generate a dump line of the whole word in hex,
  * followed by individual bits.
  */
+static void
+pobj_flag_dump(PARROT_INTERP, ARGIN_NULLOK(long flags))
 {
+    ASSERT_ARGS(pobj_flag_dump)
     INTVAL idx = 0;
     int printed_flag_p = 0;
 
@@ -139,6 +147,7 @@ static void
 PackFile_Constant_dump(PARROT_INTERP, ARGIN(const PackFile_ConstTable *ct),
                        ARGIN(const PackFile_Constant *self))
 {
+    ASSERT_ARGS(PackFile_Constant_dump)
     PMC *key;
     size_t i;
 
@@ -360,6 +369,7 @@ PARROT_EXPORT
 void
 PackFile_Fixup_dump(PARROT_INTERP, ARGIN(const PackFile_FixupTable *ft))
 {
+    ASSERT_ARGS(PackFile_Fixup_dump)
     opcode_t i;
 
     for (i = 0; i < ft->fixup_count; i++) {
