@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2003, The Perl Foundation.
-$Id: /mirror/trunk/src/pbc_disassemble.c 29340 2008-07-11T23:00:45.049706Z julianalbo  $
+$Id: /mirror/trunk/src/pbc_disassemble.c 34761 2009-01-01T02:15:46.952534Z infinoid  $
 
 =head1 NAME
 
@@ -82,7 +82,7 @@ main(int argc, char *argv[])
 
 /*
 
-=item C<static void do_dis(Parrot_Interp interp)>
+=item C<static void do_dis(PARROT_INTERP)>
 
 Do the disassembling.
 
@@ -91,7 +91,7 @@ Do the disassembling.
 */
 
 static void
-do_dis(Parrot_Interp interp)
+do_dis(PARROT_INTERP)
 {
     Parrot_disassemble(interp);
 }
