@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2005-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/pbc_merge.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/pbc_merge.c 35120 2009-01-07T05:35:06.691952Z infinoid  $
 
 =head1 NAME
 
@@ -160,6 +160,46 @@ static void pbc_merge_write(PARROT_INTERP,
         __attribute__nonnull__(3)
         FUNC_MODIFIES(*pf);
 
+#define ASSERT_ARGS_help __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_pbc_merge_begin __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs)
+#define ASSERT_ARGS_pbc_merge_bytecode __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(pf)
+#define ASSERT_ARGS_pbc_merge_constants __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(pf) \
+    || PARROT_ASSERT_ARG(bc)
+#define ASSERT_ARGS_pbc_merge_ctpointers __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(bc)
+#define ASSERT_ARGS_pbc_merge_debugs __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(pf) \
+    || PARROT_ASSERT_ARG(bc)
+#define ASSERT_ARGS_pbc_merge_fixups __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(pf) \
+    || PARROT_ASSERT_ARG(bc)
+#define ASSERT_ARGS_pbc_merge_loadpbc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(fullname)
+#define ASSERT_ARGS_pbc_merge_pic_index __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(inputs) \
+    || PARROT_ASSERT_ARG(pf) \
+    || PARROT_ASSERT_ARG(bc)
+#define ASSERT_ARGS_pbc_merge_write __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pf) \
+    || PARROT_ASSERT_ARG(filename)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -200,6 +240,7 @@ PARROT_CANNOT_RETURN_NULL
 static PackFile*
 pbc_merge_loadpbc(PARROT_INTERP, ARGIN(const char *fullname))
 {
+    ASSERT_ARGS(pbc_merge_loadpbc)
     INTVAL program_size, wanted;
     char *program_code;
     PackFile *pf;
@@ -291,9 +332,10 @@ static PackFile_ByteCode*
 pbc_merge_bytecode(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
                    int num_inputs, ARGMOD(PackFile *pf))
 {
+    ASSERT_ARGS(pbc_merge_bytecode)
+    int i;
     opcode_t *bc = mem_allocate_typed(opcode_t);
     opcode_t cursor = 0;
-    int i;
 
     /* Add a bytecode segment. */
     PackFile_ByteCode * const bc_seg =
@@ -355,9 +397,10 @@ static PackFile_ConstTable*
 pbc_merge_constants(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
                     int num_inputs, ARGMOD(PackFile *pf), ARGMOD(PackFile_ByteCode *bc))
 {
+    ASSERT_ARGS(pbc_merge_constants)
+    int i, j;
     PackFile_Constant   **constants = mem_allocate_typed(PackFile_Constant *);
     opcode_t cursor = 0;
-    int i, j;
 
     /* Add a constant table segment. */
     PackFile_ConstTable * const const_seg = (PackFile_ConstTable*)PackFile_Segment_new_seg(
@@ -450,10 +493,11 @@ static void
 pbc_merge_fixups(PARROT_INTERP, ARGIN(pbc_merge_input **inputs),
                  int num_inputs, ARGMOD(PackFile *pf), ARGMOD(PackFile_ByteCode *bc))
 {
+    ASSERT_ARGS(pbc_merge_fixups)
+    int i, j;
     PackFile_FixupTable *fixup_seg;
     PackFile_FixupEntry **fixups = mem_allocate_typed(PackFile_FixupEntry *);
     opcode_t cursor = 0;
-    int i, j;
 
     /* Add a fixup table segment. */
     fixup_seg = (PackFile_FixupTable*)PackFile_Segment_new_seg(
@@ -545,13 +589,14 @@ static void
 pbc_merge_debugs(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
                  int num_inputs, ARGMOD(PackFile *pf), ARGMOD(PackFile_ByteCode *bc))
 {
+    ASSERT_ARGS(pbc_merge_debugs)
+    int i, j;
     PackFile_Debug *debug_seg;
     opcode_t *lines                  = mem_allocate_typed(opcode_t);
-    PackFile_DebugMapping **mappings =
-        mem_allocate_typed(PackFile_DebugMapping *);
+    PackFile_DebugFilenameMapping **mappings =
+        mem_allocate_typed(PackFile_DebugFilenameMapping *);
     opcode_t num_mappings = 0;
     opcode_t num_lines    = 0;
-    int i, j;
 
     /* We need to merge both the mappings and the list of line numbers.
        The line numbers can just be concatenated. The mappings must have
@@ -570,16 +615,15 @@ pbc_merge_debugs(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
             in_seg->base.size * sizeof (opcode_t));
 
         /* Concatenate mappings. */
-        mappings = (PackFile_DebugMapping **)mem_sys_realloc(mappings,
+        mappings = (PackFile_DebugFilenameMapping **)mem_sys_realloc(mappings,
                    (num_mappings + in_seg->num_mappings) *
                    sizeof (Parrot_Pointer));
         for (j = 0; j < in_seg->num_mappings; j++) {
-            PackFile_DebugMapping *mapping = mem_allocate_typed(
-                PackFile_DebugMapping);
+            PackFile_DebugFilenameMapping *mapping = mem_allocate_typed(
+                PackFile_DebugFilenameMapping);
             STRUCT_COPY(mapping, in_seg->mappings[j]);
             mapping->offset += num_lines;
-            if (mapping->mapping_type == PF_DEBUGMAPPINGTYPE_FILENAME)
-                mapping->u.filename += inputs[i]->const_start;
+            mapping->filename += inputs[i]->const_start;
             mappings[num_mappings + j] = mapping;
         }
 
@@ -615,6 +659,7 @@ static void
 pbc_merge_pic_index(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
                  int num_inputs, ARGMOD(PackFile *pf), ARGMOD(PackFile_ByteCode *bc))
 {
+    ASSERT_ARGS(pbc_merge_pic_index)
     int i;
     PackFile_Segment *pic_index;
     size_t size;
@@ -667,11 +712,12 @@ static void
 pbc_merge_ctpointers(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs),
                      int num_inputs, ARGMOD(PackFile_ByteCode *bc))
 {
+    ASSERT_ARGS(pbc_merge_ctpointers)
+    int        cur_arg;
     opcode_t  *op_ptr;
     opcode_t  *ops       = bc->base.data;
     opcode_t   cur_op    = 0;
     int        cur_input = 0;
-    int        cur_arg;
 
     /* Loop over the ops in the merged bytecode. */
     while (cur_op < (opcode_t)bc->base.size) {
@@ -749,6 +795,7 @@ PARROT_CANNOT_RETURN_NULL
 static PackFile*
 pbc_merge_begin(PARROT_INTERP, ARGMOD(pbc_merge_input **inputs), int num_inputs)
 {
+    ASSERT_ARGS(pbc_merge_begin)
     PackFile_ByteCode   *bc;
     PackFile_ConstTable *ct;
 
@@ -789,6 +836,7 @@ This functions writes out the merged packfile.
 static void
 pbc_merge_write(PARROT_INTERP, ARGMOD(PackFile *pf), ARGIN(const char *filename))
 {
+    ASSERT_ARGS(pbc_merge_write)
     FILE     *fp;
 
     /* Get size of packfile we'll write. */
