@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2006-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/pic_jit.c 33496 2008-12-03T21:54:04.801275Z allison  $
+$Id: /mirror/trunk/src/pic_jit.c 35845 2009-01-20T16:33:48.434431Z julianalbo  $
 
 =head1 NAME
 
@@ -49,19 +49,22 @@ static int args_match_params(
         __attribute__nonnull__(3);
 
 PARROT_WARN_UNUSED_RESULT
-static int call_is_safe(ARGIN(const PMC *sub), ARGMOD(opcode_t **set_args))
+static int call_is_safe(PARROT_INTERP,
+    ARGIN(PMC *sub),
+    ARGMOD(opcode_t **set_args))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2)
+        __attribute__nonnull__(3)
         FUNC_MODIFIES(*set_args);
 
 PARROT_WARN_UNUSED_RESULT
-static int jit_can_compile_sub(PARROT_INTERP, ARGIN(const PMC *sub))
+static int jit_can_compile_sub(PARROT_INTERP, ARGIN(PMC *sub))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
 PARROT_WARN_UNUSED_RESULT
 static int ops_jittable(PARROT_INTERP,
-    ARGIN(const PMC *sub),
+    ARGIN(PMC *sub),
     ARGIN(const PMC *sig_results),
     ARGIN(const PackFile_ByteCode *seg),
     ARGIN(opcode_t *pc),
@@ -92,6 +95,31 @@ static int returns_match_results(
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
+#define ASSERT_ARGS_args_match_params __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(sig_args) \
+    || PARROT_ASSERT_ARG(seg) \
+    || PARROT_ASSERT_ARG(start)
+#define ASSERT_ARGS_call_is_safe __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sub) \
+    || PARROT_ASSERT_ARG(set_args)
+#define ASSERT_ARGS_jit_can_compile_sub __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sub)
+#define ASSERT_ARGS_ops_jittable __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(sub) \
+    || PARROT_ASSERT_ARG(sig_results) \
+    || PARROT_ASSERT_ARG(seg) \
+    || PARROT_ASSERT_ARG(pc) \
+    || PARROT_ASSERT_ARG(end) \
+    || PARROT_ASSERT_ARG(flags)
+#define ASSERT_ARGS_pic_test_func __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(args)
+#define ASSERT_ARGS_returns_match_results __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(sig_ret) \
+    || PARROT_ASSERT_ARG(sig_result)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -104,6 +132,10 @@ static int returns_match_results(
 #  include "parrot/exec.h"
 #  include "jit.h"
 
+extern const jit_arch_info *
+Parrot_jit_init(PARROT_INTERP);
+
+
 #  ifdef PIC_TEST
 /*
  * just for testing the whole scheme ...
@@ -143,6 +175,7 @@ PARROT_CAN_RETURN_NULL
 static opcode_t *
 pic_test_func(PARROT_INTERP, SHIM(INTVAL *sig_bits), ARGOUT(void **args))
 {
+    ASSERT_ARGS(pic_test_func)
     INTVAL * const result = (INTVAL*) args[0];
     INTVAL   const i      = (INTVAL) args[1];
     INTVAL   const j      = (INTVAL) args[2];
@@ -167,8 +200,9 @@ are used then JIT supports. Returns 1 if it does not use too many registers.
 
 PARROT_WARN_UNUSED_RESULT
 static int
-jit_can_compile_sub(PARROT_INTERP, ARGIN(const PMC *sub))
+jit_can_compile_sub(PARROT_INTERP, ARGIN(PMC *sub))
 {
+    ASSERT_ARGS(jit_can_compile_sub)
     const jit_arch_info * const info = Parrot_jit_init(interp);
     const jit_arch_regs * const regs = info->regs + JIT_CODE_SUB_REGS_ONLY;
     INTVAL * const n_regs_used       = PMC_sub(sub)->n_regs_used;
@@ -212,6 +246,7 @@ static int
 args_match_params(ARGIN(const PMC *sig_args), ARGIN(const PackFile_ByteCode *seg),
     ARGIN(const opcode_t *start))
 {
+    ASSERT_ARGS(args_match_params)
     const PMC *sig_params;
     int n, type;
 
@@ -260,6 +295,7 @@ PARROT_WARN_UNUSED_RESULT
 static int
 returns_match_results(ARGIN(const PMC *sig_ret), ARGIN(const PMC *sig_result))
 {
+    ASSERT_ARGS(returns_match_results)
     int type;
     const int n = parrot_pic_check_sig(sig_ret, sig_result, &type);
 
@@ -296,8 +332,9 @@ Returns C<0> otherwise.
 
 PARROT_WARN_UNUSED_RESULT
 static int
-call_is_safe(ARGIN(const PMC *sub), ARGMOD(opcode_t **set_args))
+call_is_safe(PARROT_INTERP, ARGIN(PMC *sub), ARGMOD(opcode_t **set_args))
 {
+    ASSERT_ARGS(call_is_safe)
     PMC *called, *sig_results;
 
     opcode_t * pc        = *set_args;
@@ -346,10 +383,11 @@ otherwise.
 
 PARROT_WARN_UNUSED_RESULT
 static int
-ops_jittable(PARROT_INTERP, ARGIN(const PMC *sub), ARGIN(const PMC *sig_results),
+ops_jittable(PARROT_INTERP, ARGIN(PMC *sub), ARGIN(const PMC *sig_results),
         ARGIN(const PackFile_ByteCode *seg), ARGIN(opcode_t *pc),
         ARGIN(const opcode_t *end), ARGOUT(int *flags))
 {
+    ASSERT_ARGS(ops_jittable)
     while (pc < end) {
         /* special opcodes which are handled, but not marked as JITtable */
         int i;
@@ -373,7 +411,7 @@ ops_jittable(PARROT_INTERP, ARGIN(const PMC *sub), ARGIN(const PMC *sig_results)
                 break;
             case PARROT_OP_set_args_pc:
                 /* verify call, return address after the call */
-                if (!call_is_safe(sub, &pc))
+                if (!call_is_safe(interp, sub, &pc))
                     return 0;
                 *flags |= JIT_CODE_RECURSIVE;
                 continue;
@@ -421,9 +459,10 @@ RT#48260: Not yet documented!!!
 
 PARROT_WARN_UNUSED_RESULT
 int
-parrot_pic_is_safe_to_jit(PARROT_INTERP, ARGIN(const PMC *sub), ARGIN(const PMC *sig_args),
+parrot_pic_is_safe_to_jit(PARROT_INTERP, ARGIN(PMC *sub), ARGIN(const PMC *sig_args),
         ARGIN(const PMC *sig_results), ARGOUT(int *flags))
 {
+    ASSERT_ARGS(parrot_pic_is_safe_to_jit)
 #ifdef HAS_JIT
     opcode_t *base, *start, *end;
 
@@ -484,8 +523,9 @@ RT#48260: Not yet documented!!!
 */
 
 funcptr_t
-parrot_pic_JIT_sub(PARROT_INTERP, ARGIN(const PMC *sub), int flags)
+parrot_pic_JIT_sub(PARROT_INTERP, ARGIN(PMC *sub), int flags)
 {
+    ASSERT_ARGS(parrot_pic_JIT_sub)
 #ifdef HAS_JIT
 #  ifdef PIC_TEST
     UNUSED(interp);
