@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/pmc.c 33627 2008-12-07T08:21:36.967649Z chromatic  $
+$Id: /mirror/trunk/src/pmc.c 35845 2009-01-20T16:33:48.434431Z julianalbo  $
 
 =head1 NAME
 
@@ -50,6 +50,17 @@ static void pmc_free_to_pool(PARROT_INTERP,
         FUNC_MODIFIES(*pmc)
         FUNC_MODIFIES(*pool);
 
+#define ASSERT_ARGS_create_class_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_get_new_pmc_header __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_pmc_free __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc)
+#define ASSERT_ARGS_pmc_free_to_pool __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc) \
+    || PARROT_ASSERT_ARG(pool)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -72,6 +83,7 @@ PARROT_EXPORT
 INTVAL
 PMC_is_null(SHIM_INTERP, ARGIN_NULLOK(const PMC *pmc))
 {
+    ASSERT_ARGS(PMC_is_null)
 #if PARROT_CATCH_NULL
     return pmc == PMCNULL || pmc == NULL;
 #else
@@ -98,6 +110,7 @@ PARROT_WARN_UNUSED_RESULT
 PMC *
 pmc_new(PARROT_INTERP, INTVAL base_type)
 {
+    ASSERT_ARGS(pmc_new)
     PARROT_ASSERT(interp->vtables[base_type]);
     {
         PMC *const classobj = interp->vtables[base_type]->pmc_class;
@@ -132,6 +145,7 @@ PMC *
 pmc_reuse(PARROT_INTERP, ARGIN(PMC *pmc), INTVAL new_type,
           SHIM(UINTVAL flags))
 {
+    ASSERT_ARGS(pmc_reuse)
     VTABLE *new_vtable;
     INTVAL  has_ext, new_flags;
 
@@ -183,7 +197,7 @@ pmc_reuse(PARROT_INTERP, ARGIN(PMC *pmc), INTVAL new_type,
     }
     else {
         if (has_ext)
-            Parrot_free_pmc_ext(interp, pmc);
+            Parrot_gc_free_pmc_ext(interp, pmc);
 
 #if ! PMC_DATA_IN_EXT
         PMC_data(pmc) = NULL;
@@ -219,6 +233,7 @@ PARROT_CANNOT_RETURN_NULL
 static PMC *
 get_new_pmc_header(PARROT_INTERP, INTVAL base_type, UINTVAL flags)
 {
+    ASSERT_ARGS(get_new_pmc_header)
     PMC    *pmc;
     VTABLE *vtable = interp->vtables[base_type];
     UINTVAL vtable_flags;
@@ -250,7 +265,6 @@ get_new_pmc_header(PARROT_INTERP, INTVAL base_type, UINTVAL flags)
             PARROT_ASSERT(pmc);
 
             pmc->vtable    = vtable;
-            pmc->real_self = pmc;
             VTABLE_set_pointer(interp, pmc, pmc);
         }
 
@@ -287,9 +301,8 @@ get_new_pmc_header(PARROT_INTERP, INTVAL base_type, UINTVAL flags)
 
     pmc            = new_pmc_header(interp, flags);
     pmc->vtable    = vtable;
-    pmc->real_self = pmc;
 
-#ifdef GC_VERBOSE
+#if GC_VERBOSE
     if (Interp_flags_TEST(interp, PARROT_TRACE_FLAG)) {
         /* XXX make a more verbose trace flag */
         fprintf(stderr, "\t=> new %p type %d\n", pmc, (int)base_type);
@@ -318,6 +331,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 pmc_new_noinit(PARROT_INTERP, INTVAL base_type)
 {
+    ASSERT_ARGS(pmc_new_noinit)
     PMC *const classobj = interp->vtables[base_type]->pmc_class;
 
     if (!PMC_IS_NULL(classobj) && PObj_is_class_TEST(classobj))
@@ -342,6 +356,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 constant_pmc_new_noinit(PARROT_INTERP, INTVAL base_type)
 {
+    ASSERT_ARGS(constant_pmc_new_noinit)
     return get_new_pmc_header(interp, base_type, PObj_constant_FLAG);
 }
 
@@ -361,6 +376,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 constant_pmc_new(PARROT_INTERP, INTVAL base_type)
 {
+    ASSERT_ARGS(constant_pmc_new)
     PMC * const pmc = get_new_pmc_header(interp, base_type, PObj_constant_FLAG);
     VTABLE_init(interp, pmc);
     return pmc;
@@ -382,6 +398,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 pmc_new_init(PARROT_INTERP, INTVAL base_type, ARGOUT(PMC *init))
 {
+    ASSERT_ARGS(pmc_new_init)
     PMC *const classobj = interp->vtables[base_type]->pmc_class;
 
     if (!PMC_IS_NULL(classobj) && PObj_is_class_TEST(classobj))
@@ -410,6 +427,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 constant_pmc_new_init(PARROT_INTERP, INTVAL base_type, ARGIN_NULLOK(PMC *init))
 {
+    ASSERT_ARGS(constant_pmc_new_init)
     PMC * const pmc = get_new_pmc_header(interp, base_type, PObj_constant_FLAG);
     VTABLE_init_pmc(interp, pmc, init);
     return pmc;
@@ -444,6 +462,7 @@ PARROT_CANNOT_RETURN_NULL
 PMC *
 temporary_pmc_new(PARROT_INTERP, INTVAL base_type)
 {
+    ASSERT_ARGS(temporary_pmc_new)
     PMC * const pmc = get_new_pmc_header(interp, base_type, PObj_constant_FLAG);
     VTABLE_init(interp, pmc);
     return pmc;
@@ -467,11 +486,12 @@ static void
 pmc_free_to_pool(PARROT_INTERP, ARGMOD(PMC *pmc),
     ARGMOD(Small_Object_Pool *pool))
 {
+    ASSERT_ARGS(pmc_free_to_pool)
     if (PObj_active_destroy_TEST(pmc))
         VTABLE_destroy(interp, pmc);
 
     if (PObj_is_PMC_EXT_TEST(pmc))
-        Parrot_free_pmc_ext(interp, pmc);
+        Parrot_gc_free_pmc_ext(interp, pmc);
 
     PObj_flags_SETTO((PObj *)pmc, PObj_on_free_list_FLAG);
     pool->add_free_object(interp, pool, (PObj *)pmc);
@@ -482,6 +502,7 @@ pmc_free_to_pool(PARROT_INTERP, ARGMOD(PMC *pmc),
 void
 temporary_pmc_free(PARROT_INTERP, ARGMOD(PMC *pmc))
 {
+    ASSERT_ARGS(temporary_pmc_free)
     Small_Object_Pool *pool = interp->arena_base->constant_pmc_pool;
     pmc_free_to_pool(interp, pmc, pool);
 }
@@ -489,12 +510,26 @@ temporary_pmc_free(PARROT_INTERP, ARGMOD(PMC *pmc))
 static void
 pmc_free(PARROT_INTERP, ARGMOD(PMC *pmc))
 {
+    ASSERT_ARGS(pmc_free)
     Small_Object_Pool *pool = interp->arena_base->pmc_pool;
     pmc_free_to_pool(interp, pmc, pool);
 
 }
 
 
+INTVAL
+get_new_vtable_index(PARROT_INTERP)
+{
+    ASSERT_ARGS(get_new_vtable_index)
+    const INTVAL type_id = interp->n_vtable_max++;
+
+    /* Have we overflowed the table? */
+    if (type_id >= interp->n_vtable_alloced)
+        parrot_realloc_vtables(interp);
+
+    return type_id;
+}
+
 /*
 
 =item C<INTVAL pmc_register>
@@ -510,8 +545,7 @@ PARROT_EXPORT
 INTVAL
 pmc_register(PARROT_INTERP, ARGIN(STRING *name))
 {
-    PMC *classname_hash;
-
+    ASSERT_ARGS(pmc_register)
     /* If they're looking to register an existing class, return that
        class' type number */
     INTVAL type = pmc_type(interp, name);
@@ -523,15 +557,10 @@ pmc_register(PARROT_INTERP, ARGIN(STRING *name))
         Parrot_ex_throw_from_c_args(interp, NULL, 1,
             "undefined type already exists - can't register PMC");
 
-    classname_hash = interp->class_hash;
-    type           = interp->n_vtable_max++;
-
-    /* Have we overflowed the table? */
-    if (type >= interp->n_vtable_alloced)
-        parrot_realloc_vtables(interp);
+    type = get_new_vtable_index(interp);
 
     /* set entry in name->type hash */
-    VTABLE_set_integer_keyed_str(interp, classname_hash, name, type);
+    VTABLE_set_integer_keyed_str(interp, interp->class_hash, name, type);
 
     return type;
 }
@@ -552,6 +581,7 @@ PARROT_WARN_UNUSED_RESULT
 INTVAL
 pmc_type(PARROT_INTERP, ARGIN_NULLOK(STRING *name))
 {
+    ASSERT_ARGS(pmc_type)
     if (!name)
         return enum_type_undef;
     else {
@@ -585,9 +615,11 @@ PARROT_EXPORT
 INTVAL
 pmc_type_p(PARROT_INTERP, ARGIN(PMC *name))
 {
+    ASSERT_ARGS(pmc_type_p)
     PMC * const classname_hash = interp->class_hash;
-    PMC * const item           =
-        (PMC *)VTABLE_get_pointer_keyed(interp, classname_hash, name);
+    PMC * item;
+
+    item = (PMC *)VTABLE_get_pointer_keyed(interp, classname_hash, name);
 
     if (!PMC_IS_NULL(item))
         return VTABLE_get_integer(interp, item);
@@ -612,6 +644,7 @@ PARROT_CANNOT_RETURN_NULL
 static PMC *
 create_class_pmc(PARROT_INTERP, INTVAL type)
 {
+    ASSERT_ARGS(create_class_pmc)
     /*
      * class interface - a PMC is its own class
      * put an instance of this PMC into class
@@ -630,7 +663,7 @@ create_class_pmc(PARROT_INTERP, INTVAL type)
     }
     else {
         if (PObj_is_PMC_EXT_TEST(_class))
-            Parrot_free_pmc_ext(interp, _class);
+            Parrot_gc_free_pmc_ext(interp, _class);
 
         DOD_flag_CLEAR(is_special_PMC, _class);
 
@@ -660,6 +693,7 @@ PARROT_EXPORT
 void
 Parrot_create_mro(PARROT_INTERP, INTVAL type)
 {
+    ASSERT_ARGS(Parrot_create_mro)
     PMC    *_class, *mro;
     VTABLE *vtable   = interp->vtables[type];
     PMC    *mro_list = vtable->mro;
@@ -730,6 +764,7 @@ PARROT_EXPORT
 void
 dod_register_pmc(PARROT_INTERP, ARGIN(PMC *pmc))
 {
+    ASSERT_ARGS(dod_register_pmc)
     /* Better not trigger a DOD run with a potentially unanchored PMC */
     Parrot_block_GC_mark(interp);
 
@@ -753,6 +788,7 @@ Unregisters the PMC from the interpreter's DOD registry.
 void
 dod_unregister_pmc(PARROT_INTERP, ARGIN(PMC *pmc))
 {
+    ASSERT_ARGS(dod_unregister_pmc)
     PARROT_ASSERT(interp->DOD_registry);
 
     VTABLE_delete_keyed(interp, interp->DOD_registry, pmc);
