@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/pmc_freeze.c 33290 2008-11-27T07:46:05.528409Z chromatic  $
+$Id: /mirror/trunk/src/pmc_freeze.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -83,9 +83,10 @@ static void do_action(PARROT_INTERP,
         __attribute__nonnull__(3);
 
 PARROT_INLINE
-static void do_thaw(PARROT_INTERP, ARGIN(PMC* pmc), ARGIN(visit_info *info))
+static void do_thaw(PARROT_INTERP,
+    ARGIN_NULLOK(PMC* pmc),
+    ARGIN(visit_info *info))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
 PARROT_INLINE
@@ -292,19 +293,145 @@ static void visit_next_for_GC(PARROT_INTERP,
         __attribute__nonnull__(3);
 
 static void visit_todo_list(PARROT_INTERP,
-    ARGIN(PMC* pmc),
+    ARGIN_NULLOK(PMC* pmc),
     ARGIN(visit_info* info))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
 static void visit_todo_list_thaw(PARROT_INTERP,
-    ARGIN(PMC* old),
+    ARGIN_NULLOK(PMC* old),
     ARGIN(visit_info* info))
         __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
+#define ASSERT_ARGS_add_pmc_next_for_GC __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(pmc) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_add_pmc_todo_list __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_cleanup_next_for_GC __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_cleanup_next_for_GC_pool __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(pool)
+#define ASSERT_ARGS_create_image __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_do_action __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_do_thaw __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_freeze_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_ft_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_id_from_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc)
+#define ASSERT_ARGS_next_for_GC_seen __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info) \
+    || PARROT_ASSERT_ARG(id)
+#define ASSERT_ARGS_op_append __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(s)
+#define ASSERT_ARGS_op_check_size __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(s)
+#define ASSERT_ARGS_pmc_add_ext __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc)
+#define ASSERT_ARGS_push_ascii_integer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_push_ascii_number __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_push_ascii_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io) \
+    || PARROT_ASSERT_ARG(v)
+#define ASSERT_ARGS_push_ascii_string __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io) \
+    || PARROT_ASSERT_ARG(s)
+#define ASSERT_ARGS_push_opcode_integer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_push_opcode_number __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_push_opcode_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io) \
+    || PARROT_ASSERT_ARG(v)
+#define ASSERT_ARGS_push_opcode_string __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io) \
+    || PARROT_ASSERT_ARG(v)
+#define ASSERT_ARGS_run_thaw __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(image)
+#define ASSERT_ARGS_shift_ascii_integer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_ascii_number __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_ascii_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_ascii_string __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_opcode_integer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_opcode_number __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_opcode_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_shift_opcode_string __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(io)
+#define ASSERT_ARGS_str_append __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(s) \
+    || PARROT_ASSERT_ARG(b)
+#define ASSERT_ARGS_thaw_create_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_thaw_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info) \
+    || PARROT_ASSERT_ARG(id) \
+    || PARROT_ASSERT_ARG(type)
+#define ASSERT_ARGS_todo_list_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_todo_list_seen __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc) \
+    || PARROT_ASSERT_ARG(info) \
+    || PARROT_ASSERT_ARG(id)
+#define ASSERT_ARGS_visit_loop_next_for_GC __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(current) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_visit_loop_todo_list __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_visit_next_for_GC __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(pmc) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_visit_todo_list __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_visit_todo_list_thaw __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -353,6 +480,7 @@ No encoding of strings, no transcoding.
 static void
 str_append(PARROT_INTERP, ARGMOD(STRING *s), ARGIN(const void *b), size_t len)
 {
+    ASSERT_ARGS(str_append)
     const size_t used = s->bufused;
     const int need_free = (int)PObj_buflen(s) - used - len;
     /*
@@ -384,6 +512,7 @@ Pushes an ASCII version of the integer C<v> onto the end of the C<*io>
 static void
 push_ascii_integer(PARROT_INTERP, ARGIN(IMAGE_IO *io), INTVAL v)
 {
+    ASSERT_ARGS(push_ascii_integer)
     char buffer[20];
     const size_t len = snprintf(buffer, sizeof (buffer), "%d ", (int) v);
     str_append(interp, io->image, buffer, len);
@@ -403,6 +532,7 @@ Pushes an ASCII version of the number C<v> onto the end of the C<*io>
 static void
 push_ascii_number(PARROT_INTERP, ARGIN(const IMAGE_IO *io), FLOATVAL v)
 {
+    ASSERT_ARGS(push_ascii_number)
     char buffer[40];
     const size_t len = snprintf(buffer, sizeof (buffer), "%g ", (double) v);
     str_append(interp, io->image, buffer, len);
@@ -426,6 +556,7 @@ XXX no string delimiters - so no space allowed.
 static void
 push_ascii_string(PARROT_INTERP, ARGIN(IMAGE_IO *io), ARGIN(const STRING *s))
 {
+    ASSERT_ARGS(push_ascii_string)
     const UINTVAL length = string_length(interp, s);
     char * const buffer = (char *)malloc(4*length); /* XXX Why 4?  What does that mean? */
     char *cursor = buffer;
@@ -456,6 +587,7 @@ Pushes an ASCII version of the PMC C<*v> onto the end of the C<*io>
 static void
 push_ascii_pmc(PARROT_INTERP, ARGIN(IMAGE_IO *io), ARGIN(const PMC* v))
 {
+    ASSERT_ARGS(push_ascii_pmc)
     char buffer[20];
     const size_t len = snprintf(buffer, sizeof (buffer), "%p ", (const void *)v);
     str_append(interp, io->image, buffer, len);
@@ -474,6 +606,7 @@ Removes and returns an integer from the start of the C<*io> "stream".
 static INTVAL
 shift_ascii_integer(SHIM_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_ascii_integer)
     char * const start = (char*)io->image->strstart;
     char *p = start;
     const INTVAL i = strtoul(p, &p, 10);
@@ -499,6 +632,7 @@ Removes and returns an number from the start of the C<*io> "stream".
 static FLOATVAL
 shift_ascii_number(SHIM_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_ascii_number)
     char * const start = (char*)io->image->strstart;
     char *p = start;
     const FLOATVAL f = (FLOATVAL) strtod(p, &p);
@@ -526,6 +660,7 @@ PARROT_CAN_RETURN_NULL
 static STRING*
 shift_ascii_string(PARROT_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_ascii_string)
     STRING *s;
 
     char * const start = (char*)io->image->strstart;
@@ -558,6 +693,7 @@ PARROT_CAN_RETURN_NULL
 static PMC*
 shift_ascii_pmc(SHIM_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_ascii_pmc)
     char * const start = (char*)io->image->strstart;
     char *p = start;
     const unsigned long i = strtoul(p, &p, 16);
@@ -590,6 +726,7 @@ PARROT_INLINE
 static void
 op_check_size(PARROT_INTERP, ARGIN(STRING *s), size_t len)
 {
+    ASSERT_ARGS(op_check_size)
     const size_t used = s->bufused;
     const int need_free = (int)PObj_buflen(s) - used - len;
     /*
@@ -620,6 +757,7 @@ Appends the opcode C<b> to the string C<*s>.
 static void
 op_append(PARROT_INTERP, ARGIN(STRING *s), opcode_t b, size_t len)
 {
+    ASSERT_ARGS(op_append)
     op_check_size(interp, s, len);
     *((opcode_t *)((ptrcast_t)s->strstart + s->bufused)) = b;
     s->bufused += len;
@@ -641,6 +779,7 @@ XXX assumes sizeof (opcode_t) == sizeof (INTVAL).
 static void
 push_opcode_integer(PARROT_INTERP, ARGIN(IMAGE_IO *io), INTVAL v)
 {
+    ASSERT_ARGS(push_opcode_integer)
     PARROT_ASSERT(sizeof (opcode_t) == sizeof (INTVAL));
     op_append(interp, io->image, (opcode_t)v, sizeof (opcode_t));
 }
@@ -658,6 +797,7 @@ Pushes the number C<v> onto the end of the C<*io> "stream".
 static void
 push_opcode_number(PARROT_INTERP, ARGIN(IMAGE_IO *io), FLOATVAL v)
 {
+    ASSERT_ARGS(push_opcode_number)
     const size_t   len  = PF_size_number() * sizeof (opcode_t);
     STRING * const s    = io->image;
     const size_t   used = s->bufused;
@@ -684,6 +824,7 @@ Pushes the string C<*v> onto the end of the C<*io> "stream".
 static void
 push_opcode_string(PARROT_INTERP, ARGIN(IMAGE_IO *io), ARGIN(STRING *v))
 {
+    ASSERT_ARGS(push_opcode_string)
     const size_t len = PF_size_string(v) * sizeof (opcode_t);
     STRING * const s = io->image;
     const size_t used = s->bufused;
@@ -710,6 +851,7 @@ Pushes the PMC C<*v> onto the end of the C<*io> "stream".
 static void
 push_opcode_pmc(PARROT_INTERP, ARGIN(IMAGE_IO *io), ARGIN(PMC* v))
 {
+    ASSERT_ARGS(push_opcode_pmc)
     op_append(interp, io->image, (opcode_t)v, sizeof (opcode_t));
 }
 
@@ -729,6 +871,7 @@ packfile header for wordsize and endianess.
 static INTVAL
 shift_opcode_integer(SHIM_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_opcode_integer)
     const char * const   start  = (char *)io->image->strstart;
     char               **opcode = &io->image->strstart;
     const INTVAL i              = PF_fetch_integer(io->pf,
@@ -757,6 +900,7 @@ PARROT_CAN_RETURN_NULL
 static PMC*
 shift_opcode_pmc(PARROT_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_opcode_pmc)
     INTVAL i = shift_opcode_integer(interp, io);
     return (PMC *)i;
 }
@@ -774,6 +918,7 @@ Removes and returns an number from the start of the C<*io> "stream".
 static FLOATVAL
 shift_opcode_number(SHIM_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_opcode_number)
     const char * const   start  = (const char *)io->image->strstart;
     char               **opcode = &io->image->strstart;
     const FLOATVAL       f      = PF_fetch_number(io->pf,
@@ -800,6 +945,7 @@ PARROT_CANNOT_RETURN_NULL
 static STRING*
 shift_opcode_string(PARROT_INTERP, ARGIN(IMAGE_IO *io))
 {
+    ASSERT_ARGS(shift_opcode_string)
     char * const   start  = (char*)io->image->strstart;
     char         **opcode = &io->image->strstart;
     STRING * const s      = PF_fetch_string(interp, io->pf,
@@ -830,6 +976,7 @@ Adds a C<PMC_EXT> to C<*pmc>.
 static void
 pmc_add_ext(PARROT_INTERP, ARGIN(PMC *pmc))
 {
+    ASSERT_ARGS(pmc_add_ext)
     if (pmc->vtable->flags & VTABLE_PMC_NEEDS_EXT)
         add_pmc_ext(interp, pmc);
 }
@@ -847,6 +994,7 @@ Sets all the C<next_for_GC> pointers to C<NULL>.
 static void
 cleanup_next_for_GC_pool(ARGIN(Small_Object_Pool *pool))
 {
+    ASSERT_ARGS(cleanup_next_for_GC_pool)
     Small_Object_Arena *arena;
 
     for (arena = pool->last_Arena; arena; arena = arena->prev) {
@@ -876,6 +1024,7 @@ Cleans up the C<next_for_GC> pointers.
 static void
 cleanup_next_for_GC(PARROT_INTERP)
 {
+    ASSERT_ARGS(cleanup_next_for_GC)
     cleanup_next_for_GC_pool(interp->arena_base->pmc_pool);
     cleanup_next_for_GC_pool(interp->arena_base->constant_pmc_pool);
 }
@@ -923,6 +1072,7 @@ Initializes the freeze/thaw subsystem.
 static void
 ft_init(PARROT_INTERP, ARGIN(visit_info *info))
 {
+    ASSERT_ARGS(ft_init)
     STRING *s = info->image;
     PackFile *pf;
 
@@ -980,6 +1130,7 @@ Initializes the C<*info> lists.
 static void
 todo_list_init(PARROT_INTERP, ARGOUT(visit_info *info))
 {
+    ASSERT_ARGS(todo_list_init)
     info->visit_pmc_now = visit_todo_list;
     info->visit_pmc_later = add_pmc_todo_list;
     /* we must use PMCs here, so that they get marked properly */
@@ -1006,6 +1157,7 @@ static void
 freeze_pmc(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc), ARGIN(visit_info *info),
         int seen, UINTVAL id)
 {
+    ASSERT_ARGS(freeze_pmc)
     IMAGE_IO * const io = info->image_io;
     INTVAL type;
 
@@ -1064,6 +1216,7 @@ static int
 thaw_pmc(PARROT_INTERP, ARGMOD(visit_info *info),
         ARGOUT(UINTVAL *id), ARGOUT(INTVAL *type))
 {
+    ASSERT_ARGS(thaw_pmc)
     PMC *n;
     IMAGE_IO * const io = info->image_io;
     int seen = 0;
@@ -1115,6 +1268,7 @@ static void
 do_action(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc), ARGIN(visit_info *info),
         int seen, UINTVAL id)
 {
+    ASSERT_ARGS(do_action)
     switch (info->what) {
         case VISIT_FREEZE_AT_DESTRUCT:
         case VISIT_FREEZE_NORMAL:
@@ -1144,6 +1298,7 @@ static PMC*
 thaw_create_pmc(PARROT_INTERP, ARGIN(const visit_info *info),
         INTVAL type)
 {
+    ASSERT_ARGS(thaw_create_pmc)
     PMC *pmc;
     switch (info->what) {
         case VISIT_THAW_NORMAL:
@@ -1172,8 +1327,9 @@ C<seen> is false if this is the first time the PMC has been encountered.
 
 PARROT_INLINE
 static void
-do_thaw(PARROT_INTERP, ARGIN(PMC* pmc), ARGIN(visit_info *info))
+do_thaw(PARROT_INTERP, ARGIN_NULLOK(PMC* pmc), ARGIN(visit_info *info))
 {
+    ASSERT_ARGS(do_thaw)
     UINTVAL id;
     INTVAL type;
     PMC ** pos;
@@ -1271,6 +1427,7 @@ If not found, throw an exception.
 static UINTVAL
 id_from_pmc(PARROT_INTERP, ARGIN(PMC* pmc))
 {
+    ASSERT_ARGS(id_from_pmc)
     UINTVAL id = 1;     /* first PMC in first arena */
     Small_Object_Arena *arena;
     Small_Object_Pool *pool;
@@ -1316,6 +1473,7 @@ Remembers the PMC for later processing.
 static void
 add_pmc_next_for_GC(SHIM_INTERP, ARGIN(PMC *pmc), ARGOUT(visit_info *info))
 {
+    ASSERT_ARGS(add_pmc_next_for_GC)
     if (pmc->pmc_ext) {
         PMC_next_for_GC(info->mark_ptr) = pmc;
         info->mark_ptr = PMC_next_for_GC(pmc) = pmc;
@@ -1340,6 +1498,7 @@ static int
 next_for_GC_seen(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc),
         ARGIN(visit_info *info), ARGOUT(UINTVAL *id))
 {
+    ASSERT_ARGS(next_for_GC_seen)
     int seen = 0;
 
     if (PMC_IS_NULL(pmc)) {
@@ -1380,6 +1539,7 @@ Remembers the PMC to be processed later.
 static void
 add_pmc_todo_list(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc), ARGIN(visit_info *info))
 {
+    ASSERT_ARGS(add_pmc_todo_list)
     list_push(interp, (List *)PMC_data(info->todo), pmc, enum_type_PMC);
 }
 
@@ -1400,6 +1560,7 @@ static int
 todo_list_seen(PARROT_INTERP, ARGIN(PMC *pmc), ARGMOD(visit_info *info),
         ARGOUT(UINTVAL *id))
 {
+    ASSERT_ARGS(todo_list_seen)
     HashBucket * const b =
         parrot_hash_get_bucket(interp, (Hash *)PMC_struct_val(info->seen), pmc);
 
@@ -1433,6 +1594,7 @@ appropriate action.
 static void
 visit_next_for_GC(PARROT_INTERP, ARGIN(PMC* pmc), ARGIN(visit_info* info))
 {
+    ASSERT_ARGS(visit_next_for_GC)
     UINTVAL id;
     const int seen = next_for_GC_seen(interp, pmc, info, &id);
     UNUSED(seen);
@@ -1462,8 +1624,9 @@ Checks the seen PMC via the todo list.
 */
 
 static void
-visit_todo_list(PARROT_INTERP, ARGIN(PMC* pmc), ARGIN(visit_info* info))
+visit_todo_list(PARROT_INTERP, ARGIN_NULLOK(PMC* pmc), ARGIN(visit_info* info))
 {
+    ASSERT_ARGS(visit_todo_list)
     UINTVAL id;
     int seen;
 
@@ -1491,8 +1654,9 @@ Todo-list and seen handling is all in C<do_thaw()>.
 */
 
 static void
-visit_todo_list_thaw(PARROT_INTERP, ARGIN(PMC* old), ARGIN(visit_info* info))
+visit_todo_list_thaw(PARROT_INTERP, ARGIN_NULLOK(PMC* old), ARGIN(visit_info* info))
 {
+    ASSERT_ARGS(visit_todo_list_thaw)
     do_thaw(interp, old, info);
 }
 
@@ -1511,6 +1675,7 @@ static void
 visit_loop_next_for_GC(PARROT_INTERP, ARGIN(PMC *current),
         ARGIN(visit_info *info))
 {
+    ASSERT_ARGS(visit_loop_next_for_GC)
     visit_next_for_GC(interp, current, info);
     if (current->pmc_ext) {
         PMC *prev = NULL;
@@ -1538,6 +1703,7 @@ static void
 visit_loop_todo_list(PARROT_INTERP, ARGIN_NULLOK(PMC *current),
         ARGIN(visit_info *info))
 {
+    ASSERT_ARGS(visit_loop_todo_list)
     PMC        **list_item;
     List        *finish_list    = NULL;
     List * const todo           = (List *)PMC_data(info->todo);
@@ -1613,6 +1779,7 @@ Allocate image to some estimated size.
 static void
 create_image(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc), ARGMOD(visit_info *info))
 {
+    ASSERT_ARGS(create_image)
     STRING *array = CONST_STRING(interp, "array");
     STRING *hash  = CONST_STRING(interp, "hash");
     INTVAL  len;
@@ -1654,6 +1821,7 @@ PARROT_CAN_RETURN_NULL
 static PMC*
 run_thaw(PARROT_INTERP, ARGIN(STRING* image), visit_enum_type what)
 {
+    ASSERT_ARGS(run_thaw)
     visit_info info;
     int dod_block = 0;
     const UINTVAL bufused = image->bufused;
@@ -1729,6 +1897,7 @@ PARROT_CAN_RETURN_NULL
 STRING*
 Parrot_freeze_at_destruct(PARROT_INTERP, ARGIN(PMC* pmc))
 {
+    ASSERT_ARGS(Parrot_freeze_at_destruct)
     visit_info info;
 
     Parrot_block_GC_mark(interp);
@@ -1765,7 +1934,9 @@ PARROT_CAN_RETURN_NULL
 STRING*
 Parrot_freeze(PARROT_INTERP, ARGIN(PMC* pmc))
 {
+    ASSERT_ARGS(Parrot_freeze)
 #if FREEZE_USE_NEXT_FOR_GC
+    ASSERT_ARGS(Parrot_freeze)
     /*
      * we could do a DOD run here before, to free resources
      */
@@ -1806,6 +1977,7 @@ PARROT_CAN_RETURN_NULL
 PMC*
 Parrot_thaw(PARROT_INTERP, ARGIN(STRING* image))
 {
+    ASSERT_ARGS(Parrot_thaw)
     return run_thaw(interp, image, VISIT_THAW_NORMAL);
 }
 
@@ -1826,6 +1998,7 @@ PARROT_CAN_RETURN_NULL
 PMC*
 Parrot_thaw_constants(PARROT_INTERP, ARGIN(STRING* image))
 {
+    ASSERT_ARGS(Parrot_thaw_constants)
     return run_thaw(interp, image, VISIT_THAW_CONSTANTS);
 }
 
@@ -1847,6 +2020,7 @@ PARROT_CAN_RETURN_NULL
 PMC*
 Parrot_clone(PARROT_INTERP, ARGIN(PMC* pmc))
 {
+    ASSERT_ARGS(Parrot_clone)
     return VTABLE_clone(interp, pmc);
 }
 
