@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/spf_render.c 31873 2008-10-09T20:33:20.758186Z chromatic  $
+$Id: /mirror/trunk/src/spf_render.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -90,6 +90,18 @@ static STRING* str_append_w_flags(PARROT_INTERP,
         FUNC_MODIFIES(*dest)
         FUNC_MODIFIES(*src);
 
+#define ASSERT_ARGS_gen_sprintf_call __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(out) \
+    || PARROT_ASSERT_ARG(info)
+#define ASSERT_ARGS_handle_flags __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(info) \
+    || PARROT_ASSERT_ARG(str)
+#define ASSERT_ARGS_str_append_w_flags __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(dest) \
+    || PARROT_ASSERT_ARG(info) \
+    || PARROT_ASSERT_ARG(src)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -116,6 +128,7 @@ static STRING *
 handle_flags(PARROT_INTERP, ARGIN(const SpfInfo *info), ARGMOD(STRING *str),
         INTVAL is_int_type, ARGIN_NULLOK(STRING* prefix))
 {
+    ASSERT_ARGS(handle_flags)
     UINTVAL len = string_length(interp, str);
 
     if (is_int_type) {
@@ -222,6 +235,7 @@ static STRING*
 str_append_w_flags(PARROT_INTERP, ARGOUT(STRING *dest), ARGIN(const SpfInfo *info),
         ARGMOD(STRING *src), ARGIN_NULLOK(STRING *prefix))
 {
+    ASSERT_ARGS(str_append_w_flags)
     src = handle_flags(interp, info, src, 1, prefix);
     dest = string_append(interp, dest, src);
     return dest;
@@ -242,6 +256,7 @@ a float.
 static void
 gen_sprintf_call(ARGOUT(char *out), ARGMOD(SpfInfo *info), int thingy)
 {
+    ASSERT_ARGS(gen_sprintf_call)
     int i    = 0;
     out[i++] = '%';
 
@@ -306,6 +321,7 @@ STRING *
 Parrot_sprintf_format(PARROT_INTERP,
         ARGIN(STRING *pat), ARGIN(SPRINTF_OBJ *obj))
 {
+    ASSERT_ARGS(Parrot_sprintf_format)
     INTVAL i;
     INTVAL len     = 0;
     INTVAL old     = 0;
