@@ -1,7 +1,7 @@
 /* trace.h
  *  Copyright (C) 2001-2007, The Perl Foundation.
  *  SVN Info
- *     $Id: /mirror/trunk/src/trace.h 27459 2008-05-12T02:15:12.435938Z petdance  $
+ *     $Id: /mirror/trunk/src/trace.h 35845 2009-01-20T16:33:48.434431Z julianalbo  $
  *  Overview:
  *     Tracing support for runops_cores.c.
  *  Data Structure and Algorithms:
@@ -18,7 +18,7 @@
 /* HEADERIZER BEGIN: src/trace.c */
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 
-int trace_key_dump(PARROT_INTERP, ARGIN(const PMC *key))
+int trace_key_dump(PARROT_INTERP, ARGIN(PMC *key))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
@@ -40,6 +40,19 @@ void trace_op_dump(PARROT_INTERP,
 void trace_pmc_dump(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc))
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_trace_key_dump __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(key)
+#define ASSERT_ARGS_trace_op __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(code_start) \
+    || PARROT_ASSERT_ARG(code_end)
+#define ASSERT_ARGS_trace_op_dump __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp) \
+    || PARROT_ASSERT_ARG(code_start) \
+    || PARROT_ASSERT_ARG(pc)
+#define ASSERT_ARGS_trace_pmc_dump __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/trace.c */
 
