@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, The Perl Foundation.
-$Id: /mirror/trunk/src/tsq.c 33963 2008-12-15T19:54:53.572920Z Whiteknight  $
+$Id: /mirror/trunk/src/tsq.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -34,6 +34,7 @@ PARROT_CAN_RETURN_NULL
 QUEUE_ENTRY *
 pop_entry(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(pop_entry)
     QUEUE_ENTRY *returnval;
     queue_lock(queue);
     returnval = nosync_pop_entry(queue);
@@ -58,6 +59,7 @@ PARROT_WARN_UNUSED_RESULT
 QUEUE_ENTRY *
 peek_entry(ARGIN(const QUEUE *queue))
 {
+    ASSERT_ARGS(peek_entry)
     return queue->head;
 }
 
@@ -77,6 +79,7 @@ PARROT_CANNOT_RETURN_NULL
 QUEUE_ENTRY *
 nosync_pop_entry(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(nosync_pop_entry)
     QUEUE_ENTRY *returnval;
     if (!queue->head) {
         return NULL;
@@ -108,6 +111,7 @@ PARROT_CAN_RETURN_NULL
 QUEUE_ENTRY *
 wait_for_entry(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(wait_for_entry)
     QUEUE_ENTRY *returnval;
 
     queue_lock(queue);
@@ -133,6 +137,7 @@ Does a synchronized insertion of C<entry> onto the tail of the queue.
 void
 push_entry(ARGMOD(QUEUE *queue), ARGIN(QUEUE_ENTRY *entry))
 {
+    ASSERT_ARGS(push_entry)
     queue_lock(queue);
     /* Is there something in the queue? */
     if (queue->tail) {
@@ -160,6 +165,7 @@ Does a synchronized insertion of C<entry> into the head of the queue.
 void
 unshift_entry(ARGMOD(QUEUE *queue), ARGIN(QUEUE_ENTRY *entry))
 {
+    ASSERT_ARGS(unshift_entry)
     QUEUE_ENTRY *cur;
 
     queue_lock(queue);
@@ -191,6 +197,7 @@ queue mutex.
 void
 nosync_insert_entry(ARGMOD(QUEUE *queue), ARGIN(QUEUE_ENTRY *entry))
 {
+    ASSERT_ARGS(nosync_insert_entry)
     QUEUE_ENTRY *cur = queue->head;
     QUEUE_ENTRY *prev;
     parrot_event *event;
@@ -242,6 +249,7 @@ Does a synchronized insert of C<entry>.
 void
 insert_entry(ARGMOD(QUEUE *queue), ARGIN(QUEUE_ENTRY *entry))
 {
+    ASSERT_ARGS(insert_entry)
     queue_lock(queue);
     nosync_insert_entry(queue, entry);
     queue_signal(queue);
@@ -261,6 +269,7 @@ Locks the queue's mutex.
 void
 queue_lock(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_lock)
     LOCK(queue->queue_mutex);
 }
 
@@ -277,6 +286,7 @@ Unlocks the queue's mutex.
 void
 queue_unlock(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_unlock)
     UNLOCK(queue->queue_mutex);
 }
 
@@ -293,6 +303,7 @@ This function wakes up I<every> thread waiting on the queue.
 void
 queue_broadcast(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_broadcast)
     COND_BROADCAST(queue->queue_condition);
 }
 
@@ -309,6 +320,7 @@ RT#48260: Document this!
 void
 queue_signal(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_signal)
     COND_SIGNAL(queue->queue_condition);
 }
 
@@ -325,6 +337,7 @@ Instructs the queue to wait.
 void
 queue_wait(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_wait)
     COND_WAIT(queue->queue_condition, queue->queue_mutex);
 }
 
@@ -341,6 +354,7 @@ Instructs the queue to wait for C<abs_time> seconds (?).
 void
 queue_timedwait(ARGMOD(QUEUE *queue), ARGIN(const struct timespec *abs_time))
 {
+    ASSERT_ARGS(queue_timedwait)
     COND_TIMED_WAIT(queue->queue_condition, queue->queue_mutex, abs_time);
 }
 
@@ -359,6 +373,7 @@ PARROT_MALLOC
 QUEUE*
 queue_init(UINTVAL prio)
 {
+    ASSERT_ARGS(queue_init)
     QUEUE * const queue = mem_allocate_typed(QUEUE);
 
     queue->head = queue->tail = NULL;
@@ -381,6 +396,7 @@ Destroys the queue, raising an exception if it is not empty.
 void
 queue_destroy(ARGMOD(QUEUE *queue))
 {
+    ASSERT_ARGS(queue_destroy)
     if (peek_entry(queue))
         exit_fatal(1, "Queue not empty on destroy");
 
