@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, The Perl Foundation.
-$Id: /mirror/trunk/src/warnings.c 33726 2008-12-09T05:16:33.974298Z allison  $
+$Id: /mirror/trunk/src/warnings.c 35040 2009-01-05T23:17:26.989703Z infinoid  $
 
 =head1 NAME
 
@@ -29,6 +29,8 @@ messages.
 static INTVAL print_warning(PARROT_INTERP, ARGIN_NULLOK(STRING *msg))
         __attribute__nonnull__(1);
 
+#define ASSERT_ARGS_print_warning __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+       PARROT_ASSERT_ARG(interp)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -46,6 +48,7 @@ PARROT_EXPORT
 void
 print_pbc_location(PARROT_INTERP)
 {
+    ASSERT_ARGS(print_pbc_location)
     Interp * const tracer = interp->debugger ? interp->debugger : interp;
     Parrot_io_eprintf(tracer, "%Ss\n",
             Parrot_Context_infostr(interp,
@@ -65,6 +68,7 @@ Prints the warning message and the bytecode location.
 static INTVAL
 print_warning(PARROT_INTERP, ARGIN_NULLOK(STRING *msg))
 {
+    ASSERT_ARGS(print_warning)
     if (!msg)
         Parrot_io_puts(interp, Parrot_io_STDERR(interp), "Unknown warning\n");
     else {
@@ -101,7 +105,7 @@ INTVAL
 Parrot_warn(PARROT_INTERP, INTVAL warnclass,
             ARGIN(const char *message), ...)
 {
-    PARROT_ASSERT(interp);
+    ASSERT_ARGS(Parrot_warn)
     if (!PARROT_WARNINGS_test(interp, warnclass))
         return 2;
     else {
