@@ -1,7 +1,7 @@
 #! perl
 
 # Copyright (C) 2007, The Perl Foundation.
-# $Id: /mirror/trunk/tools/dev/reconfigure.pl 29467 2008-07-14T16:09:46.135024Z coke  $
+# $Id: /mirror/trunk/tools/dev/reconfigure.pl 34978 2009-01-05T00:07:29.920573Z jkeenan  $
 
 use 5.008;
 use strict;
@@ -24,15 +24,15 @@ my $conf = Parrot::Configure->new;
 $conf->add_step( $args->{step} );
 $conf->options->set( %{$args} );
 
-# The result of slurp() is that the parameters in %Parrot::Config::PConfig
+# The result of get_PConfig() is that the parameters in %Parrot::Config::PConfig
 # are assigned to the {c} attribute in $conf.
-$conf->data()->slurp();
+$conf->data()->get_PConfig();
 
-# The result of slurp_temp() is that the parameters in
+# The result of get_PConfig_Temp() is that the parameters in
 # %Parrot::Config::PConfig_Temp
 # are assigned to the {c}{$_} attribute in $conf.
 if ( $args->{step} =~ /gen::makefiles/ ) {
-    $conf->data()->slurp_temp();
+    $conf->data()->get_PConfig_Temp();
 }
 $conf->run_single_step( $args->{step} );
 print "\n";
