@@ -1,6 +1,6 @@
 #! perl -pi.bak
-# $Id: /mirror/trunk/tools/dev/vtablize.pl 32435 2008-11-06T20:41:25.337682Z coke  $
-# Copyright (C) 2008, The Perl Foundation.
+# $Id: /mirror/trunk/tools/dev/vtablize.pl 35819 2009-01-20T05:19:27.074079Z chromatic  $
+# Copyright (C) 2008-2009, The Perl Foundation.
 
 =head1 NAME
 
@@ -31,7 +31,7 @@ use warnings;
 s/^(\s*)(void\s+init\(\)\s+{)/$1VTABLE $2/;
 s/^(\s*)(void\s+init_pmc\(PMC\s+\*\w*\)\s+{)/$1VTABLE $2/;
 s/^(\s*)(PMC\s+\*instantiate\(PMC\s+\*\w*\)\s+{)/$1VTABLE $2/;
-s/^(\s*)(PMC\s+\*new_from_string\(STRING\s+\*\w*,\s+INTVAL\s+\w*\)\s+{)/$1VTABLE $2/;
+s/^(\s*)(PMC\s+\*instantiate_str\(STRING\s+\*\w*,\s+INTVAL\s+\w*\)\s+{)/$1VTABLE $2/;
 s/^(\s*)(void\s+morph\(INTVAL\s+\w*\)\s+{)/$1VTABLE $2/;
 s/^(\s*)(void\s+mark\(\)\s+{)/$1VTABLE $2/;
 s/^(\s*)(void\s+destroy\(\)\s+{)/$1VTABLE $2/;
