@@ -1,6 +1,6 @@
 #! perl
-# Copyright (C) 2007-2008, The Perl Foundation.
-# $Id: /mirror/trunk/tools/install/smoke.pl 32098 2008-10-21T09:00:50.524985Z fperrad  $
+# Copyright (C) 2007-2009, The Perl Foundation.
+# $Id: /mirror/trunk/tools/install/smoke.pl 35745 2009-01-18T12:09:17.170228Z bernhard  $
 
 use strict;
 use warnings;
@@ -167,15 +167,6 @@ $out = `$parrot languages/ecmascript/js.pbc $filename`;
 ok($out eq "Hello World from JS\n", "check ecmascript");
 unlink($filename);
 
-$filename = 'test.HQ9Plus';
-open $FH, '>', $filename
-        or die "Can't open $filename ($!).\n";
-print $FH "H";
-close $FH;
-$out = `$parrot languages/hq9plus/hq9plus.pbc $filename`;
-ok($out eq "Hello, world!\n", "check HQ9Plus");
-unlink($filename);
-
 $filename = 'test.l';
 open $FH, '>', $filename
         or die "Can't open $filename ($!).\n";
@@ -201,9 +192,6 @@ unlink($filename);
 $out = `$parrot languages/lua/lua.pbc -e "print(nil)"`;
 ok($out eq "nil\n", "check lua");
 
-$out = `$parrot languages/m4/m4.pbc`;
-ok($out =~ /^Usage/, "check m4");
-
 $filename = 'test.text';
 open $FH, '>', $filename
         or die "Can't open $filename ($!).\n";
